/* Native ddl to define Insurance DDS */
CREATE TABLE ACCOUNTING_TRANS (
     ACCOUNTING_TRANS_ID  VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     REFERENCE_NO         VARCHAR(32),
     INT_EXT_TRANS_FLG    CHARACTER(1),
     ACCOUNTING_TRANS_TYPE_CD VARCHAR(3),
     ACCOUNTING_TRANS_SUB_TYPE_CD VARCHAR(3),
     ACCOUNTING_TRANS_CURRENCY_CD VARCHAR(3),
     TOTAL_TRANS_AMT      NUMERIC(18,5),
     ACCOUNTING_TRANS_DT  DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ACCOUNTING_TRANS_PI (ACCOUNTING_TRANS_ID,SOURCE_SYSTEM_CD)
;
CREATE TABLE ACCOUNTING_TRANS_LINE_ITEM (
     ACCOUNTING_TRANS_LINE_ITEM_NO NUMERIC(9)     NOT NULL,
     ACCOUNTING_TRANS_ID  VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     AMT_TYPE_CD          VARCHAR(3),
     LINE_ITEM_TRANS_AMT  NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ACCOUNTING_TRANS_LINE_ITEM_PI (ACCOUNTING_TRANS_LINE_ITEM_NO,ACCOUNTING_TRANS_ID,SOURCE_SYSTEM_CD)
;
CREATE TABLE ACCOUNT_CREDIT_ASSESSMENT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     ASSESSMENT_DT        DATE     NOT NULL,
     ASSESSMENT_MODEL_RK  NUMERIC(10)     NOT NULL,
     ASSESSMENT_RESULT_TYPE_CD VARCHAR(3)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10),
     OVERRIDE_RATING_FLG  CHARACTER(1),
     ASSESSMENT_RESULT_RT NUMERIC(9,4),
     ASSESS_CHANGE_REASON_CD VARCHAR(3),
     ASSESSMENT_RESULT_NO NUMERIC(6),
     CR_MITIGANT_ADJUSTED_FLG CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ACCOUNT_CREDIT_ASSESSMENT_PI (ACCOUNT_RK,ASSESSMENT_DT,ASSESSMENT_MODEL_RK,ASSESSMENT_RESULT_TYPE_CD)
;
CREATE TABLE ACCOUNT_CREDIT_RISK_MITIGANT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     CREDIT_RISK_MITIGANT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     MATURITY_DT          DATE,
     TOTAL_VALUE_AMT      NUMERIC(18,5),
     SOURCE_DOCUMENT_TXT  VARCHAR(100),
     CR_MITIGANT_RANK_NO  NUMERIC(6),
     USED_TO_COV_RISK_TYPE_CD VARCHAR(3),
     MTM_TOTAL_VALUE_AMT  NUMERIC(18,5),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ACCOUNT_CREDIT_RISK_MITIGAN_PI (ACCOUNT_RK,CREDIT_RISK_MITIGANT_RK)
;
CREATE TABLE ACCOUNT_PERIOD (
     ACCOUNT_PERIOD_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ACCOUNT_PERIOD_ID    VARCHAR(32)     NOT NULL,
     ACCOUNT_PERIOD_NM    VARCHAR(50),
     ACCOUNT_PERIOD_STATUS_CD VARCHAR(3),
     ACCOUNT_PERIOD_TYPE_CD VARCHAR(3),
     ACCOUNT_PERIOD_START_DT DATE,
     ACCOUNT_PERIOD_END_DT DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ACCOUNT_PERIOD_PI (ACCOUNT_PERIOD_RK)
;
CREATE TABLE ACCOUNT_PERIOD_ASSOC (
     ACCOUNT_PERIOD_RK    NUMERIC(10)     NOT NULL,
     PARENT_ACCOUNT_PERIOD_RK NUMERIC(10)     NOT NULL,
     ACCOUNT_PERIOD_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ACCOUNT_PERIOD_ASSOC_PI (ACCOUNT_PERIOD_RK,PARENT_ACCOUNT_PERIOD_RK,ACCOUNT_PERIOD_ASSOC_TYPE_CD)
;
CREATE TABLE AGENCY_TYPE (
     AGENCY_TYPE_CD       VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     AGENCY_TYPE_DESC     VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX AGENCY_TYPE_PI (AGENCY_TYPE_CD)
;
CREATE TABLE AIR_SPORT_DETAILS (
     LIFE_STYLE_ACTIVITY_RK NUMERIC(10)     NOT NULL,
     PROFESSIONAL_IND     CHARACTER(1),
     COMPETE_IND          CHARACTER(1),
     SAFETY_STANDARDS_IND CHARACTER(1),
     LAND_IND             CHARACTER(1),
     INLAND_WATER_IND     CHARACTER(1),
     REMOTE_TERRAIN_IND   CHARACTER(1),
     MOUNTAINS_IND        CHARACTER(1),
     OCEAN_IND            CHARACTER(1),
     BALLOON_TYPE_CD      VARCHAR(3),
     CERTIFIED_CRAFT_IND  CHARACTER(1),
     EXPERIMENTAL_EQUIP_IND CHARACTER(1),
     JUMP_LOCATION_TYPE_CD VARCHAR(3),
     FREE_FALL_MAX        NUMERIC(14,4),
     FREE_FALL_AVG        NUMERIC(14,4),
     MAX_DURATION_MINUTE  NUMERIC(6,2),
     NUM_HOURS            NUMERIC(4,2),
     CRAFT_ASSEMBLY_CD    VARCHAR(3),
     RIGID_WING_IND       CHARACTER(1),
     MOTORIZED_IND        CHARACTER(1),
     LICENSE_IND          CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX AIR_SPORT_DETAILS_PI (LIFE_STYLE_ACTIVITY_RK)
;
CREATE TABLE ALARM_DETAILS (
     ALARM_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ALARM_TYPE_CD        VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     ALERT_TYPE_CD        VARCHAR(3),
     ALARM_COVERAGE_AREA_CD VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ALARM_DETAILS_PI (ALARM_RK)
;
CREATE TABLE ANALYTICAL_MODEL (
     MODEL_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     MODEL_ID             VARCHAR(32)     NOT NULL,
     MODEL_TYPE_CD        VARCHAR(3),
     MODEL_NM             VARCHAR(40),
     MODEL_DESC           VARCHAR(250),
     MODEL_CREATION_DT    DATE,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     CR_MITIGANT_ADJUSTED_FLG CHARACTER(1),
     CUT_OFF_SCORE_NO     NUMERIC(4),
     FACTOR_RT            NUMERIC(9,4),
     MODEL_ANALYTICS_TYPE_CD VARCHAR(3),
     MODEL_CATEGORY_CD    VARCHAR(3),
     MODEL_DEPLOYMENT_CD  VARCHAR(3),
     MODEL_OUTPUT_VALUE_TYPE_CD VARCHAR(3),
     MODEL_PRODUCT_TYPE_CD VARCHAR(3),
     OFFSET_RT            NUMERIC(9,4),
     TARGET_PERIOD_CNT    NUMERIC(6),
     TARGET_PERIOD_MTHS_CNT NUMERIC(6,2),
     TARGET_PERIOD_TIME_UOM_CD VARCHAR(3),
     VERSION_NO           VARCHAR(20),
     MODEL_PACKAGE_RK     NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ANALYTICAL_MODEL_PI (MODEL_RK)
;
CREATE TABLE ANALYTICAL_MODEL_ASSOC (
     MODEL_RK             NUMERIC(10)     NOT NULL,
     REFERENCE_MODEL_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     MODEL_ASSOC_TYPE_CD  VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ANALYTICAL_MODEL_ASSOC_PI (MODEL_RK,REFERENCE_MODEL_RK)
;
CREATE TABLE ANALYTICAL_MODEL_PACKAGE (
     MODEL_PACKAGE_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     MODEL_PACKAGE_ID     VARCHAR(32),
     MODEL_PACKAGE_DESC   VARCHAR(100),
     MODEL_PACKAGE_LIBREF_NM VARCHAR(40),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     MODEL_PACKAGE_PATH_TXT VARCHAR(256))
     PRIMARY INDEX ANALYTICAL_MODEL_PACKAGE_PI (MODEL_PACKAGE_RK)
;
CREATE TABLE ANALYTICAL_MODEL_PARAMETER (
     MODEL_RK             NUMERIC(10)     NOT NULL,
     MODEL_PARAMETER_CD   VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     MODEL_PARAMETER_NM   VARCHAR(40),
     MODEL_PARAMETER_VALUE_RT NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ANALYTICAL_MODEL_PARAMETER_PI (MODEL_RK,MODEL_PARAMETER_CD)
;
CREATE TABLE ANALYTICAL_MODEL_X_ENTITY (
     ANALYTICAL_MODEL_X_ENTITY_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CALC_MODEL_STANDARD_CD VARCHAR(3)     NOT NULL,
     MODEL_RK             NUMERIC(10)     NOT NULL,
     SEGMENT_RK           NUMERIC(10),
     COUNTERPARTY_RK      NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ANALYTICAL_MODEL_X_ENTITY_PI (ANALYTICAL_MODEL_X_ENTITY_RK)
;
CREATE TABLE ANALYTICAL_MODEL_X_EXPOSURE (
     ANALYTICAL_MODEL_X_EXPOSURE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     MODEL_RK             NUMERIC(10)     NOT NULL,
     ACCOUNT_RK           NUMERIC(10),
     EMBEDDED_OPTION_RK   NUMERIC(10),
     PHYSICAL_ASSET_RK    NUMERIC(10),
     MODEL_VALUATION_STANDARD_CD VARCHAR(3),
     CREDIT_FACILITY_RK   NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ANALYTICAL_MODEL_X_EXPOSURE_PI (FINANCIAL_INSTRUMENT_RK,MODEL_RK,EMBEDDED_OPTION_RK)
;
CREATE TABLE ANALYTICAL_MODEL_X_RISK_FACTOR (
     MODEL_RK             NUMERIC(10)     NOT NULL,
     RISK_FACTOR_ID       VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     MODELING_STANDARD_CD VARCHAR(3)     NOT NULL,
     ANALYTICAL_MODEL_ROLE_CD VARCHAR(3)     NOT NULL,
     RISK_FACTOR_WEIGHT   NUMERIC(9,6),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ANALYTICAL_MODEL_X_RISK_FAC_PI (MODEL_RK,RISK_FACTOR_ID,MODELING_STANDARD_CD,ANALYTICAL_MODEL_ROLE_CD)
;
CREATE TABLE ANNUITY_POLICY_DETAILS (
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PREMIUM_TYPE_CD      VARCHAR(3),
     TOTAL_AMT_WITHDRAWN  NUMERIC(18,5),
     MAN_PAYOUT_DT        DATE,
     ANNUITY_PAID_UP_TO_DT DATE,
     ANNUITY_BILLED_TO_DT DATE,
     HOME_LOAN_AMT        NUMERIC(18,5),
     DEATH_BENEFIT_PAY_OPTION_CD VARCHAR(3),
     DEATH_BENEFIT_AMT    NUMERIC(18,5),
     SURRENDER_CHARGE_AMT NUMERIC(18,5),
     SURRENDER_VALUE      NUMERIC(18,5),
     GUAR_INT_RT          NUMERIC(9,4),
     GUAR_LIFETIME_RT     NUMERIC(9,4),
     EE_CONTRIB_AMT       NUMERIC(18,5),
     ER_CONTRIB_AMT       NUMERIC(18,5),
     LOANED_AMT_INT_RT    NUMERIC(9,4),
     REQUESTED_MATURITY_AGE NUMERIC(3),
     REQUESTED_MATURITY_DT DATE,
     REQUESTED_MATURITY_DURATION NUMERIC(9),
     BONUS_VALUE_AMT      NUMERIC(18,5),
     PREMIUM_BONUS_AMT    NUMERIC(18,5),
     VALUATION_CLASS_TYPE_CD VARCHAR(3),
     GUAR_INT_RT_PERIOD_IND CHARACTER(1),
     GUAR_INT_START_DT    DATE,
     GUAR_INT_END_DT      DATE,
     INT_CREDITED_UPTO_DT DATE,
     JOINT_ANN_DEATH_REDUCT_RULE_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXANNUITY (POLICY_RK)
;
CREATE TABLE ANNUITY_PRODUCT (
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ANNUITY_TYPE_CD      VARCHAR(3),
     ANN_PAYOUT_TYPE_CD   VARCHAR(3),
     PREMIUM_TYPE_CD      VARCHAR(3),
     NEW_MONEY_ALLOC_RULE_CD VARCHAR(3),
     LOADING_TYPE_CD      VARCHAR(3),
     ANNUITIZATION_DATE_REQD_IND CHARACTER(1),
     DEATH_BENEFIT_ACCUM_CD VARCHAR(3),
     GUAR_PREMIUM_ACCUM_RT NUMERIC(9,4),
     PHASE_VALUED_CD      VARCHAR(3),
     ANNUITIZATION_RT     NUMERIC(9,4),
     ANN_PAYOUT_INDEX_RT  NUMERIC(9,4),
     ANN_PAYOUT_INDEX_FREQ_CD VARCHAR(3),
     ANN_PAYOUT_INDEX_METHOD_CD VARCHAR(3),
     DEATH_BENEFIT_PAYOUT_CD VARCHAR(3),
     GUAR_INT_CREDIT_FREQ_CD VARCHAR(3),
     GUAR_INT_COMPOUND_FREQ_CD VARCHAR(3),
     FIRST_DEATH_REDUCTION_RULE_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXANNUITY_PRODUCT (INSURANCE_PRODUCT_RK)
;
CREATE TABLE ANTI_THEFT_DEVICE (
     VEHICLE_RK           NUMERIC(10)     NOT NULL,
     ANTI_THEFT_DEVICE_CD VARCHAR(3)     NOT NULL,
     ANTI_THEFT_DEVICE_COST NUMERIC(18,5),
     MANUFACTURER_NM      VARCHAR(50),
     MANUFACTURE_YR       NUMERIC(4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ANTI_THEFT_DEVICE_PI (VEHICLE_RK,ANTI_THEFT_DEVICE_CD)
;
CREATE TABLE APPLICATION_DETAILS (
     APPLICATION_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     APPLICATION_NO       VARCHAR(32)     NOT NULL,
     APPLICATION_TYPE_CD  VARCHAR(3),
     APPLICATION_DTTM     TIMESTAMP,
     REQUESTED_POLICY_DT  DATE,
     INSURED_FULL_TO_BE_PAID_AMT NUMERIC(18,5),
     MAX_RISK_AMT         NUMERIC(18,5),
     UNDERWRITER_NM       VARCHAR(40),
     UNDERWRITING_DT      DATE,
     APPLICATION_STATUS_CD VARCHAR(3),
     STATUS_CHANGE_DT     DATE,
     STATUS_REASON_CD     VARCHAR(3),
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     QUOTE_RK             NUMERIC(10),
     PRODUCER_RK          NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX APPLICATION_DETAILS_PI (APPLICATION_RK)
;
CREATE TABLE ASSESSMENT_AGENCY (
     ASSESSMENT_AGENCY_CD VARCHAR(5)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ASSESSMENT_AGENCY_NM VARCHAR(100),
     ACCREDITED_EXTERNAL_AGENCY_FLG CHARACTER(1),
     EXTERNAL_FLG         CHARACTER(1),
     AGENCY_TYPE_CD       VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ASSESSMENT_AGENCY_PI (ASSESSMENT_AGENCY_CD)
;
CREATE TABLE ASSESSMENT_RATING_GRADE (
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ASSESSMENT_RATING_GRADE_ID VARCHAR(32)     NOT NULL,
     ASSESSMENT_AGENCY_CD VARCHAR(5)     NOT NULL,
     ASSESSMENT_GRADE     VARCHAR(20),
     ASSESSMENT_SCORE_NO  NUMERIC(10,2),
     ASSESSMENT_TYPE_CD   VARCHAR(3),
     SHORTTERM_FLG        CHARACTER(1),
     MODEL_RK             NUMERIC(10),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ASSESSMENT_RATING_GRADE_PI (ASSESSMENT_RATING_GRADE_RK)
;
CREATE TABLE ASSESSMENT_TYPE (
     ASSESSMENT_TYPE_CD   VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ASSESSMENT_TYPE_DESC VARCHAR(100),
     SHORTTERM_FLG        CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ASSESSMENT_TYPE_PI (ASSESSMENT_TYPE_CD)
;
CREATE TABLE ASSESSMENT_VALUES (
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ASSESSMENT_VALUE_TYPE_CD VARCHAR(3)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     MIN_ASSESSMENT_RT    NUMERIC(9,4),
     MAX_ASSESSMENT_RT    NUMERIC(9,4),
     AVG_ASSESSMENT_RT    NUMERIC(9,4),
     VALUE_MODEL_RK       NUMERIC(10),
     MEAN_RT              NUMERIC(9,4),
     STANDARD_DEVIATION_RT NUMERIC(9,4),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ASSESSMENT_VALUES_PI (VALID_FROM_DTTM,ASSESSMENT_VALUE_TYPE_CD,ASSESSMENT_RATING_GRADE_RK)
;
CREATE TABLE ASSET_PORTFOLIO_SEGMENT (
     ASSET_PORTFOLIO_SEGMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ASSET_PORTFOLIO_SEGMNT_TYPE_CD VARCHAR(3),
     FINANCIAL_FUND_RK    NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ASSET_PORTFOLIO_SEGMENT_PI (ASSET_PORTFOLIO_SEGMENT_RK)
;
CREATE TABLE ASSET_SEGMENT_X_EXPOSURE (
     ASSET_SEGMENT_X_EXPOSURE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ASSET_PORTFOLIO_SEGMENT_RK NUMERIC(10)     NOT NULL,
     ACCOUNT_RK           NUMERIC(10),
     PHYSICAL_ASSET_RK    NUMERIC(10),
     CREDIT_FACILITY_RK   NUMERIC(10),
     PROPORTION_PCT       NUMERIC(9,4),
     FINANCIAL_POSITION_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ASSET_SEGMENT_X_EXPOSURE_PI (ASSET_SEGMENT_X_EXPOSURE_RK)
;
CREATE TABLE ASSET_X_PHYSICAL_COLLATERAL (
     PHYSICAL_COLLATERAL_RK NUMERIC(10)     NOT NULL,
     PHYSICAL_ASSET_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ASSET_CLLTRL_RLN_TYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ASSET_X_PHYSICAL_COLLATERAL_PI (PHYSICAL_COLLATERAL_RK,PHYSICAL_ASSET_RK)
;
CREATE TABLE AUTO_LOSS_DETAILS (
     AUTO_LOSS_RK         NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     VEHICLE_NO           VARCHAR(32)     NOT NULL,
     MANUFACTURER_NM      VARCHAR(50),
     MODEL_NM             VARCHAR(50),
     AIR_BAG_TYPE_CD      VARCHAR(3),
     AIR_BAG_STATUS_CD    VARCHAR(3),
     OBJECT_LOSS_DESC     VARCHAR(255),
     VEH_SPEED            NUMERIC(14,4),
     IMPACT_POINT_CD      VARCHAR(3),
     DAMAGE_DESC          VARCHAR(255),
     OTHER_INSURANCE_IND  CHARACTER(1),
     PROPERTY_DAMAGED_VEH_IND CHARACTER(1),
     VEH_BEING_TOWED_IND  CHARACTER(1),
     DRIVABLE_IND         CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX AUTO_LOSS_DETAILS_PI (AUTO_LOSS_RK)
;
CREATE TABLE AVIATION_DETAILS (
     LIFE_STYLE_ACTIVITY_RK NUMERIC(10)     NOT NULL,
     AVIATION_TYPE_CD     VARCHAR(3),
     IFR_IND              CHARACTER(1),
     STUDENT_IND          CHARACTER(1),
     AIRCRAFT_TYPE_CD     VARCHAR(3),
     AIRCRAFT_SERIES      VARCHAR(50),
     JOB_ABOARD_AIRCRAFT_CD VARCHAR(3),
     FLYING_PURPOSE_CD    VARCHAR(3),
     HIGHEST_QUAL_LEVEL_CD VARCHAR(3),
     PROPOSED_QUAL_LEVEL_IND CHARACTER(1),
     QUALIFICATION_DT     DATE,
     RENEWAL_IND          CHARACTER(1),
     FOREIGN_FLIGHT_IND   CHARACTER(1),
     GROUNDED_IND         CHARACTER(1),
     MED_CLASS_WAIVER_IND CHARACTER(1),
     REVOKED_IND          CHARACTER(1),
     MED_EXAM_CLASS_CD    VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX AVIATION_DETAILS_PI (LIFE_STYLE_ACTIVITY_RK)
;
CREATE TABLE BARRIER_FEATURE (
     BARRIER_FEATURE_RK   NUMERIC(10)     NOT NULL,
     BARRIER_TYPE_CD      VARCHAR(3),
     UPPER_BARRIER_KIND_CD VARCHAR(3),
     UPPER_BARRIER_VALUE  NUMERIC(18,5),
     UPPER_BARRIER_VALUE_TYPE_CD VARCHAR(3),
     LOWER_BARRIER_KIND_CD VARCHAR(3),
     LOWER_BARRIER_VALUE  NUMERIC(18,5),
     LOWER_BARRIER_VALUE_TYPE_CD VARCHAR(3),
     BARRIER_CASH_REBATE_AMT NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BARRIER_FEATURE_PI (BARRIER_FEATURE_RK)
;
CREATE TABLE BATHROOM_TYPE_DETAILS (
     BATHROOM_TYPE_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     BATHROOM_TYPE_CD     VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     NUM_BATHROOMS        NUMERIC(6),
     CONSTR_QUALITY_CD    VARCHAR(3),
     NUM_ADDITIONAL_FIXTURES NUMERIC(6),
     ESTIMATED_REPL_COST_AMT NUMERIC(18,5),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BATHROOM_TYPE_DETAILS_PI (BATHROOM_TYPE_RK)
;
CREATE TABLE BENEFICIARY (
     BENEFICIARY_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     BENEFICIARY_ID       VARCHAR(32)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BENEFICIARY_PI (BENEFICIARY_RK)
;
CREATE TABLE BENEFICIARY_X_UOE (
     BENEFICIARY_RK       NUMERIC(10)     NOT NULL,
     UOE_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     IRREVOKABLE_IND      CHARACTER(1),
     BENEF_DISTRIBUTION_AMT NUMERIC(18,5),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     RELATIONSHIP_TO_INSURED_CD VARCHAR(3),
     BENEF_DESIGNATION_CD VARCHAR(3),
     INCOME_OPTION_CD     VARCHAR(3),
     BENEF_SEQ_NUM        NUMERIC(2),
     BENEF_SHARE_METHOD_CD VARCHAR(3),
     BENEF_DISTRIBUTION_PCT NUMERIC(9,4),
     PROCEEDS_HOLD_DURATION NUMERIC(9),
     BENEF_CLAIM_PERIOD   NUMERIC(9,4),
     BENEFIT_REDUCTION_PCT NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BENEFICIARY_X_UOE_PI (BENEFICIARY_RK,UOE_RK)
;
CREATE TABLE BENEFIT_PAYOUT_SCHEDULE (
     COVERAGE_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     POLICY_TERM          NUMERIC(9,4),
     BENEFIT_TERM_BREAKUP_CD VARCHAR(3),
     BENEFIT_PCT          NUMERIC(9,4),
     BONUS_AMT            NUMERIC(18,5),
     BENEFIT_AMT_TYPE_CD  VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BENEFIT_PAYOUT_SCHEDULE_PI (COVERAGE_RK)
;
CREATE TABLE BINARY_OPTION_INSTRUMENT (
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     BINARY_OPTION_TYPE_CD VARCHAR(3),
     CASH_PAYOUT_AMT      NUMERIC(18,5),
     PAY_AT_HIT_FLG       CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BINARY_OPTION_INSTRUMENT_PI (VALID_FROM_DTTM,FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE BLDG_IMPROVEMENT_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     EXTR_PAINT_TYPE_CD   VARCHAR(3),
     EXTR_PAINT_YR        NUMERIC(4),
     HEATING_IMPROVEMENT_CD VARCHAR(3),
     HEATING_IMPROVEMENT_YR NUMERIC(4),
     PLUMBING_IMPROVEMENT_CD VARCHAR(3),
     PLUMBING_IMPROVEMENT_YR NUMERIC(4),
     ROOFING_IMPROVEMENT_CD VARCHAR(3),
     ROOFING_IMPROVEMENT_YR NUMERIC(4),
     WIRING_IMPROVEMENT_CD VARCHAR(3),
     WIRING_IMPROVEMENT_YR NUMERIC(4),
     SUBSTANTIAL_IMPROVEMENT_DT DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BLDG_IMPROVEMENT_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE BLDG_OCCUPANCY_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     NUM_UNITS_OWNER_OCCUPIED NUMERIC(6),
     VACANT_UNOCCUPIED_CD VARCHAR(3),
     OCCUPIED_PCT         NUMERIC(9,4),
     AREA_OCCUPIED        NUMERIC(14,4),
     AREA_UNOCCUPIED      NUMERIC(14,4),
     OCCUPANCY_DESC       VARCHAR(255),
     NATURE_BUSINESS_CD   VARCHAR(3),
     OPERATIONS_DESC      VARCHAR(255),
     NUM_EMPLOYEES        NUMERIC(6),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BLDG_OCCUPANCY_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE BLDG_PROTECTION_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     NUM_FIRE_DIV         NUMERIC(6),
     NUM_UNITS_IN_FIRE_DIV NUMERIC(6),
     FIRE_PROTECTION_CLASS_CD VARCHAR(3),
     DISTANCE_TO_FIRE_STATION NUMERIC(14,4),
     DISTANCE_TO_HYDRANT  NUMERIC(14,4),
     FIRE_EXTINGUISHER_IND CHARACTER(1),
     PROTECTION_DEVICE_BURGLAR_IND CHARACTER(1),
     PROTECTION_DEVICE_FIRE_IND CHARACTER(1),
     PROTECTION_DEVICE_SMOKE_IND CHARACTER(1),
     PROTECTION_DEVICE_SPRINKLR_IND CHARACTER(1),
     PROTECTION_CLASS_GRD_CD VARCHAR(3),
     PROTECTION_CLASS_IMPROVED_IND CHARACTER(1),
     DOOR_LOCK_CD         VARCHAR(3),
     SPRINKLERED_PCT      NUMERIC(9,4),
     SOLE_UNIT_IN_FIRE_DIV_IND CHARACTER(1),
     NUM_SMOKE_ALARMS     NUMERIC(6),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BLDG_PROTECTION_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE BOND_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     BOND_INSTRUMENT_TYPE_CD VARCHAR(10),
     REDEMPTION_PRICE_AMT NUMERIC(18,5),
     REDEMPTION_CURRENCY_CD VARCHAR(3),
     SPECIALIZED_LENDING_CD VARCHAR(3),
     CALL_PROTECTION_DT   DATE,
     CONVERTIBLE_FLG      CHARACTER(1),
     PRINCIPAL_EXCHANGE_FLG CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BOND_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE BOND_QUOTE (
     BOND_ID              VARCHAR(32)     NOT NULL,
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     MARKET_DT            DATE,
     RISK_FACTOR_ID       VARCHAR(32),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BOND_QUOTE_PI (BOND_ID,QUOTE_DTTM,MARKET_CD)
;
CREATE TABLE BOND_VOLATILITY_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     ISSUE_CD             VARCHAR(15)     NOT NULL,
     ASK_PRICE_AMT        NUMERIC(18,5),
     BID_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     ASK_VOLATILITY_RT    NUMERIC(11,6),
     BID_VOLATILITY_RT    NUMERIC(11,6),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BOND_VOLATILITY_QUOTE_PI (QUOTE_DTTM,MARKET_CD,ISSUE_CD)
;
CREATE TABLE BUILTINS_DETAILS (
     BUILTINS_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     BUILTINS_CD          VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     CONSTR_QUALITY_CD    VARCHAR(3),
     SURFACE_AREA         NUMERIC(14,4),
     ESTIMATED_REPL_COST_AMT NUMERIC(18,5),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX BUILTINS_DETAILS_PI (BUILTINS_RK)
;
CREATE TABLE BUSINESS_ENTITY (
     BUSINESS_ENTITY_ID   VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP	NOT NULL,
     BUSINESS_ENTITY_DESC VARCHAR(100),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     INTERNAL_ORG_RK      NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP	NOT NULL)
     PRIMARY INDEX BUSINESS_ENTITY_PI (BUSINESS_ENTITY_ID)
;
CREATE TABLE CAL_DATE (
     CALENDAR_DT          DATE     NOT NULL,
     DAY_OF_YEAR_NO       NUMERIC(4),
     WEEK_NO              NUMERIC(4),
     MONTH_NO             NUMERIC(4),
     YEAR_NO              NUMERIC(4),
     DAY_OF_MONTH_NO      NUMERIC(4),
     MONTH_NM             VARCHAR(40),
     DAY_OF_WEEK_NM       VARCHAR(40),
     DAY_OF_WEEK_NO       NUMERIC(2),
     LAST_DAY_OF_MONTH_FLG CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CAL_DATE_PI (CALENDAR_DT)
;
CREATE TABLE CAMPAIGN (
     CAMPAIGN_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CAMPAIGN_CD          VARCHAR(30)     NOT NULL,
     CAMPAIGN_STATUS_CD   VARCHAR(30),
     CAMPAIGN_PRIORITY_CD VARCHAR(30),
     CAMPAIGN_DETAIL_TXT  VARCHAR(255),
     PROGRAM_NM           VARCHAR(40),
     CAMPAIGN_BUDGET_AMT  NUMERIC(18,5),
     TARGET_RESPONSE_PCT  NUMERIC(9,4),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     CAMPAIGN_DESC        VARCHAR(100),
     EVENT_RK             NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CAMPAIGN_PI (EVENT_RK,CAMPAIGN_RK)
;
CREATE TABLE CAPITAL_ALLOCATION (
     CAPITAL_ALLOCATION_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CAPITAL_ALLOCATION_ID VARCHAR(32),
     CAPITAL_ALLOCATION_RT NUMERIC(9,4),
     MATURITY_LENGTH_IN_YEARS_NO NUMERIC(6,2),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CAPITAL_ALLOCATION_PI (CAPITAL_ALLOCATION_RK)
;
CREATE TABLE CAPITAL_COST (
     CAPITAL_COST_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CAPITAL_COST_ID      VARCHAR(32),
     CAPITAL_COST_RT      NUMERIC(9,4),
     MATURITY_LENGTH_IN_YEARS_NO NUMERIC(6,2),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CAPITAL_COST_PI (CAPITAL_COST_RK)
;
CREATE TABLE CARDIAC_MURMUR_DETAILS (
     CONDITION_TYPE_RK    NUMERIC(10)     NOT NULL,
     LOCATION_TC_CD       VARCHAR(3)     NOT NULL,
     TRANSMITTED_IND      CHARACTER(1),
     INTENSITY_GRADE_TC_CD VARCHAR(3),
     QUALITY_TC_CD        VARCHAR(3),
     TIMING_TC_CD         VARCHAR(3),
     AFTER_EXERCISE_DESC  VARCHAR(255),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CARDIAC_MURMUR_DETAILS_PI (CONDITION_TYPE_RK,LOCATION_TC_CD)
;
CREATE TABLE CATASTROPHE (
     CATASTROPHE_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CATASTROPHE_ID       VARCHAR(32),
     CATASTROPHE_TYPE_CD  VARCHAR(3),
     CAT_AGENCY_NM        VARCHAR(40),
     CATASTROPHE_DESC     VARCHAR(255),
     ASSIGNED_DT          DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CATASTROPHE_PI (CATASTROPHE_RK)
;
CREATE TABLE CEDED_LOSS (
     CEDED_LOSS_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CEDED_LOSS_REFERENCE_ID VARCHAR(32)     NOT NULL,
     CEDED_CASE_RESERVE_AMT NUMERIC(18,5),
     CEDED_LAE_CASE_RESERVE_AMT NUMERIC(18,5),
     CEDED_PAID_LOSS_AMT  NUMERIC(18,5),
     CEDED_RECOVERY_AMT   NUMERIC(18,5),
     CEDED_PAID_LAE_AMT   NUMERIC(18,5),
     CEDED_LOSS_STATUS_CD VARCHAR(3),
     CEDED_LOSS_STATUS_REASON_CD VARCHAR(3),
     CEDED_LOSS_STATUS_CHANGE_DT DATE,
     CEDED_LOSS_AMT_CHANGE_DTTM TIMESTAMP,
     ACCIDENT_YR          NUMERIC(4),
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     RI_EXP_RK            NUMERIC(10)     NOT NULL,
     XL_LAYER_RK          NUMERIC(10),
     INCIDENT_RK          NUMERIC(10)     NOT NULL,
     CATASTROPHE_RK       NUMERIC(10),
     LOB_RK               NUMERIC(10)     NOT NULL,
     RI_CONTRACT_SECTION_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXREINSURANCE_CARRIER (CEDED_LOSS_RK)
;
CREATE TABLE CLAIMANT (
     CLAIMANT_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIMANT_ID          VARCHAR(32)     NOT NULL,
     RELATIONSHIP_TO_INSURED_CD VARCHAR(3),
     AUTHORIZED_REP_IND   CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIMANT_PI (CLAIMANT_RK)
;
CREATE TABLE CLAIM_ADMINISTRATOR (
     CLAIM_ADMINISTRATOR_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIM_ADMINISTRATOR_NO VARCHAR(32)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_ADMINISTRATOR_PI (CLAIM_ADMINISTRATOR_RK)
;
CREATE TABLE CLAIM_DRIVER_DETAILS (
     LICENSE_NO           VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LICENSE_TYPE_CD      VARCHAR(3),
     LICENSE_STATUS_CD    VARCHAR(3),
     LICENSED_DT          DATE,
     PURPOSE_USE          VARCHAR(50),
     PERMISSION_IND       CHARACTER(1),
     OPERATOR_AT_FAULT_IND CHARACTER(1),
     AT_FAULT_PCT         NUMERIC(9,4),
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_DRIVER_DETAILS_PI (LICENSE_NO)
;
CREATE TABLE CLAIM_INJURED (
     CLAIM_INJURED_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIM_INJURED_ID     VARCHAR(32),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_INJURED_PI (CLAIM_INJURED_RK)
;
CREATE TABLE CLAIM_ITEM (
     CLAIM_ITEM_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIM_ITEM_NO        VARCHAR(50)     NOT NULL,
     CLAIM_SERVICE_PROVIDER_RK NUMERIC(10)     NOT NULL,
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     ITEM_DESC            VARCHAR(255),
     ITEM_QTY             NUMERIC(6),
     ITEM_PRICE           NUMERIC(18,5),
     ESTIMATED_AMT        NUMERIC(18,5),
     REASON_CD            VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_ITEM_PI (CLAIM_ITEM_RK)
;
CREATE TABLE CLAIM_SERVICE_PROVIDER (
     CLAIM_SERVICE_PROVIDER_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIM_SERVICE_PROVIDER_TYPE_CD VARCHAR(3),
     CLAIM_SERVICE_PROVIDER_NO VARCHAR(32)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_SERVICE_PROVIDER_PI (CLAIM_SERVICE_PROVIDER_RK)
;
CREATE TABLE CLAIM_TRANS (
     CLAIM_TRANS_ID       VARCHAR(32)     NOT NULL,
     CLAIM_RK             NUMERIC(10)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     REFERENCE_NO         VARCHAR(32),
     PAYMENT_METHOD_CD    VARCHAR(3),
     CLAIM_TRANS_TYPE_CD  VARCHAR(3),
     TOTAL_TRANS_AMT      NUMERIC(18,5),
     PAYMENT_DT           DATE,
     TRANS_CURRENCY_CD    VARCHAR(3),
     SERVICE_DURATION     NUMERIC(9,4),
     PAYMENT_DESC         VARCHAR(255),
     CLAIM_SERVICE_PROVIDER_RK NUMERIC(10),
     CLAIMANT_RK          NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_TRANS_PI (CLAIM_TRANS_ID,SOURCE_SYSTEM_CD)
;
CREATE TABLE CLAIM_TRANS_LINE_ITEM (
     CLAIM_TRANS_LINE_ITEM_NO NUMERIC(9)     NOT NULL,
     CLAIM_TRANS_ID       VARCHAR(32)     NOT NULL,
     CLAIM_RK             NUMERIC(10)     NOT NULL,
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     AMT_TYPE_CD          VARCHAR(3),
     LINE_ITEM_TRANS_AMT  NUMERIC(18,5),
     PAYMENT_REASON_CD    VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_TRANS_LINE_ITEM_PI (CLAIM_TRANS_LINE_ITEM_NO,CLAIM_TRANS_ID,CLAIM_RK,CLAIM_UNIT_RK,SOURCE_SYSTEM_CD)
;
CREATE TABLE CLAIM_UNIT (
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIM_RK             NUMERIC(10)     NOT NULL,
     UOE_RK               NUMERIC(10)     NOT NULL,
     CLAIM_UNIT_ESTIMATED_AMT NUMERIC(18,5),
     CLAIM_UNIT_PAID_AMT  NUMERIC(18,5),
     CLAIM_UNIT_EST_EXPENSE_AMT NUMERIC(18,5),
     CLAIM_UNIT_PAID_EXPENSE_AMT NUMERIC(18,5),
     CLAIM_UNIT_STATUS_CD VARCHAR(3),
     RECOVERY_ESTIMATED_AMT NUMERIC(18,5),
     RECOVERY_RECEIVED_AMT NUMERIC(18,5),
     CLAIM_UNIT_CURRENCY_CD VARCHAR(3),
     STATUS_CHANGE_DTTM   TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXCLAIM_UNIT (CLAIM_UNIT_RK)
;
CREATE TABLE CLAIM_UNIT_X_ADMINISTRATOR (
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     CLAIM_ADMINISTRATOR_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ASSIGNED_DT          DATE,
     ROLE_CD              VARCHAR(3),
     PRIMARY_CLAIM_ADMIN_FLG CHARACTER(1)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_UNIT_X_ADMINISTRATOR_PI (CLAIM_UNIT_RK,CLAIM_ADMINISTRATOR_RK)
;
CREATE TABLE CLAIM_UNIT_X_INJURED (
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     CLAIM_INJURED_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ACTIVITIES_DESC      VARCHAR(255),
     WORK_PROCESS_DESC    VARCHAR(255),
     EQUIPMENT_USED_DESC  VARCHAR(255),
     FATALITY_IND         CHARACTER(1),
     PRE_EXISTING_DISABILITY_CD VARCHAR(3),
     INITIAL_TREATMENT_CD VARCHAR(3),
     ICD_DIAGNOSTIC_CD    VARCHAR(3),
     SURGERY_IND          CHARACTER(1),
     OTHER_INSURANCE_IND  CHARACTER(1),
     WHERE_TAKEN_DESC     VARCHAR(255),
     TIME_LOST_PERIOD     NUMERIC(9,4),
     RESTRICTED_WORK_PERIOD NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_UNIT_X_INJURED_PI (CLAIM_UNIT_RK,CLAIM_INJURED_RK)
;
CREATE TABLE CLAIM_UNIT_X_SERVICE_PROVIDER (
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     CLAIM_SERVICE_PROVIDER_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ROLE_CD              VARCHAR(3),
     ASSIGNED_DTTM        TIMESTAMP,
     COMPLETION_DTTM      TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLAIM_UNIT_X_SERVICE_PROVID_PI (CLAIM_UNIT_RK,CLAIM_SERVICE_PROVIDER_RK)
;
CREATE TABLE CLIMBING_DETAILS (
     LIFE_STYLE_ACTIVITY_RK NUMERIC(10)     NOT NULL,
     TYPE_OF_EQUIPMENT    VARCHAR(20),
     LOCATION_OF_LAST_CLIMB VARCHAR(20),
     AVG_CLIMB_DURATION   NUMERIC(9,4),
     AVG_CLIMB_HEIGHT     NUMERIC(14,4),
     AVG_DEGREE_OF_DIFFICULTY_CD VARCHAR(3),
     MAX_CLIMB_HEIGHT_TO_DT DATE,
     GUIDE_USAGE_IND      CHARACTER(1),
     CLIMB_SOLO_IND       CHARACTER(1),
     AVG_PARTY_SIZE       NUMERIC(9),
     BREATHING_APPARATUS_IND CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CLIMBING_DETAILS_PI (LIFE_STYLE_ACTIVITY_RK)
;
CREATE TABLE COINSURANCE_DETAILS (
     POLICY_RK            NUMERIC(10)     NOT NULL,
     ORG_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COINSURANCE_PCT      NUMERIC(9,4),
     COINSURANCE_AMT      NUMERIC(18,5),
     COINSURANCE_TYPE_CD  VARCHAR(3),
     LEAD_INSURER_IND     CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COINSURANCE_DETAILS_PI (POLICY_RK,ORG_RK)
;
CREATE TABLE COL_INDEX (
     INCOME_PAYOUT_RK     NUMERIC(10)     NOT NULL,
     COL_INDEX_CD         VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COL_INDEX_PI (INCOME_PAYOUT_RK,COL_INDEX_CD)
;
CREATE TABLE COMML_DRIVER_DETAILS (
     DRIVER_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COMML_MOTOR_AGR_RK   NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     HIRED_NON_OWNED_IND  CHARACTER(1),
     HIRED_DT             DATE,
     COMML_EXPERIENCE_IN_MTHS NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMML_DRIVER_DETAILS_PI (DRIVER_RK,COMML_MOTOR_AGR_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE COMML_MOTOR_AGREEMENT (
     COMML_MOTOR_AGR_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COMML_MOTOR_AGR_ID   VARCHAR(32)     NOT NULL,
     DRIVER_PHYSICALS_IND CHARACTER(1),
     DRIVER_RECRUITING_METHOD_IND CHARACTER(1),
     DRIVER_TESTING_IND   CHARACTER(1),
     DRIVER_TRAINING_IND  CHARACTER(1),
     HAUL_FOR_OTHERS_IND  CHARACTER(1),
     HIRE_EQUIPMENT_IND   CHARACTER(1),
     INSURING_AGREEMENT_IND CHARACTER(1),
     LEASED_WITH_OPERATORS_IND CHARACTER(1),
     LEASE_VEHS_TO_OTHERS_IND CHARACTER(1),
     LEASED_PCT           NUMERIC(9,4),
     MAX_EXPOSURE_AMT     NUMERIC(18,5),
     MAX_EXPOSURE_LOCATION_AMT NUMERIC(18,5),
     MAX_EXPOSURE_VEH_AMT NUMERIC(18,5),
     NUM_VEHS_OWNED       NUMERIC(6),
     NUM_VEHS_IN_FLEET    NUMERIC(6),
     TARGET_COMMODITIES_IND CHARACTER(1),
     CARRIER_TYPE_CD      VARCHAR(3),
     SHIPPER_TYPE_CD      VARCHAR(3),
     VEH_MAINTENANCE_IND  CHARACTER(1),
     NUM_DAYS             NUMERIC(6),
     NUM_VEHS             NUMERIC(6),
     NUM_INDIVIDUALS_COVERED NUMERIC(6),
     NUM_LICENSED         NUMERIC(6),
     NUM_NOT_LICENSED     NUMERIC(6),
     CONTINUOUS_INSURANCE_CD VARCHAR(3),
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXCOMML_AUTO_SECTION (COMML_MOTOR_AGR_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE COMML_NON_OWNED_DETAILS (
     NON_OWNED_CLASS_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     NON_OWNED_CLASS_CD   VARCHAR(3)     NOT NULL,
     NON_OWNED_GROUP_TYPE_CD VARCHAR(3),
     NUM_NON_OWNED        NUMERIC(6),
     NON_OWNED_PCT        NUMERIC(9,4),
     INDIVIDUAL_LIAB_FOR_EMP_IND CHARACTER(1),
     VOLUNTEER_INDIVIDUAL_LIAB_IND CHARACTER(1),
     SOCIAL_SERVICE_AGENCY_IND CHARACTER(1),
     COMML_MOTOR_AGR_RK   NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMML_NON_OWNED_DETAILS_PI (NON_OWNED_CLASS_RK)
;
CREATE TABLE COMML_PROP_CONSTR_DETAILS (
     COMML_PROP_CONSTR_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CONSTR_CD            VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     CONSTR_DESC          VARCHAR(255),
     INSURER_CONSTR_CLASS_CD VARCHAR(3),
     CONSTR_BEGAN_DT      DATE,
     CONSTR_EST_END_DT    DATE,
     CONSTR_COST_AMT      NUMERIC(18,5),
     BUILT_YR             NUMERIC(4),
     FOUNDATION_CD        VARCHAR(3),
     BLDG_AREA            NUMERIC(14,4),
     NUM_STORIES          NUMERIC(6),
     NUM_UNITS            NUMERIC(6),
     EARTHQUAKE_BLDG_GROUND_CD VARCHAR(3),
     ROOFING_MATERIAL     VARCHAR(50),
     HURRICANE_RESISTIVE_GLASS_IND CHARACTER(1),
     EARTHQUAKE_BLDG_CLASS_CD VARCHAR(3),
     EARTHQUAKE_RETROFIT_CD VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMML_PROP_CONSTR_DETAILS_PI (COMML_PROP_CONSTR_RK)
;
CREATE TABLE COMML_PROP_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBJECT_INSURANCE_CD VARCHAR(3),
     PROPERTY_AGR_RK      NUMERIC(10)     NOT NULL,
     CLASS_SPECIFIC_RATED_CD VARCHAR(3),
     CLASS_CD             VARCHAR(3),
     FLOOR_AREA           NUMERIC(14,4),
     SUBJECT_ID           VARCHAR(32)     NOT NULL,
     ITEM_DESC            VARCHAR(255),
     ITEM_VALUE_AMT       NUMERIC(18,5),
     VALUATION_CD         VARCHAR(3),
     AGREED_VALUE_IND     CHARACTER(1),
     MANUFACTURING_AREA   NUMERIC(14,4),
     MERCANTILE_AREA      NUMERIC(14,4),
     BUSINESS_INCOME_TYPE_CD VARCHAR(3),
     BLANKET_NO           NUMERIC(9),
     VALUE_REPORTING_IND  CHARACTER(1),
     LOCATION_RK          NUMERIC(10),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     APPLICATION_RK       NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMML_PROP_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE COMML_VEHICLE_DETAILS (
     VEHICLE_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VEHICLE_NO           VARCHAR(32)     NOT NULL,
     FLEET_IND            CHARACTER(1),
     LEASED_AMT           NUMERIC(18,5),
     DURATION_VEH_LEASED  NUMERIC(9,4),
     MOTOR_CARRIER_ACT_IND CHARACTER(1),
     NEAR_ZONE_CD         VARCHAR(3),
     NEW_VEH_IND          CHARACTER(1),
     PRIMARY_CLASS_CD     VARCHAR(3),
     RADIUS_USE           NUMERIC(14,4),
     RATING_CREDIT_CD     VARCHAR(3),
     SEATING_CAPACITY     NUMERIC(9),
     LOAD_CAPACITY        NUMERIC(14,4),
     SECONDARY_CLASS_CD   VARCHAR(3),
     SELF_PROPELLED_VEH_IND CHARACTER(1),
     SPECIAL_CLASS_CD     VARCHAR(3),
     SPECIAL_USE_CD       VARCHAR(3),
     VEH_ALTERED_IND      CHARACTER(1),
     VEH_LEASED_CD        VARCHAR(3),
     VEH_USE_CD           VARCHAR(3),
     ZONE_COMBINATION_CD  VARCHAR(3),
     REPLACED_VEH_IDENTIFICATION_NO VARCHAR(32),
     COMML_MOTOR_AGR_RK   NUMERIC(10)     NOT NULL,
     FLEET_RK             NUMERIC(10),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     APPLICATION_RK       NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXCOMML_VEHICLE (VEHICLE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE COMMODITY_CODE (
     COMMODITY_CD         VARCHAR(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     COMMODITY_DESC       VARCHAR(200),
     PARENT_COMMODITY_CD  VARCHAR(10),
     COMMODITY_TYPE_CD    VARCHAR(10),
     COMMODITY_UOM_CD     VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMMODITY_CODE_PI (COMMODITY_CD)
;
CREATE TABLE COMMODITY_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     COMMODITY_CD         VARCHAR(10),
     COMMODITY_INST_TYPE_CD VARCHAR(3),
     COMMODITY_UOM_CD     VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMMODITY_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE COMMODITY_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     COMMODITY_CD         VARCHAR(10)     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     MARKET_DT            DATE,
     RISK_FACTOR_ID       VARCHAR(32),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMMODITY_QUOTE_PI (QUOTE_DTTM,MARKET_CD,COMMODITY_CD)
;
CREATE TABLE COMMODITY_TYPE (
     COMMODITY_TYPE_CD    VARCHAR(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     COMMODITY_TYPE_DESC  VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMMODITY_TYPE_PI (COMMODITY_TYPE_CD)
;
CREATE TABLE COMMODITY_VOLATILITY_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     COMMODITY_CD         VARCHAR(10)     NOT NULL,
     ASK_PRICE_AMT        NUMERIC(18,5),
     BID_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     ASK_VOLATILITY_RT    NUMERIC(11,6),
     BID_VOLATILITY_RT    NUMERIC(11,6),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMMODITY_VOLATILITY_QUOTE_PI (QUOTE_DTTM,MARKET_CD,COMMODITY_CD)
;
CREATE TABLE COMMUNICATION (
     COMMUNICATION_CD     VARCHAR(30)     NOT NULL,
     CAMPAIGN_RK          NUMERIC(10)     NOT NULL,
     COMMUNICATION_TYPE_CD VARCHAR(30),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     COMMUNICATION_NM     VARCHAR(40),
     COMMUNICATION_PRIORITY_CD VARCHAR(30),
     COMMUNICATION_DETAILS_TXT VARCHAR(255),
     MEDIA_TYPE_CD        VARCHAR(30),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMMUNICATION_PI (COMMUNICATION_CD,CAMPAIGN_RK)
;
CREATE TABLE COMPETITION_DETAILS (
     LIFE_STYLE_ACTIVITY_RK NUMERIC(10)     NOT NULL,
     COMPETITION_VEH_MODEL VARCHAR(50),
     COMPETITION_VEH_MAKE VARCHAR(50),
     ENGINE_MAKE          VARCHAR(50),
     ENGINE_MODEL         VARCHAR(50),
     ENGINE_SIZE          NUMERIC(14,4),
     HP                   NUMERIC(14,4),
     CLASS_OF_COMPETITION_CD VARCHAR(3),
     CHANGE_CLASS_OF_COMP_IND CHARACTER(1),
     VEH_USAGE_IND        CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMPETITION_DETAILS_PI (LIFE_STYLE_ACTIVITY_RK)
;
CREATE TABLE COMPLAINT (
     COMPLAINT_RK         NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COMPLAINT_ID         VARCHAR(32)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     COMPLAINT_TYPE_CD    VARCHAR(3),
     COMPLAINT_REASON_CD  VARCHAR(3),
     COMPLAINT_DETAIL_TXT VARCHAR(255),
     COMPLAINT_CHANNEL_CD VARCHAR(3),
     COMPLAINT_SEVERITY_CD VARCHAR(3),
     COMPLAINT_OPEN_DTTM  TIMESTAMP,
     COMPLAINT_CLOSE_DTTM TIMESTAMP,
     COMPLAINT_STATUS_CD  VARCHAR(3),
     STATUS_CHANGE_DT     DATE,
     STATUS_REASON_CD     VARCHAR(3),
     COMPLAINT_RESOLUTION_CD VARCHAR(3),
     SLA_DURATION_HOURS   NUMERIC(4,2),
     RESOLUTION_DURATION_HOURS NUMERIC(4,2),
     EMPLOYEE_RK          NUMERIC(10),
     CUSTOMER_RK          NUMERIC(10),
     CAPTURED_COST_AMT    NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COMPLAINT_PI (COMPLAINT_RK)
;
CREATE TABLE CONTRACT_ITEM (
     CONTRACT_ITEM_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SERIAL_NO            VARCHAR(50)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     ITEM_TYPE_CD         VARCHAR(3),
     MANUFACTURER_NM      VARCHAR(50),
     MANUFACTURE_METHOD_CD VARCHAR(3),
     CERTIFYING_ENTITY_CD VARCHAR(3),
     MODEL_NM             VARCHAR(50),
     MODEL_YR             NUMERIC(4),
     ITEM_DESC            VARCHAR(255),
     BODY_TYPE_CD         VARCHAR(3),
     CHASSIS_SERIAL_NO    VARCHAR(50),
     ENGINE_SERIAL_NO     VARCHAR(50),
     TRANSMISSION_SERIAL_NO VARCHAR(50),
     LEASED_IND           CHARACTER(1),
     REGISTRATION_ID      VARCHAR(32),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CONTRACT_ITEM_PI (CONTRACT_ITEM_RK)
;
CREATE TABLE CONTRACT_SECTION_X_RI_CARRIER (
     RI_CARRIER_RK        NUMERIC(10)     NOT NULL,
     RI_CONTRACT_SECTION_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COMMUTATION_DT       DATE,
     SHARE_PCT            NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CONTRACT_SECTION_X_RI_CARRI_PI (RI_CARRIER_RK,RI_CONTRACT_SECTION_RK)
;
CREATE TABLE CONVERSION_SCHEDULE (
     CONVERSION_SCHEDULE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CONVERSION_SCHEDULE_ID VARCHAR(32),
     CONVERSION_SCHEDULE_TYPE_CD VARCHAR(3),
     STOCK_PRICE_DT       DATE,
     STOCK_PRICE_AMT      NUMERIC(18,5),
     CONVERSION_VALUE     NUMERIC(18,5),
     CONVERSION_VALUE_TYPE_CD VARCHAR(3),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CONVERSION_SCHEDULE_PI (CONVERSION_SCHEDULE_RK)
;
CREATE TABLE CONVERTIBLE_BOND_FEATURE (
     CONVERTIBLE_TYPE_CD  VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CONVERSION_SCHEDULE_FLG CHARACTER(1),
     CONVERSION_VALUE     NUMERIC(18,5),
     CONVERTIBLE_STYLE_CD VARCHAR(3),
     CONVERSION_VALUE_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CONVERTIBLE_BOND_FEATURE_PI (CONVERTIBLE_TYPE_CD,FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE CORE_BANKING_ACCOUNT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CORE_ACCOUNT_TYPE_CD VARCHAR(3),
     CORE_ACCOUNT_STATUS_CD VARCHAR(3),
     AUTHORIZED_USERS_CNT NUMERIC(6),
     APR_RT               NUMERIC(9,4),
     INTEREST_PERIOD_CNT  NUMERIC(6),
     INTEREST_TIER_NO     NUMERIC(5),
     ROLLED_OVER_FLG      CHARACTER(1),
     WITHDRAWAL_PRIVILEGES_FLG CHARACTER(1),
     WITHDRAWAL_NOTICE_DAYS_CNT NUMERIC(6),
     OVERDRAFT_PRIVILEGES_FLG CHARACTER(1),
     OVERDRAFT_FLG        CHARACTER(1),
     OVERDRAFT_LIMIT_AMT  NUMERIC(18,5),
     OVERDRAFT_CHARGE_AMT NUMERIC(18,5),
     OVERDRAFT_CHARGE_NOTIF_DT DATE,
     CHECKING_MAIN_FLG    CHARACTER(1),
     CHECKING_BOOK_FLG    CHARACTER(1),
     CHECKING_BOOK_DT     DATE,
     MANDATE_SINGLE_LIMIT_AMT NUMERIC(18,5),
     TERM                 NUMERIC(6),
     TERM_TIME_UOM_CD     VARCHAR(3),
     WITHDRAWL_NOTICE_FLG CHARACTER(1),
     RECURRING_DEPOSIT_PLAN_FLG CHARACTER(1),
     STANDING_ORDERS_CNT  NUMERIC(6),
     DIRECT_DEBITS_CNT    NUMERIC(6),
     ADDITIONAL_SERVICES_FLG CHARACTER(1),
     OVERDRAFT_CURRENT_AMT NUMERIC(18,5),
     PREFERRED_DEPOSIT_CHANNEL_CD VARCHAR(3),
     PREF_WITHDRAWAL_CHANNEL_CD VARCHAR(3),
     PAYMENT_AMT          NUMERIC(18,5),
     PAYMENT_TIME_FREQUENCY_CD VARCHAR(3),
     INTERNAL_DIRECT_DEP_FLG CHARACTER(1),
     ACCOUNT_RENEWAL_TYPE_CD VARCHAR(3),
     CHG_DIRECT_DEPOSIT_MTH_NO NUMERIC(2),
     SAFE_DEPOSIT_FLG     CHARACTER(1),
     ACCOUNT_ID           VARCHAR(32),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     RENEWAL_DT           DATE,
     BASE_APR_RT          NUMERIC(9,4),
     OVERDRAFT_PROTECTION_FLG CHARACTER(1),
     ACTIVE_DIRECT_DEBITS_CNT NUMERIC(6),
     PROTECTION_INS_STATUS_CD VARCHAR(3),
     PROTECTION_INS_FLG   CHARACTER(1),
     OVERDRAFT_LIMIT_DT   DATE,
     MIN_ACCOUNT_OPENING_AMT NUMERIC(18,5),
     ACTUAL_ACCOUNT_OPENING_AMT NUMERIC(18,5),
     REQUIRED_MIN_BALANCE_AMT NUMERIC(18,5),
     LINKED_ACCOUNT_FLG   CHARACTER(1),
     LINKED_DEPOSIT_ACCOUNT_FLG CHARACTER(1),
     STEP_UP_FACILITY_USED_FLG CHARACTER(1),
     CALLABLE_FACILITY_USED_FLG CHARACTER(1),
     INTEREST_PAYOUT_FLG  CHARACTER(1),
     MATURITY_DT          DATE,
     PAYMENT_METHOD_CD    VARCHAR(3),
     FIRST_PAYMENT_DT     DATE,
     LAST_PAYMENT_DT      DATE,
     CURRENT_APR_SET_DT   DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CORE_BANKING_ACCOUNT_PI (ACCOUNT_RK)
;
CREATE TABLE CORRELATION_MATRIX (
     CORRELATION_MATRIX_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CORRELATION_MATRIX_ID VARCHAR(32),
     CORRELATION_MATRIX_TYPE_CD VARCHAR(3),
     MATRIX_STORAGE_TYPE_CD VARCHAR(3),
     DIMENSION_SIZE_CNT   NUMERIC(6),
     CORRELATION_PERIOD_UOM_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CORRELATION_MATRIX_PI (CORRELATION_MATRIX_RK)
;
CREATE TABLE CORRELATION_MATRIX_ELEMENT (
     CORRELATION_MATRIX_RK NUMERIC(10)     NOT NULL,
     VAR1_NM              VARCHAR(32)     NOT NULL,
     VAR2_NM              VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CORRELATION_VALUE    NUMERIC(18,5),
     LOCATOR_TYPE_CD      VARCHAR(3),
     RISK_FACTOR_ID       VARCHAR(32),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CORRELATION_MATRIX_ELEMENT_PI (CORRELATION_MATRIX_RK,VAR1_NM,VAR2_NM)
;
CREATE TABLE COST_CENTER (
     COST_CENTER_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COST_CENTER_ID       VARCHAR(32)     NOT NULL,
     COST_CENTER_NM       VARCHAR(50),
     COST_CENTER_DESC     VARCHAR(255),
     RESPONSIBLE_EMPLOYEE_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COST_CENTER_PI (COST_CENTER_RK)
;
CREATE TABLE COST_CENTER_ASSOC (
     COST_CENTER_RK       NUMERIC(10)     NOT NULL,
     PARENT_COST_CENTER_RK NUMERIC(10)     NOT NULL,
     COST_CENTER_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COST_CENTER_ASSOC_PI (COST_CENTER_RK,PARENT_COST_CENTER_RK,COST_CENTER_ASSOC_TYPE_CD)
;
CREATE TABLE COUNTERPARTY (
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COUNTERPARTY_ID      VARCHAR(32),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     COUNTERPARTY_ROLE_CD VARCHAR(3),
     COUNTERPARTY_GROUP_ID VARCHAR(32),
     COUNTERPARTY_GROUP_PARENT_FLG CHARACTER(1),
     COUNTERPARTY_TYPE_CD VARCHAR(3),
     REGLTRY_COUNTERPARTY_TYPE_CD VARCHAR(3)     NOT NULL,
     ECONOMIC_SECTOR_CD   VARCHAR(3),
     HIGH_RISK_CATEGORY_FLG CHARACTER(1),
     COUNTERPARTY_LEGAL_TYPE_CD VARCHAR(3),
     CORE_MKT_PARTICIPANT_FLG CHARACTER(1),
     RISK_WEIGHT_PCT      NUMERIC(9,4),
     COUNTERPARTY_RLN_TYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     DOMESTIC_CURRENCY_CD VARCHAR(3),
     ELIG_CCR_CENTRAL_CPTY_FLG CHARACTER(1),
     SOLVENCY_RATIO_PCT   NUMERIC(9,4),
     CPTY_INTERNAL_RPT_CATEGORY_CD VARCHAR(3),
     MIN_CAPITAL_REQ_FLG  CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_PI (COUNTERPARTY_RK)
;
CREATE TABLE COUNTERPARTY_ASSOC (
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     ASSOCIATE_COUNTERPARTY_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COUNTERPARTY_ASSOC_TYPE_CD VARCHAR(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_ASSOC_PI (COUNTERPARTY_RK,ASSOCIATE_COUNTERPARTY_RK,COUNTERPARTY_ASSOC_TYPE_CD)
;
CREATE TABLE COUNTERPARTY_CREDIT_ASSESSMENT (
     ASSESSMENT_DT        DATE     NOT NULL,
     ASSESSMENT_RESULT_TYPE_CD VARCHAR(3)     NOT NULL,
     CURRENCY_CD          VARCHAR(3)     NOT NULL,
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     ASSESSMENT_MODEL_RK  NUMERIC(10)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10),
     OVERRIDE_RATING_FLG  CHARACTER(1),
     ASSESSMENT_RESULT_RT NUMERIC(9,4),
     ASSESS_CHANGE_REASON_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     DOMESTIC_CURR_ASSESSMENT_FLG CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATING_GRADE_PI (ASSESSMENT_DT,ASSESSMENT_RESULT_TYPE_CD,CURRENCY_CD,COUNTERPARTY_RK,ASSESSMENT_MODEL_RK)
;
CREATE TABLE COUNTERPARTY_CREDIT_BEHAVIOR (
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     KNOWN_SINCE_DT       DATE,
     ECONOMIC_SECTOR_CD   VARCHAR(3),
     CURRENT_ASSETS_AMT   NUMERIC(18,5),
     TOTAL_ASSETS_AMT     NUMERIC(18,5),
     CURRENT_LIABILITIES_AMT NUMERIC(18,5),
     TOTAL_LIABILITIES_AMT NUMERIC(18,5),
     CURRENT_RATIO_RT     NUMERIC(9,4),
     SHAREHOLDERS_FUNDS_AMT NUMERIC(18,5),
     EBIT_AMT             NUMERIC(18,5),
     RETURN_ON_ASSETS_AMT NUMERIC(18,5),
     RETURN_ON_EQUITY_AMT NUMERIC(18,5),
     RETURN_ON_COMMON_EQUITY_AMT NUMERIC(18,5),
     CAPITAL_ADEQUACY_RT  NUMERIC(9,4),
     CURRENCY_CD          VARCHAR(3),
     STATE_REGION_CD      VARCHAR(4),
     COUNTY_NM            VARCHAR(40),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_CREDIT_BEHAVIO_PI (COUNTERPARTY_RK)
;
CREATE TABLE COUNTERPARTY_INSURANCE (
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     INSURED_DT           DATE     NOT NULL,
     INSURED_AMT          NUMERIC(18,5)     NOT NULL,
     INSURANCE_TYPE_CD    VARCHAR(3)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_INSURANCE_PI (COUNTERPARTY_RK,INSURED_DT,INSURED_AMT,INSURANCE_TYPE_CD)
;
CREATE TABLE COUNTERPARTY_X_CR_MITIGANT (
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     CREDIT_RISK_MITIGANT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CR_MITIGANT_REL_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_X_CR_MITIGANT_PI (COUNTERPARTY_RK,CREDIT_RISK_MITIGANT_RK,CR_MITIGANT_REL_TYPE_CD)
;
CREATE TABLE COUNTERPARTY_X_CUSTOMER (
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_X_CUSTOMER_PI (COUNTERPARTY_RK,CUSTOMER_RK)
;
CREATE TABLE COUNTERPARTY_X_EXTERNAL_ORG (
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     EXTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_X_EXTERNAL_ORG_PI (COUNTERPARTY_RK,EXTERNAL_ORG_RK)
;
CREATE TABLE COUNTERPARTY_X_INTERNAL_ORG (
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     INTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_X_INTERNAL_ORG_PI (COUNTERPARTY_RK,INTERNAL_ORG_RK)
;
CREATE TABLE COUNTERPARTY_X_SEGMENT (
     SEGMENT_RK           NUMERIC(10)     NOT NULL,
     COUNTERPARTY_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTERPARTY_X_SEGMENT_PI (SEGMENT_RK,COUNTERPARTY_RK)
;
CREATE TABLE COUNTRY (
     COUNTRY_CD           VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     COUNTRY_DESC         VARCHAR(100),
     COUNTRY_REGION_DESC  VARCHAR(100),
     COUNTRY_REGION_CD    VARCHAR(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTRY_PI (COUNTRY_CD)
;
CREATE TABLE COUNTRY_EXTERNAL_DATA (
     FROM_DT              DATE     NOT NULL,
     COUNTRY_CD           VARCHAR(3)     NOT NULL,
     TO_DT                DATE,
     INFLATION_RT         NUMERIC(9,4),
     EMPLOYMENT_GROWTH_RT NUMERIC(9,4),
     ANNUAL_GDP_GROWTH_RT NUMERIC(9,4),
     POPULATION_GROWTH_RT NUMERIC(9,4),
     AVG_PERSONAL_INCOME_GROWTH_RT NUMERIC(9,4),
     HOUSE_PRICE_INDEX_RT NUMERIC(9,4),
     UNEMPLOYMENT_RT      NUMERIC(9,4),
     TREASURY_10_YR_RT    NUMERIC(9,4),
     TREASURY_1_YEAR_RT   NUMERIC(9,4),
     CASH_FLOW_DISCOUNT_RT NUMERIC(9,4),
     CONSUMER_PRICE_INDEX_RT NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTRY_EXTERNAL_DATA_PI (FROM_DT,COUNTRY_CD)
;
CREATE TABLE COUNTY (
     STATE_REGION_CD      VARCHAR(4)     NOT NULL,
     COUNTY_NM            VARCHAR(40)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     COUNTY_DESC          VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL)
     PRIMARY INDEX COUNTY_PI (STATE_REGION_CD,COUNTY_NM)
;
CREATE TABLE COVERAGE (
     COVERAGE_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COVERAGE_CD          VARCHAR(3)     NOT NULL,
     COVERAGE_TYPE_CD     VARCHAR(3),
     COVERAGE_DESC        VARCHAR(100),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COVERAGE_PI (COVERAGE_RK)
;
CREATE TABLE COVERAGE_DETAILS (
     COVERAGE_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COVERAGE_NO          VARCHAR(32)     NOT NULL,
     COVERAGE_DESC        VARCHAR(100),
     BASE_COVERAGE_INDICATOR_CD VARCHAR(3),
     RIDER_TYPE_CD        VARCHAR(3),
     COVERAGE_TYPE_CD     VARCHAR(3),
     DB_OPT_CHANGES_CD    VARCHAR(3),
     SALE_EFFECTIVE_DT    DATE,
     SALE_EXPIRATION_DT   DATE,
     PARTICIPATING_IND    CHARACTER(1),
     VALUE_PER_UNIT       NUMERIC(18,5),
     MAX_MULTI_LIVES      NUMERIC(14,4),
     MATURITY_AGE         NUMERIC(3),
     MAX_FLAT_EXTRA       NUMERIC(18,5),
     TOTAL_DISB_PCT       NUMERIC(9,4),
     PARTIAL_DISB_PCT     NUMERIC(9,4),
     DISB_DEATH_BENEFIT_ELIG_PERIOD NUMERIC(9,4),
     DISB_PAYOUT_INDEX_FREQ_CD VARCHAR(3),
     DISB_PAYOUT_INDEX_METHOD_CD VARCHAR(3),
     DISB_PAYOUT_INDEX_RT NUMERIC(9,4),
     STATUTORY_CURVE_GROUP_REF_ID VARCHAR(32),
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXCOVERAGE_DETAILS (COVERAGE_RK)
;
CREATE TABLE COVERAGE_OPTIONS_BENEFITS (
     OPTION_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRODUCT_CD           VARCHAR(3)     NOT NULL,
     PLAN_NM              VARCHAR(40),
     COVERAGE_RK          NUMERIC(10)     NOT NULL,
     SALE_EFFECTIVE_DT    DATE,
     SALE_EXPIRATION_DT   DATE,
     COVERAGE_AMT_CHANGES_CD VARCHAR(3),
     COVERAGE_AMT_MODULUS_FACTOR NUMERIC(18,5),
     MAX_AMT_OF_PARENT    NUMERIC(18,5),
     MIN_AMT_OF_PARENT    NUMERIC(18,5),
     MIN_RATIO_TO_PARENT  NUMERIC(14,4),
     MAX_RATIO_TO_PARENT  NUMERIC(14,4),
     VALUE_PER_UNIT       NUMERIC(18,5),
     MATURITY_AGE         NUMERIC(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COVERAGE_OPTIONS_BENEFITS_PI (OPTION_RK)
;
CREATE TABLE COVERED_PERILS (
     UOE_RK               NUMERIC(10)     NOT NULL,
     PERIL_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX COVERED_PERILS_PI (UOE_RK,PERIL_RK)
;
CREATE TABLE CREDIT_CARD_ACCOUNT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CREDIT_STATUS_CD     VARCHAR(3),
     CARD_EXPIRATION_DT   DATE,
     CARD_ISSUE_DT        DATE,
     CARD_REISSUE_DT      DATE,
     CARD_CANCEL_DT       DATE,
     CARD_CANCEL_REASON_CD VARCHAR(3),
     CARD_LOSS_DT         DATE,
     CARD_LOSS_AMT        NUMERIC(18,5),
     CREDIT_CYCLE_DAY_NO  NUMERIC(2),
     BASE_APR_RT          NUMERIC(9,4),
     APR_RT               NUMERIC(9,4),
     BALANCE_TRANSFER_RT  NUMERIC(9,4),
     CASH_ADVANCE_RT      NUMERIC(9,4),
     PURCHASE_RT          NUMERIC(9,4),
     INITIAL_LIMIT_AMT    NUMERIC(18,5),
     CURRENT_LIMIT_AMT    NUMERIC(18,5),
     CURRENT_LIMIT_DT     DATE,
     PROVISIONAL_CREDIT_LIMIT_AMT NUMERIC(18,5),
     PROV_CREDIT_LIMIT_OPEN_DT DATE,
     PROV_CREDIT_LIMIT_CLOSE_DT DATE,
     PAYMENT_METHOD_CD    VARCHAR(3),
     COLLECTIONS_STATUS_CD VARCHAR(3),
     CREDIT_PAYMENT_PROTECTION_DT DATE,
     CARD_PROTECTION_INS_CD VARCHAR(3),
     PROTECTION_INS_STATUS_CD VARCHAR(3),
     PROTECTION_INS_DT    DATE,
     PAYMENT_PROTECT_STATUS_CD VARCHAR(3),
     CREDIT_PAYMENT_PROTECTION_CD VARCHAR(3),
     CHARGE_OFF_DT        DATE,
     CHARGE_OFF_AMT       NUMERIC(18,5),
     OPEN_TO_BUY_AMT      NUMERIC(18,5),
     OPEN_TO_BUY_PCT      NUMERIC(9,4),
     BUREAU_CLASS_CD      VARCHAR(3),
     MONTHS_SINCE_AT_BUREAU_CNT NUMERIC(6),
     INCENTIVE_TYPE_CD    VARCHAR(3),
     INCENTIVE_END_DT     DATE,
     AUTO_PAY_FLG         CHARACTER(1),
     KEY_AUTO_DEBIT_ACCOUNT_NO VARCHAR(20),
     ACCOUNT_RENEWAL_TYPE_CD VARCHAR(3),
     CARD_PAYMENT_TYPE_CD VARCHAR(3),
     TRAVEL_MILES_PGRM_FLG CHARACTER(1),
     BONUS_POINT_PGRM_FLG CHARACTER(1),
     RENEWAL_FEE_DT       DATE,
     MAX_DEBT_DT          DATE,
     ADDITIONAL_CARD_CNT  NUMERIC(6),
     INSURANCE_AMT        NUMERIC(18,5),
     CREDIT_LINE_USED_RNG_CD VARCHAR(3),
     CASH_CREDIT_LINE_AMT NUMERIC(18,5),
     MAX_LATE_DAY_CNT     NUMERIC(6),
     CREDIT_DAYS_CNT      NUMERIC(6),
     BALANCE_TRANSFER_FLG CHARACTER(1),
     ACCOUNT_ID           VARCHAR(32),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     CREDIT_CARD_ACCOUNT_TYPE_CD VARCHAR(3),
     OFFSET_ACCOUNT_FLG   CHARACTER(1),
     REWARD_PROGRAM_FLG   CHARACTER(1),
     PAYMENT_PROTECTION_FLG CHARACTER(1),
     ACTIVE_DIRECT_DEBITS_CNT NUMERIC(6),
     RENEWAL_DT           DATE,
     CASH_BACK_FLG        CHARACTER(1),
     CASH_BACK_PCT        NUMERIC(9,4),
     FINANCE_CHARGE_FLG   CHARACTER(1),
     OFF_BALANCE_SHEET_TYPE_CD VARCHAR(3),
     CURRENT_APR_SET_DT   DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_CARD_ACCOUNT_PI (ACCOUNT_RK)
;
CREATE TABLE CREDIT_DERIVATIVE_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CREDIT_DERIVATIVE_TYPE_CD VARCHAR(3),
     N_TH_TO_DEFAULT_PROTECTION_NO NUMERIC(3),
     CONTRACT_PRICE_AMT   NUMERIC(18,5),
     ACCRUAL_PAYMENTS_FLG CHARACTER(1),
     BASKET_UNDERLYING_INSTR_CNT NUMERIC(6),
     CONTRACT_PER_ANNUM_PREMIUM_RT NUMERIC(9,4),
     DIGITAL_PAYMENT_FLG  CHARACTER(1),
     WEIGHTED_AVG_LGD_PCT NUMERIC(9,4),
     CORRELATION_MATRIX_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_DERIVATIVE_INSTRUMEN_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE CREDIT_DERIVATIVE_INSTR_QUOTE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_DERIVATIVE_INSTR_QUO_PI (FINANCIAL_INSTRUMENT_RK,QUOTE_DTTM)
;
CREATE TABLE CREDIT_DERIV_CR_MITIGANT (
     CREDIT_RISK_MITIGANT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3),
     FIRST_TO_DEFAULT_PROT_FLG CHARACTER(1),
     HOLDINGS_NO          NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_DERIV_CR_MITIGANT_PI (CREDIT_RISK_MITIGANT_RK)
;
CREATE TABLE CREDIT_FACILITY (
     CREDIT_FACILITY_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COVERED_BY_CREDIT_FACILITY_RK NUMERIC(10),
     EFFECTIVE_FROM_DT    DATE,
     EXPIRATION_DT        DATE,
     CREDIT_FACILITY_ID   VARCHAR(32),
     CURRENCY_CD          VARCHAR(3),
     LIMIT_AMT            NUMERIC(18,5),
     IN_DEFAULT_FLG       CHARACTER(1),
     SPECIALIZED_LENDING_CD VARCHAR(3),
     SENIORITY_CD         VARCHAR(3),
     OFF_BALANCE_SHEET_TYPE_CD VARCHAR(3),
     REGULATORY_PRODUCT_CD VARCHAR(3),
     CREDIT_FACILITY_TYPE_CD VARCHAR(3),
     COMMITMENT_TYPE_CD   VARCHAR(3),
     HAIRCUT_VALUE_PCT    NUMERIC(9,4),
     EXPECTED_LOSS_PCT    NUMERIC(9,4),
     REMARGINING_DAYS_CNT NUMERIC(6),
     HOLDING_PERIOD_DAYS_CNT NUMERIC(6),
     RISK_WEIGHT_PCT      NUMERIC(9,4),
     HAIRCUT_SET_ID       VARCHAR(32),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     GL_ACCOUNT_RK        NUMERIC(10),
     EFFECTIVE_MATURITY_YEAR_NO NUMERIC(7,3),
     FINANCIAL_FUND_RK    NUMERIC(10),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     EXPOSURE_AT_DEFAULT_AMT NUMERIC(18,5),
     ADJUSTMENT_TO_EXPOSURE_AMT NUMERIC(18,5),
     REVOLVING_END_DT     DATE,
     RESETS_TYPE_CD       VARCHAR(3),
     LAST_RESET_DT        DATE,
     RESETS_PER_ANNUM_NO  NUMERIC(5),
     SPREAD_RT            NUMERIC(9,4),
     DISCOUNT_SPREAD_RT   NUMERIC(9,4),
     INITIAL_CONTRACT_RT  NUMERIC(9,4),
     FIRST_RESET_DT       DATE,
     EXERCISE_TYPE_CD     VARCHAR(3),
     EXERCISE_DT          DATE,
     INTERNAL_REPORTING_CATEGORY_CD VARCHAR(3),
     PORTFOLIO_ID         VARCHAR(32),
     COUNTERPARTY_RK      NUMERIC(10),
     COVER_SECURITIZATION_POOL_RK NUMERIC(10),
     OWNED_BY_INTERNAL_ORG_RK NUMERIC(10),
     NETTING_SET_RK       NUMERIC(10),
     RATE_POLICY_RK       NUMERIC(10),
     CAPITAL_ALLOCATION_RK NUMERIC(10),
     CAPITAL_COST_RK      NUMERIC(10),
     SEGMENT_RK           NUMERIC(10),
     CREDIT_FACILITY_GROUP_RK NUMERIC(10),
     EXPENSE_ALLOCATION_RK NUMERIC(10),
     LIQUIDITY_CATEGORY_TYPE_CD VARCHAR(3),
     RECEIVABLES_POOL_RK  NUMERIC(10),
     SECURITIZATION_POOL_RK NUMERIC(10),
     CIC_CD               VARCHAR(4),
     UNWIND_TRIGGER_EVENT_TYPE_CD VARCHAR(3),
     UNWIND_MAX_LOSS_AMT  NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_FACILITY_PI (CREDIT_FACILITY_RK)
;
CREATE TABLE CREDIT_FACILITY_CREDIT_ASSESS (
     ASSESSMENT_DT        DATE     NOT NULL,
     ASSESSMENT_RESULT_TYPE_CD VARCHAR(3)     NOT NULL,
     CREDIT_FACILITY_RK   NUMERIC(10)     NOT NULL,
     ASSESSMENT_MODEL_RK  NUMERIC(10)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10),
     OVERRIDE_RATING_FLG  CHARACTER(1),
     ASSESSMENT_RESULT_RT NUMERIC(9,4),
     CR_MITIGANT_ADJUSTED_FLG CHARACTER(1),
     PRINCIPAL_ONLY_FLG   CHARACTER(1),
     ASSESS_CHANGE_REASON_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATING_GRADE_PI (ASSESSMENT_DT,ASSESSMENT_RESULT_TYPE_CD,CREDIT_FACILITY_RK,ASSESSMENT_MODEL_RK)
;
CREATE TABLE CREDIT_FACILITY_CR_MITIGANT (
     CREDIT_FACILITY_RK   NUMERIC(10)     NOT NULL,
     CREDIT_RISK_MITIGANT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CR_MITIGANT_RANK_NO  NUMERIC(8),
     TOTAL_VALUE_AMT      NUMERIC(18,5),
     USED_TO_COV_RISK_TYPE_CD VARCHAR(3),
     MATURITY_DT          DATE,
     SOURCE_DOCUMENT_TXT  VARCHAR(100),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_FACILITY_CR_MITIGANT_PI (CREDIT_FACILITY_RK,CREDIT_RISK_MITIGANT_RK)
;
CREATE TABLE CREDIT_FACILITY_GROUP (
     CREDIT_FACILITY_GROUP_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PARENT_CREDIT_FACLTY_GROUP_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CREDIT_FACILITY_GROUP_ID VARCHAR(32),
     GROUP_LIMIT_AMT      NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_FACILITY_GROUP_PI (CREDIT_FACILITY_GROUP_RK)
;
CREATE TABLE CREDIT_RISK_MITIGANT (
     CREDIT_RISK_MITIGANT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     EFFECTIVE_FROM_DT    DATE,
     CREDIT_RISK_MITIGANT_TYPE_CD VARCHAR(3),
     CREDIT_RISK_MITIGANT_ID VARCHAR(32),
     PHYSICAL_COLLATERAL_RK NUMERIC(10),
     FINANCIAL_COLLATERAL_RK NUMERIC(10),
     GUARANTEE_RK         NUMERIC(10),
     RECEIVABLES_RK       NUMERIC(10),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     VALUATION_TYPE_CD    VARCHAR(3),
     HIGHER_SENIORITY_AMT NUMERIC(18,5),
     PROTECTION_VALUE_AMT NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     EXPIRATION_DT        DATE,
     MTM_TIME_FREQUENCY_CD VARCHAR(3),
     IRREVOCABLE_FLG      CHARACTER(1),
     ELIGIBLE_CR_MITIGANT_TYPE_CD VARCHAR(3),
     HELD_BY_INTERNAL_ORG_RK NUMERIC(10),
     UNFUNDED_FLG         CHARACTER(1),
     THIRD_PARTY_DEPOSIT_FLG CHARACTER(1),
     USED_FOR_APPL_ONLY_FLG CHARACTER(1),
     IRB_ALT_TREAT_ELIGIBLE_TYPE_CD VARCHAR(3),
     MTM_MITIGANT_VALUE_AMT NUMERIC(18,5),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_RISK_MITIGANT_PI (CREDIT_RISK_MITIGANT_RK)
;
CREATE TABLE CREDIT_RISK_MITIGANT_TYPE (
     CREDIT_RISK_MITIGANT_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CREDIT_RISK_MITIGANT_TYPE_DESC VARCHAR(100),
     CREDIT_RISK_MITIGANT_CLASS_CD VARCHAR(20),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_RISK_MITIGANT_TYPE_PI (CREDIT_RISK_MITIGANT_TYPE_CD)
;
CREATE TABLE CREDIT_SCORE_DETAILS (
     APPLICATION_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CREDIT_SCORE         VARCHAR(32),
     CREDIT_SCORE_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_SCORE_DETAILS_PI (APPLICATION_RK)
;
CREATE TABLE CREDIT_SPREAD_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10)     NOT NULL,
     CURRENCY_CD          VARCHAR(3)     NOT NULL,
     RISK_FACTOR_ID       VARCHAR(32),
     ASK_SPREAD_RT        NUMERIC(9,4),
     BID_SPREAD_RT        NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_SPREAD_QUOTE_PI (QUOTE_DTTM,MARKET_CD,ASSESSMENT_RATING_GRADE_RK,CURRENCY_CD)
;
CREATE TABLE CREDIT_SURCHARGE (
     CREDIT_SURCHARGE_RK  NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CREDIT_SURCHARGE_CD  VARCHAR(3)     NOT NULL,
     UOE_RK               NUMERIC(10)     NOT NULL,
     DEDUCTIBLE_RK        NUMERIC(10),
     CREDIT_SURCHARGE_AMT NUMERIC(18,5),
     CREDIT_SURCHARGE_PCT NUMERIC(9,4),
     CREDIT_SURCHARGE_FACTOR NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CREDIT_SURCHARGE_PI (CREDIT_SURCHARGE_RK)
;
CREATE TABLE CRIME_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     BUSINESS_HOURS_START_TM DATE,
     BUSINESS_HOURS_CLOSE_TM DATE,
     AVG_NUM_EMPLOYEES    NUMERIC(6),
     CHECKS_STAMPED_IND   CHARACTER(1),
     DEPOSIT_FREQUENCY_CD VARCHAR(3),
     NIGHT_DEPOSIT_IND    CHARACTER(1),
     ANNUAL_GROSS_RECEIPTS_AMT NUMERIC(18,5),
     PROPERTY_DESC        VARCHAR(255),
     MAX_PROPERTY_VALUE_AMT NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CRIME_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE CRIMINAL_CONVICTION_DETAILS (
     CRIME_TYPE_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CRIME_TYPE_CD        VARCHAR(3)     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     FINE_AMT             NUMERIC(18,5),
     CRIME_DESC           VARCHAR(255),
     CONVICTION_DT        DATE,
     PROBATION_IND        CHARACTER(1),
     PROBATION_END_DT     DATE,
     CONVICTION_COUNTRY_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CRIMINAL_CONVICTION_DETAILS_PI (CRIME_TYPE_RK)
;
CREATE TABLE CRITICAL_ILLNESS (
     CRITICAL_ILLNESS_RK  NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CI_DIAGNOSED_BENEFIT_AMT NUMERIC(18,5),
     CI_DEATH_BENEFIT_AMT NUMERIC(18,5),
     CI_NATURAL_DEATH_BENEFIT_AMT NUMERIC(18,5),
     AUTO_PREMIUM_WAIVER_IND CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CRITICAL_ILLNESS_PI (CRITICAL_ILLNESS_RK)
;
CREATE TABLE CROSS_SELL_TARGET_PRODUCT (
     MODEL_RK             NUMERIC(10)     NOT NULL,
     SCORE_DT             DATE     NOT NULL,
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CROSS_SELL_TARGET_PRODUCT_PI (INSURANCE_PRODUCT_RK)
;
CREATE TABLE CURRENCY (
     CURRENCY_CD          VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CONVERTED_TO_EURO_FLG CHARACTER(1),
     CURRENCY_DESC        VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CURRENCY_PI (CURRENCY_CD)
;
CREATE TABLE CURRENCY_CONVERSION_RATE (
     FROM_CURRENCY_CD     VARCHAR(3)     NOT NULL,
     TO_CURRENCY_CD       VARCHAR(3)     NOT NULL,
     ACCOUNT_PERIOD_RK    NUMERIC(10)     NOT NULL,
     CONVERSION_RATE_TYPE_CD VARCHAR(3)     NOT NULL,
     CONVERSION_RT        NUMERIC(9,4)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CURRENCY_CONVERSION_RATE_PI (TO_CURRENCY_CD)
;
CREATE TABLE CUSTOMER (
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CUSTOMER_ID          VARCHAR(32)     NOT NULL,
     CUSTOMER_TYPE_CD     VARCHAR(3),
     CUST_LIFE_TIME_VALUE NUMERIC(9,4),
     CUSTOMER_STATUS_CD   VARCHAR(3),
     CUSTOMER_POISE_CD    VARCHAR(3),
     CROSS_SELLABLE_FLG   CHARACTER(1),
     CUSTOMER_LIFECYCLE_CD VARCHAR(3),
     FIRST_BECAME_CUSTOMER_DT DATE,
     TERMINATION_DT       DATE,
     NUM_RELATIONS        NUMERIC(6),
     ANNUAL_INCOME        NUMERIC(18,5),
     ADVERSE_CREDIT_JUDGEMENT_CNT NUMERIC(6),
     MAILABLE_FLG         CHARACTER(1),
     TELEPHONABLE_FLG     CHARACTER(1),
     EMAILABLE_FLG        CHARACTER(1),
     SMS_TEXTABLE_FLG     CHARACTER(1),
     CONTACTABLE_FLG      CHARACTER(1),
     EARNING_DEPENDENT_CNT NUMERIC(6),
     NONEARNING_DEPENDENT_CNT NUMERIC(6),
     DEPENDENT_CHILDREN_CNT NUMERIC(6),
     DEPENDENT_ADULT_CNT  NUMERIC(6),
     RELATED_POLICYHOLDERS_CNT NUMERIC(6),
     UNINSURED_RELATED_CLIENTS_CNT NUMERIC(6),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXCUSTOMER (CUSTOMER_RK)
;
CREATE TABLE CUSTOMER_COMMUNICATION (
     COMMUNICATION_CD     VARCHAR(30)     NOT NULL,
     CAMPAIGN_RK          NUMERIC(10)     NOT NULL,
     COMMUNICATION_DTTM   TIMESTAMP     NOT NULL,
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     COMMUNICATION_STATUS_CD VARCHAR(30),
     OFFER_CD             VARCHAR(30),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     INSURANCE_PRODUCT_RK NUMERIC(10),
     PRODUCT_COVERAGE_RK  NUMERIC(10),
     MODEL_RK             NUMERIC(10),
     POLICY_RK            NUMERIC(10),
     EMPLOYEE_RK          NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CUSTOMER_COMMUNICATION_PI (COMMUNICATION_CD,CAMPAIGN_RK,COMMUNICATION_DTTM,CUSTOMER_RK)
;
CREATE TABLE CUSTOMER_MODEL_SCORE (
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     MODEL_RK             NUMERIC(10)     NOT NULL,
     SCORE_DT             DATE     NOT NULL,
     MODEL_SCORE_NO       NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CUSTOMER_MODEL_SCORE_PI (CUSTOMER_RK,MODEL_RK,SCORE_DT)
;
CREATE TABLE CUSTOMER_SEGMENT (
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     MODEL_RK             NUMERIC(10)     NOT NULL,
     SCORE_DT             DATE     NOT NULL,
     SEGMENT_CD           VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CUSTOMER_SEGMENT_PI (CUSTOMER_RK,MODEL_RK,SCORE_DT)
;
CREATE TABLE CUSTOMER_SURVEY (
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     SURVEY_REFERENCE_NO  VARCHAR(32)     NOT NULL,
     SURVEY_COLLECTED_DTTM TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CUSTOMER_SURVEY_PI (CUSTOMER_RK,SURVEY_REFERENCE_NO)
;
CREATE TABLE CUST_INS_WITH_OTHER_INSURERS (
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     INSURED_AMT          NUMERIC(18,5),
     PREMIUM_AMT          NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX CUST_INS_WITH_OTHER_INSURER_PI (LOB_RK,CUSTOMER_RK)
;
CREATE TABLE DAY_BASIS (
     DAY_BASIS_CD         VARCHAR(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     DAY_BASIS_DESC       VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DAY_BASIS_PI (DAY_BASIS_CD)
;
CREATE TABLE DECK_DETAILS (
     DECK_RK              NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     DECK_ID              VARCHAR(32)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     LENGTH_HANDRAIL      NUMERIC(14,4),
     DECK_TYPE_CD         VARCHAR(3),
     SURFACE_AREA         NUMERIC(14,4),
     NUM_DECKS            NUMERIC(6),
     ESTIMATED_REPL_COST_AMT NUMERIC(18,5),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DECK_DETAILS_PI (DECK_RK)
;
CREATE TABLE DEDUCTIBLE (
     DEDUCTIBLE_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     DEDUCTIBLE_TYPE_CD   VARCHAR(3)     NOT NULL,
     UOE_RK               NUMERIC(10)     NOT NULL,
     DEDUCTIBLE_APPLIES_TO_CD VARCHAR(3),
     DEDUCTIBLE_AMT       NUMERIC(18,5),
     DEDUCTIBLE_PCT       NUMERIC(9,4),
     DEDUCTIBLE_FACTOR    NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DEDUCTIBLE_PI (DEDUCTIBLE_RK)
;
CREATE TABLE DEFAULT_EVENT (
     DEFAULT_EVENT_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     DEFAULT_EVENT_ID     VARCHAR(32)     NOT NULL,
     DEFAULT_DT           DATE,
     COUNTERPARTY_RK      NUMERIC(10),
     EXPOSURE_AT_DEFAULT_AMT NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     ACCOUNT_RK           NUMERIC(10),
     CREDIT_RISK_MITIGANT_RK NUMERIC(10),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     DEFAULT_REASON_CD    VARCHAR(3),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     DEFAULT_STATUS_CD    VARCHAR(3),
     DEFAULT_TYPE_CD      VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DEFAULT_EVENT_PI (DEFAULT_EVENT_RK)
;
CREATE TABLE DERIVATIVE_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     DERIVATIVE_INSTRUMENT_TYPE_CD VARCHAR(3),
     CONTRACT_PRICE_AMT   NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DERIVATIVE_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE DISABILITY (
     DISABILITY_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     DISB_TYPE_CD         VARCHAR(3),
     DISB_DEATH_BENEFIT_AMT NUMERIC(18,5),
     MAX_DISB_BENEFIT_AMT NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DISABILITY_PI (DISABILITY_RK)
;
CREATE TABLE DISCRETE_CARRYING_COST (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     COST_DT              DATE     NOT NULL,
     CARRYING_COST_VALUE  NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     CARRYING_COST_VALUE_TYPE_CD VARCHAR(3))
     PRIMARY INDEX DISCRETE_CARRYING_COST_PI (FINANCIAL_INSTRUMENT_RK,COST_DT)
;
CREATE TABLE DISCRETE_YIELD (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     YIELD_DT             DATE     NOT NULL,
     YIELD_VALUE          NUMERIC(18,5),
     YIELD_VALUE_TYPE_CD  VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DISCRETE_YIELD_PI (FINANCIAL_INSTRUMENT_RK,YIELD_DT)
;
CREATE TABLE DIVE_PURPOSE_DETAILS (
     LIFE_STYLE_ACTIVITY_RK NUMERIC(10)     NOT NULL,
     DIVE_PURPOSE_TYPE_CD VARCHAR(3)     NOT NULL,
     LAST_YR_AVG_DEPTH    NUMERIC(9,4),
     NEXT_YR_AVG_DEPTH    NUMERIC(9,4),
     LAST_YR_AVG_MINUTE   NUMERIC(6,2),
     NEXT_YR_AVG_MINUTE   NUMERIC(6,2),
     DIVING_LOCATIONS     VARCHAR(50),
     DIVING_EQUIPMENT     VARCHAR(50),
     EQUIPMENT_SERVICED_IND CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DIVE_PURPOSE_DETAILS_PI (LIFE_STYLE_ACTIVITY_RK,DIVE_PURPOSE_TYPE_CD)
;
CREATE TABLE DRIVER (
     DRIVER_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     DRIVER_NO            VARCHAR(32)     NOT NULL,
     LICENSE_TYPE_CD      VARCHAR(3),
     LICENSE_STATUS_CD    VARCHAR(3),
     LICENSED_DT          DATE,
     LICENSE_CLASS_CD     VARCHAR(3),
     LICENSE_TERM         NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DRIVER_PI (DRIVER_RK)
;
CREATE TABLE DRIVER_HISTORY (
     DRIVER_RK            NUMERIC(10)     NOT NULL,
     ACCIDENT_CONVICTION_DTTM TIMESTAMP     NOT NULL,
     ACCIDENT_DESC        VARCHAR(255),
     ACCIDENT_CONVICTION_LOCATION VARCHAR(50),
     BODILY_INJURY_IND    CHARACTER(1),
     DEATH_IND            CHARACTER(1),
     PROP_DAMAGE_AMT      NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DRIVER_HISTORY_PI (DRIVER_RK,ACCIDENT_CONVICTION_DTTM)
;
CREATE TABLE DRIVER_VEHICLE_DETAILS (
     DRIVER_RK            NUMERIC(10)     NOT NULL,
     VEHICLE_RK           NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     OWNED_VEH_IND        CHARACTER(1),
     OWNS_OTHER_VEH_IND   CHARACTER(1),
     USE_PCT              NUMERIC(9,4),
     PRIMARY_DRIVER_IND   CHARACTER(1),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX DRIVER_VEHICLE_DETAILS_PI (DRIVER_RK,VEHICLE_RK,POLICY_RK)
;
CREATE TABLE ECONOMIC_SECTOR (
     ECONOMIC_SECTOR_CD   VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ECONOMIC_SECTOR_DESC VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ECONOMIC_SECTOR_PI (ECONOMIC_SECTOR_CD)
;
CREATE TABLE ELIGIBLE_CR_MITIGANT_TYPE (
     ELIGIBLE_CR_MITIGANT_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     STD_SIMPLE_FLG       CHARACTER(1),
     STD_COMPREHENSIVE_FLG CHARACTER(1),
     IRBF_FLG             CHARACTER(1),
     IRBA_FLG             CHARACTER(1),
     ELIGIBLE_CR_MITIGANT_TYPE_DESC VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ELIGIBLE_CR_MITIGANT_TYPE_PI (ELIGIBLE_CR_MITIGANT_TYPE_CD)
;
CREATE TABLE EMBEDDED_OPTIONS (
     EMBEDDED_OPTION_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EMBEDDED_OPTION_TYPE_CD VARCHAR(3),
     EMBDDED_OPTION_STRIKE_QUOTE_CD VARCHAR(3),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     ACCOUNT_RK           NUMERIC(10),
     EMBEDDED_OPTION_VALUE_AMT NUMERIC(18,5),
     PUT_CALL_TYPE_CD     VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     EXERCISE_TRANSACTION_COST_PCT NUMERIC(9,4),
     DAY_BASIS_CD         VARCHAR(10),
     STRIKE_VALUE         NUMERIC(18,5),
     STRIKE_VALUE_TYPE_CD VARCHAR(3),
     EMBEDDED_OPTION_ID   VARCHAR(32),
     CREDIT_FACILITY_RK   NUMERIC(10),
     EMBED_OPT_SCHEDULE_LOOKUP_FLG CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EMBEDDED_OPTIONS_PI (EMBEDDED_OPTION_RK)
;
CREATE TABLE EMPLOYEE (
     EMPLOYEE_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EMPLOYEE_ID          VARCHAR(32)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     EMPLOYMENT_START_DT  DATE,
     TERMINATION_DT       DATE,
     HIRED_STATE_REGION_CD VARCHAR(3),
     EMPLOYMENT_STATUS_CD VARCHAR(3),
     FTE_IND              CHARACTER(1),
     RATING_CLASSIFICATION_CD VARCHAR(3),
     TAX_FILING_STATUS_CD VARCHAR(3),
     NUM_DEPENDENTS       NUMERIC(6),
     NUM_EXEMPTS_ENTITLED NUMERIC(6),
     NUM_EXEMPTS_WITHHOLDING NUMERIC(6),
     REGULAR_DEPT         VARCHAR(50),
     BORROWED_DEPT        VARCHAR(50),
     ORG_PRIMARY_CONTACT_IND CHARACTER(1),
     ORG_MANAGER_IND      CHARACTER(1),
     EMPLOYING_ORG_RK     NUMERIC(10),
     PRODUCER_RK          NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EMPLOYEE_PI (EMPLOYEE_RK)
;
CREATE TABLE EQUITY_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EQUITY_INSTRUMENT_TYPE_CD VARCHAR(10),
     REGULATORY_SCALING_FACTOR_NO NUMERIC(6,2),
     REDEMPTION_PRICE_AMT NUMERIC(18,5),
     CALL_PROTECTION_DT   DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     OUTSTANDING_SHARES_NO NUMERIC(6,2))
     PRIMARY INDEX EQUITY_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE EQUITY_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     ISSUE_CD             VARCHAR(15)     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     ISSUE_TYPE_CD        VARCHAR(3),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EQUITY_QUOTE_PI (QUOTE_DTTM,MARKET_CD,ISSUE_CD)
;
CREATE TABLE EQUITY_VOLATILITY_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     ISSUE_CD             VARCHAR(15)     NOT NULL,
     BID_VOLATILITY_RT    NUMERIC(11,6),
     ASK_VOLATILITY_RT    NUMERIC(11,6),
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     ISSUE_TYPE_CD        VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EQUITY_VOLATILITY_QUOTE_PI (QUOTE_DTTM,MARKET_CD,ISSUE_CD)
;
CREATE TABLE EVENT (
     EVENT_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EVENT_ID             VARCHAR(32)     NOT NULL,
     EVENT_NM             VARCHAR(40),
     EVENT_TYPE_CD        VARCHAR(30),
     EVENT_DT             DATE,
     EVENT_TXT            VARCHAR(100),
     EVENT_AMT            NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EVENT_PI (EVENT_RK)
;
CREATE TABLE EXOTIC_OPTION_ATTRIBUTE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     OPTION_INSTR_EXOTIC_TYPE_CD VARCHAR(3)     NOT NULL,
     EXOTIC_OPTION_ATTRIBUTE_NM VARCHAR(30)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     EXOTIC_OPTION_ATTRIBUTE_DESC VARCHAR(100),
     ATTRIBUTE_NUMERIC_VALUE_AMT NUMERIC(18,5),
     ATTRIBUTE_DATE_VALUE_DTTM TIMESTAMP,
     ATTRIBUTE_CHAR_VALUE_TXT VARCHAR(32),
     COLUMN_DATA_TYPE_CD  VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXOTIC_OPTION_ATTRIBUTE_PI (FINANCIAL_INSTRUMENT_RK,OPTION_INSTR_EXOTIC_TYPE_CD,EXOTIC_OPTION_ATTRIBUTE_NM)
;
CREATE TABLE EXOTIC_OPTION_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     OPTION_INSTR_EXOTIC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     OPTION_INSTR_EXOTIC_SUBTYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXOTIC_OPTION_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK,OPTION_INSTR_EXOTIC_TYPE_CD)
;
CREATE TABLE EXPENSE_ALLOCATION (
     EXPENSE_ALLOCATION_RK NUMERIC(10)     NOT NULL,
     EXPENSE_TYPE_CD      VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     EXPENSE_ALLOCATION_ID VARCHAR(32),
     EXPENSE_ALLOCATION_VALUE NUMERIC(18,5),
     EXPENSE_ALLOC_VALUE_TYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXPENSE_ALLOCATION_PI (EXPENSE_ALLOCATION_RK)
;
CREATE TABLE EXPOSURE_CR_MITIGANT_RANK (
     CREDIT_RISK_MITIGANT_RK NUMERIC(10),
     ACCOUNT_RK           NUMERIC(10),
     FINANCIAL_POSITION_RK NUMERIC(10),
     RANK_ORDER_NO        NUMERIC(10),
     CREDIT_FACILITY_RK   NUMERIC(10),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXPOSURE_CR_MITIGANT_RANK_PI (RANK_ORDER_NO,EFFECTIVE_FROM_DTTM,CREDIT_RISK_MITIGANT_RK,ACCOUNT_RK,FINANCIAL_POSITION_RK)
;
CREATE TABLE EXPOSURE_PLEDGED (
     PLEDGE_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PLEDGE_ID            VARCHAR(32),
     FINANCIAL_POSITION_RK NUMERIC(10)     NOT NULL,
     PLEDGED_TYPE_CD      VARCHAR(3),
     PLEDGED_TYPE_AMT     NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXPOSURE_PLEDGED_PI (PLEDGE_RK)
;
CREATE TABLE EXPOSURE_RECOVERY (
     RECOVERY_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     RECOVERY_ID          VARCHAR(32),
     RECOVERY_DT          DATE,
     RECOVERY_RT          NUMERIC(9,4),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     VALUE_AT_DEFAULT_AMT NUMERIC(18,5),
     VALUE_AT_RECOVERY_AMT NUMERIC(18,5),
     VALUE_REALIZED_AMT   NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     LGD_RT               NUMERIC(9,4),
     DEFAULT_EVENT_RK     NUMERIC(10),
     RECOVERY_COST_AMT    NUMERIC(18,5),
     RECOVERY_FROM_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXPOSURE_RECOVERY_PI (RECOVERY_RK)
;
CREATE TABLE EXTENDIBLE_OPTION_INSTRUMENT (
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     EXTENDIBLE_OPTION_TYPE_CD VARCHAR(3),
     EXTENDED_MATURITY_DT DATE,
     EXTENDED_PREMIUM_AMT NUMERIC(18,5),
     EXTENDED_STRIKE_VALUE NUMERIC(18,5),
     EXTENDED_STRIKE_VALUE_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXTENDIBLE_OPTION_INSTRUMEN_PI (VALID_FROM_DTTM,FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE EXTERNAL_ORG (
     EXTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EXTERNAL_ORG_REFERENCE_NO VARCHAR(32)     NOT NULL,
     ORG_NM               VARCHAR(50),
     ORG_LEGAL_NM         VARCHAR(50),
     ORG_SHORT_NM         VARCHAR(50),
     CURRENCY_CD          VARCHAR(3),
     WEB_SITE_TXT         VARCHAR(255),
     ORG_TYPE_CD          VARCHAR(3),
     ORG_LEGAL_TYPE_CD    VARCHAR(3),
     CENTRAL_TAX_NO       VARCHAR(32),
     OWNERSHIP_TYPE_CD    VARCHAR(3),
     PREFERRED_LANGUAGE_CD VARCHAR(3),
     NAICS_CD             VARCHAR(10),
     ACCOUNTING_FIRM_NM   VARCHAR(50),
     FIRST_OPERATION_DT   DATE,
     COMPANY_REGISTRATION_NO VARCHAR(32),
     SALES_TURNOVER       NUMERIC(18,5),
     SIC_CD               VARCHAR(10),
     DUNS_NO              VARCHAR(9),
     ESTABLISHED_DT       DATE,
     LISTED_SECURITY_SYMBOL_CD VARCHAR(3),
     NATURE_OF_BUSINESS_CD VARCHAR(3),
     CREDIT_RATING_CD     VARCHAR(20),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXTERNAL_ORG_PI (EXTERNAL_ORG_RK)
;
CREATE TABLE EXTERNAL_ORG_ADDRESS (
     ORG_ADDRESS_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EXTERNAL_ORG_RK      NUMERIC(10),
     ADDRESS_TYPE_CD      VARCHAR(3),
     ADDRESS_LINE_1       VARCHAR(64),
     ADDRESS_LINE_2       VARCHAR(64),
     ADDRESS_LINE_3       VARCHAR(64),
     ADDRESS_LINE_4       VARCHAR(64),
     CITY_NM              VARCHAR(100),
     POSTAL_CD            VARCHAR(20),
     COUNTY_NM            VARCHAR(40),
     STATE_REGION_CD      VARCHAR(4),
     COUNTRY_CD           VARCHAR(3),
     NON_PHYSICAL_ADDRESS_FLG CHARACTER(1),
     DELIVERY_POINT_ID    VARCHAR(32),
     ADDRESS_QUALITY_CD   VARCHAR(3),
     TELEPHONE_NO         VARCHAR(20),
     FAX_NO               VARCHAR(20),
     PRIMARY_ADDRESS_FLG  CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXTERNAL_ORG_ADDRESS_PI (ORG_ADDRESS_RK)
;
CREATE TABLE EXTERNAL_ORG_ASSOC (
     PARENT_EXTERNAL_ORG_RK NUMERIC(10)     NOT NULL,
     EXTERNAL_ORG_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EXTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXTERNAL_ORG_ASSOC_PI (PARENT_EXTERNAL_ORG_RK,EXTERNAL_ORG_ASSOC_TYPE_CD,EXTERNAL_ORG_RK)
;
CREATE TABLE EXTERNAL_ORG_FINANCIAL_DATA (
     EXTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ANNUAL_REVENUE_AMT   NUMERIC(18,5),
     REVENUE_GROWTH_AMT   NUMERIC(18,5),
     GROSS_ANNUAL_SALES_AMT NUMERIC(18,5),
     NET_SALES_REVENUE_AMT NUMERIC(18,5),
     ANNUAL_OPERATING_REVENUE_AMT NUMERIC(18,5),
     CAGR_OPERATING_REVENUE_AMT NUMERIC(18,5),
     NON_OPERATING_REVENUE_AMT NUMERIC(18,5),
     COST_OF_GOODS_SOLD_AMT NUMERIC(18,5),
     COST_OF_SALES_AMT    NUMERIC(18,5),
     OPBDIT_AMT           NUMERIC(18,5),
     ANNUAL_INTEREST_CHARGES_AMT NUMERIC(18,5),
     INTEREST_FINANCE_CHARGES_AMT NUMERIC(18,5),
     TOTAL_TERM_DEBT_P_AND_I_AMT NUMERIC(18,5),
     LONG_TERM_DEBT_INT_EXPENSE_AMT NUMERIC(18,5),
     DEPREC_NON_CASH_CHARGES_AMT NUMERIC(18,5),
     OWNER_COMP_DRAWING_AMT NUMERIC(18,5),
     GENERAL_OTHER_EXPENSE_AMT NUMERIC(18,5),
     EBIT_AMT             NUMERIC(18,5),
     PRIOR_PERIOD_ADJUSTMENTS_NO NUMERIC(6),
     EXTRA_ORDINARY_INCOME_AMT NUMERIC(18,5),
     EXTRA_ORDINARY_EXPENSES_AMT NUMERIC(18,5),
     GROSS_PROFIT_AMT     NUMERIC(18,5),
     PBT_AMT              NUMERIC(18,5),
     PAT_AMT              NUMERIC(18,5),
     ACCRETION_TO_RESERVES_AMT NUMERIC(18,5),
     NET_CASH_ACCRUALS_AMT NUMERIC(18,5),
     FREE_CASH_FLOW_AMT   NUMERIC(18,5),
     GROSS_OPERATING_MARGINS_AMT NUMERIC(18,5),
     NET_INCOME_AMT       NUMERIC(18,5),
     GROSS_MARGIN_AMT     NUMERIC(18,5),
     NET_MARGIN_AMT       NUMERIC(18,5),
     RETURN_ON_CAPITAL_EMPLOYED_AMT NUMERIC(18,5),
     RETURN_ON_EQUITY_AMT NUMERIC(18,5),
     DEBT_SERVICE_COVERAGE_RT NUMERIC(9,4),
     AVG_DEBT_SERVICE_COVERAGE_RT NUMERIC(9,4),
     INTEREST_COVERAGE_RT NUMERIC(9,4),
     AVERAGE_INTEREST_COVERAGE_RT NUMERIC(9,4),
     RENT_AMT             NUMERIC(18,5),
     TOTAL_ASSETS_AMT     NUMERIC(18,5),
     FIXED_ASSETS_AMT     NUMERIC(18,5),
     CURRENT_ASSETS_AMT   NUMERIC(18,5),
     NET_TRADE_REC_AMT    NUMERIC(18,5),
     INVENTORY_AMT        NUMERIC(18,5),
     OTHER_CURRENT_ASSETS_AMT NUMERIC(18,5),
     MARKETABLE_SECURITIES_AMT NUMERIC(18,5),
     ASSETS_SECURITIZED_AMT NUMERIC(18,5),
     CASH_AND_BANK_BALANCES_AMT NUMERIC(18,5),
     INTANGIBLE_ASSETS_AMT NUMERIC(18,5),
     REVALUATION_RESERVES_AMT NUMERIC(18,5),
     OTHER_ASSETS_AMT     NUMERIC(18,5),
     TOTAL_LIABILITY_AMT  NUMERIC(18,5),
     TOTAL_DEBT_AMT       NUMERIC(18,5),
     LONG_TERM_DEBT_AMT   NUMERIC(18,5),
     LONG_TERM_DEBT_EXPO_AMT NUMERIC(18,5),
     SHORT_TERM_DEBT_AMT  NUMERIC(18,5),
     SHORT_TERM_DEBT_EXPO_AMT NUMERIC(18,5),
     SECURED_DEBT_AMT     NUMERIC(18,5),
     UNSECURED_DEBT_AMT   NUMERIC(18,5),
     NOTES_PAYABLE_AMT    NUMERIC(18,5),
     TRADE_PAYABLE_AMT    NUMERIC(18,5),
     SHORT_TERM_PAYABLES_AMT NUMERIC(18,5),
     CURRENT_LTD_AMT      NUMERIC(18,5),
     OTHER_CURRENT_LIABILITY_AMT NUMERIC(18,5),
     TOTAL_CURRENT_LIABILITY_AMT NUMERIC(18,5),
     OTHER_LIABILITY_AMT  NUMERIC(18,5),
     CONTINGENT_LIABILITIES_AMT NUMERIC(18,5),
     TRADE_CREDITORS_AMT  NUMERIC(18,5),
     FOREIGN_CURR_EXPOS_TRANS_AMT NUMERIC(18,5),
     FOREIGN_CURR_TRANS_EXPOS_AMT NUMERIC(18,5),
     FOREIGN_OTHER_EXPOS_AMT NUMERIC(18,5),
     CHARGED_OFF_AMT      NUMERIC(18,5),
     CURRENT_VALUE_SECURITY_AMT NUMERIC(18,5),
     NET_WORTH_AMT        NUMERIC(18,5),
     ADJUSTED_NET_WORTH_AMT NUMERIC(18,5),
     LIQUIDITY_RT         NUMERIC(9,4),
     CURRENT_RT           NUMERIC(9,4),
     TOTAL_EQUITY_NET_WORTH_AMT NUMERIC(18,5),
     RETAINED_EARNINGS_AMT NUMERIC(18,5),
     ASSET_BETA_NO        NUMERIC(10),
     MARKET_CAPITALIZATION_AMT NUMERIC(18,5),
     MARKET_CAPITALIZATION_DT DATE,
     DIVIDEND_PAYOUT_AMT  NUMERIC(18,5),
     DIVIDEND_PAYOUT_RATIO_PCT NUMERIC(9,4),
     EARNINGS_PER_SHARE_AMT NUMERIC(18,5),
     PRICE_EARNINGS_RATIO_RT NUMERIC(9,4),
     DEBT_EQUITY_RT       NUMERIC(9,4),
     LT_DEBT_EQUITY_RT    NUMERIC(9,4),
     ST_DEBT_EQUITY_RT    NUMERIC(9,4),
     DAYS_PAYABLE_RT      NUMERIC(9,4),
     DAYS_RECEIVABLE_RT   NUMERIC(9,4),
     DAYS_FINISHED_GOODS_INV_RT NUMERIC(9,4),
     DAYS_WORK_IN_PROG_GOODS_RT NUMERIC(9,4),
     KNOWN_BANK_RELATIONS_CNT NUMERIC(6),
     CURRENCY_CD          VARCHAR(3),
     EQUITY_CAPITAL_AMT   NUMERIC(18,5),
     CREDIT_BUREAU_SCORE_NO NUMERIC(4),
     CREDIT_BUREAU_SCORE_DT DATE,
     TAX_BRACKET_CD       VARCHAR(3),
     LIQUID_NET_WORTH_AMT NUMERIC(18,5),
     BANKRUPTCY_FILED_DT  DATE,
     BANKRUPTCY_STATUS_CD VARCHAR(3),
     REPORTED_ON_DT       DATE,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     WORKING_CAPITAL_AMT  NUMERIC(18,5),
     CASH_FLOW_AMT        NUMERIC(18,5),
     INTEREST_INCOME_AMT  NUMERIC(18,5),
     RETURN_ON_ASSESTS_AMT NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXTERNAL_ORG_FINANCIAL_DATA_PI (EXTERNAL_ORG_RK)
;
CREATE TABLE EXTERNAL_ORG_INDUSTRY_CLASS (
     EXTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     INDUSTRY_CLASS_TYPE_CD VARCHAR(20)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INDUSTRY_CLASS_CD    VARCHAR(20),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX EXTERNAL_ORG_INDUSTRY_CLASS_PI (EXTERNAL_ORG_RK,INDUSTRY_CLASS_TYPE_CD)
;
CREATE TABLE FAMILY_ILLNESS_DETAILS (
     FAMILY_ILLNESS_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FULL_NM              VARCHAR(150)     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     ROLE_CODE_DESC       VARCHAR(100),
     LAST_UPDATED_DT      DATE,
     ONSET_AGE            NUMERIC(3),
     ONSET_DT             DATE,
     RECOVERY_IND         CHARACTER(1),
     RECOVERY_DT          DATE,
     DIAGNOSIS_CD         VARCHAR(3),
     AGE_AT_DEATH         NUMERIC(3),
     AGE_IF_LIVING        NUMERIC(3),
     AGE_AS_OF_DT         DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FAMILY_ILLNESS_DETAILS_PI (FAMILY_ILLNESS_RK)
;
CREATE TABLE FEES (
     FEE_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     FEE_TYPE_CD          VARCHAR(3)     NOT NULL,
     FEE_DESC             VARCHAR(100),
     FEE_AMT              NUMERIC(18,5),
     FEE_PCT              NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FEES_PI (FEE_RK)
;
CREATE TABLE FINANCIAL_ACCOUNT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ACCOUNT_ID           VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3),
     ACCOUNT_REGISTRATION_NM VARCHAR(100),
     ALTERNATE_ACCOUNT_NM VARCHAR(40),
     FINANCIAL_ACCOUNT_TYPE_CD VARCHAR(3)     NOT NULL,
     ACCOUNT_REGISTRATION_TYPE_CD VARCHAR(3),
     ACCOUNT_STATUS_CD    VARCHAR(3),
     OPEN_DT              DATE,
     CLOSE_DT             DATE,
     CLOSE_REASON_CD      VARCHAR(3),
     ACCOUNT_TAX_ID       VARCHAR(32),
     EXPECTED_LOSS_PCT    NUMERIC(9,4),
     INDIVIDUAL_ORGANIZATION_CD VARCHAR(3),
     SOURCE_CD            VARCHAR(5),
     OPENING_CHANNEL_CD   VARCHAR(3),
     PREFERRED_CHANNEL_CD VARCHAR(3),
     CURRENCY_CD          VARCHAR(3),
     PRIMARY_PHONE_NO     VARCHAR(20),
     PRIMARY_PHONE_TYPE_CD VARCHAR(3),
     SECONDARY_PHONE_NO   VARCHAR(20),
     SECONDARY_PHONE_TYPE_CD VARCHAR(3),
     MAILABLE_FLG         CHARACTER(1),
     TELEPHONABLE_FLG     CHARACTER(1),
     EMAIL_FLG            CHARACTER(1),
     SMS_FLG              CHARACTER(1),
     DO_NOT_CONTACT_FLG   CHARACTER(1),
     EMPLOYEE_RK          NUMERIC(10),
     CURRENCY_BASED_ACCOUNT_FLG CHARACTER(1),
     FEE_BASED_FLG        CHARACTER(1),
     ANNUAL_FEES_AMT      NUMERIC(18,5),
     MONTHLY_FEES_AMT     NUMERIC(18,5),
     CAMPAIGN_CD          VARCHAR(30),
     COMMUNICATION_CD     VARCHAR(30),
     REGISTERED_ONLINE_DT DATE,
     FIRST_LOGIN_DT       DATE,
     ONLINE_BILL_PAYMENT_FLG CHARACTER(1),
     ID_VERIFICATION_TYPE_CD VARCHAR(3),
     PREVIOUS_ACCOUNT_ID  VARCHAR(32),
     FUTURE_MARGIN_INCOME_AMT NUMERIC(18,5),
     IN_DEFAULT_FLG       CHARACTER(1),
     IRRECOVERABLE_FLG    CHARACTER(1),
     PREVIOUS_BANK_EXTERNAL_ORG_RK NUMERIC(10),
     NETTING_SET_RK       NUMERIC(10),
     REVOLVING_FLG        CHARACTER(1),
     SOURCE_CHANNEL_CD    VARCHAR(3),
     GRACE_PERIOD_DAYS_CNT NUMERIC(6),
     REMARGINING_DAYS_CNT NUMERIC(6),
     FINANCIAL_CALENDAR_RK NUMERIC(10),
     DAY_BASIS_CD         VARCHAR(10),
     PORTFOLIO_ID         VARCHAR(32),
     SECURITIZATION_POOL_RK NUMERIC(10),
     ACCOUNT_USAGE_TYPE_CD VARCHAR(3),
     RISK_ALARM_FLG       CHARACTER(1),
     LOW_PROFITABILITY_FLG CHARACTER(1),
     ACCOUNT_LIFECYCLE_STG_CD VARCHAR(3),
     ATTRITION_ALARM_FLG  CHARACTER(1),
     BALANCE_FROZEN_FLG   CHARACTER(1),
     BALANCE_FROZEN_DT    DATE,
     ACCOUNT_BLOCK_REASON_CD VARCHAR(3),
     TAXATION_STATE_CD    VARCHAR(4),
     EFFECTIVE_MATURITY_YEAR_NO NUMERIC(7,3),
     GL_ACCOUNT_RK        NUMERIC(10),
     FROM_OTHER_INSTITUTION_FLG CHARACTER(1),
     ACCOUNT_RENEWAL_CNT  NUMERIC(6),
     BALANCE_TRANSFER_DT  DATE,
     BALANCE_TRANSFER_AMT NUMERIC(18,5),
     BALANCE_TRANSFER_CNT NUMERIC(6),
     BASE_LONG_TERM_APR_RT NUMERIC(9,4),
     BROKER_FLG           CHARACTER(1),
     MULT_RATE_FLG        CHARACTER(1),
     AUTO_DEBIT_ACCOUNT_NO VARCHAR(32),
     WORST_STATUS_LAST_12_MTH_CD VARCHAR(3),
     WORST_STATUS_LAST_12_MTH_DT DATE,
     BALANCE_TRNSF_OTHER_ACCT_CNT NUMERIC(6),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     COUNTERPARTY_RK      NUMERIC(10),
     INSURED_BY_COUNTERPARTY_RK NUMERIC(10),
     STATEMENT_FREQUENCY_CD VARCHAR(3),
     SECURITY_DEPOSIT_AMT NUMERIC(18,5),
     SECURITY_DEPOSIT_REFUND_AMT NUMERIC(18,5),
     FIRST_PAYMENT_DT     DATE,
     LAST_PAYMENT_DT      DATE,
     FIRST_RESET_DT       DATE,
     LAST_RESET_DT        DATE,
     PRINCIPAL_PAYMENT_TYPE_CD VARCHAR(3),
     PRINCIPAL_PAYMENT_AMT NUMERIC(18,5),
     RATE_POLICY_RK       NUMERIC(10),
     CAPITAL_ALLOCATION_RK NUMERIC(10),
     SPREAD_RT            NUMERIC(9,4),
     DISCOUNT_SPREAD_RT   NUMERIC(9,4),
     INITIAL_CONTRACT_RT  NUMERIC(9,4),
     FIXED_MONTHLY_PREPAYMENT_RT NUMERIC(9,4),
     FINANCIAL_FUND_RK    NUMERIC(10),
     CAPITAL_COST_RK      NUMERIC(10),
     QUANTO_FEATURE_RK    NUMERIC(10),
     SEGMENT_RK           NUMERIC(10),
     ANNUITY_PAYMENT_TYPE_CD VARCHAR(3),
     ARREARS_PAYMENT_CD   VARCHAR(3),
     AUTO_DEBIT_ACCOUNT_TYPE_CD VARCHAR(3),
     CASH_INTENSIVE_BUSINESS_FLG CHARACTER(1),
     CONVEXITY_ADJUSTMENT_FLG CHARACTER(1),
     INTEREST_PAYMENT_TIME_FREQ_CD VARCHAR(3),
     INTEREST_PAYMENT_TYPE_CD VARCHAR(3),
     INTERNAL_REPORTING_CATEGORY_CD VARCHAR(3),
     LETTER_OF_CREDIT_ONFILE_FLG CHARACTER(1),
     RESETS_PER_ANNUM_NO  NUMERIC(5),
     STATEMENT_OPT_FLG    CHARACTER(1),
     TRADE_FINANCE_FLG    CHARACTER(1),
     VALUE_SCALING_FACTOR_RT NUMERIC(9,4),
     PREPMT_PSA_SPEED_RT  NUMERIC(9,4),
     OWNED_BY_INTERNAL_ORG_RK NUMERIC(10),
     CREDIT_FACILITY_RK   NUMERIC(10),
     EXPENSE_ALLOCATION_RK NUMERIC(10),
     FIRST_INTEREST_PAYMENT_DT DATE,
     HOLIDAY_DATE_ROLL_CONV_CD VARCHAR(3),
     LAST_INTEREST_PAYMENT_DT DATE,
     LIQUIDITY_CATEGORY_TYPE_CD VARCHAR(3),
     RECEIVABLES_POOL_RK  NUMERIC(10),
     WEEKEND_DATE_ROLL_CONV_CD VARCHAR(3),
     CIC_CD               VARCHAR(4),
     UNWIND_TRIGGER_EVENT_TYPE_CD VARCHAR(3),
     UNWIND_MAX_LOSS_AMT  NUMERIC(18,5),
     PAYMENT_DAY_OF_MONTH_NO NUMERIC(3),
     INT_PAYMENT_DAY_OF_MONTH_NO NUMERIC(3),
     RESET_DAY_OF_MONTH_NO NUMERIC(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_ACCOUNT_PI (ACCOUNT_RK)
;
CREATE TABLE FINANCIAL_ACCOUNT_ADDRESS (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ADDRESS_TYPE_CD      VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ADDRESS_LINE_1_TXT   VARCHAR(100),
     ADDRESS_LINE_2_TXT   VARCHAR(100),
     ADDRESS_LINE_3_TXT   VARCHAR(100),
     ADDRESS_LINE_4_TXT   VARCHAR(100),
     CITY_NM              VARCHAR(100),
     STATE_REGION_CD      VARCHAR(4),
     POSTAL_CD            VARCHAR(20),
     COUNTRY_CD           VARCHAR(3),
     PREFERRED_CONTACT_ADDRESS_FLG CHARACTER(1),
     NON_PHYSICAL_ADDRESS_FLG CHARACTER(1),
     ADDRESS_QUALITY_CD   VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_ACCOUNT_ADDRESS_PI (ACCOUNT_RK,ADDRESS_TYPE_CD)
;
CREATE TABLE FINANCIAL_ACCOUNT_ASSOC (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     REFERENCE_FINANCIAL_ACCOUNT_RK NUMERIC(10)     NOT NULL,
     FINANCIAL_ACCT_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_ACCOUNT_ASSOC_PI (ACCOUNT_RK,REFERENCE_FINANCIAL_ACCOUNT_RK,FINANCIAL_ACCT_ASSOC_TYPE_CD)
;
CREATE TABLE FINANCIAL_ACCOUNT_CALC_SPEC (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     RISK_WEIGHT_PCT      NUMERIC(9,4),
     HOLDING_PERIOD_DAYS_CNT NUMERIC(6),
     HAIRCUT_SET_ID       VARCHAR(32),
     HAIRCUT_VALUE_RT     NUMERIC(9,4),
     REGULATORY_PRODUCT_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_ACCOUNT_CALC_SPEC_PI (ACCOUNT_RK)
;
CREATE TABLE FINANCIAL_ACCOUNT_CHNG (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     STATEMENT_DT         DATE,
     BILL_DUE_DT          DATE,
     BILLED_AMT           NUMERIC(18,5),
     CURRENT_BILL_AMT     NUMERIC(18,5),
     BALANCE_AMT          NUMERIC(18,5),
     EQUITY_BALANCE_AMT   NUMERIC(18,5),
     MARGIN_BALANCE_AMT   NUMERIC(18,5),
     INTEREST_BALANCE_AMT NUMERIC(18,5),
     PRINCIPAL_BALANCE_AMT NUMERIC(18,5),
     FEES_AMT             NUMERIC(18,5),
     PAST_DUE_AMT         NUMERIC(18,5),
     DAYS_PAYMENT_PAST_DUE_CNT NUMERIC(6),
     CURRENCY_CD          VARCHAR(3),
     LAST_ACTIVITY_DT     DATE,
     TOTAL_BALANCE_AMT    NUMERIC(18,5),
     AVG_DAILY_BALANCE_AMT NUMERIC(18,5),
     MAX_ACCOUNT_VALUE_AMT NUMERIC(18,5),
     MIN_ACCOUNT_VALUE_AMT NUMERIC(18,5),
     AVG_ACCOUNT_VALUE_AMT NUMERIC(18,5),
     CURTAILMENT_AMT      NUMERIC(18,5),
     MINIMUM_BILL_DUE_AMT NUMERIC(18,5),
     EXPOSURE_AT_DEFAULT_AMT NUMERIC(18,5),
     ADJUSTMENT_TO_EXPOSURE_AMT NUMERIC(18,5),
     ACCRUED_INTEREST_AMT NUMERIC(18,5),
     ACCRUED_BASE_INTEREST_AMT NUMERIC(18,5),
     LAST_PAYMENT_STATUS_CD VARCHAR(3),
     LAST_LOGIN_DT        DATE,
     ACCOUNT_VALUE_AMT    NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_ACCOUNT_CHNG_PI (ACCOUNT_RK)
;
CREATE TABLE FINANCIAL_ACCOUNT_RESETS (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     RESET_DT             DATE     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_ACCOUNT_RESETS_PI (ACCOUNT_RK,RESET_DT)
;
CREATE TABLE FINANCIAL_ACCT_TRANSFER_RATE (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     TRANSFER_RATE_TYPE_CD VARCHAR(3)     NOT NULL,
     TRANSFER_METHOD_CD   VARCHAR(3)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP     NOT NULL,
     EFFECTIVE_TO_DTTM    TIMESTAMP     NOT NULL,
     TRANSFER_RT          NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_ACCT_TRANSFER_RAT_PI (ACCOUNT_RK,TRANSFER_RATE_TYPE_CD,TRANSFER_METHOD_CD,EFFECTIVE_FROM_DTTM)
;
CREATE TABLE FINANCIAL_CALENDAR (
     FINANCIAL_CALENDAR_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3),
     FINANCIAL_CALENDAR_ID VARCHAR(32),
     FINANCIAL_CALENDAR_NM VARCHAR(40),
     COUNTRY_CD           VARCHAR(3)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     WEEKEND_DAY_1_OF_WEEK_NO NUMERIC(3),
     WEEKEND_DAY_2_OF_WEEK_NO NUMERIC(3))
     PRIMARY INDEX FINANCIAL_CALENDAR_PI (FINANCIAL_CALENDAR_RK)
;
CREATE TABLE FINANCIAL_CAL_DATE (
     FINANCIAL_CALENDAR_RK NUMERIC(10)     NOT NULL,
     CALENDAR_DT          DATE     NOT NULL,
     HOLIDAY_FLG          CHARACTER(1),
     TRADING_DAY_FLG      CHARACTER(1),
     BUSINESS_DAY_FLG     CHARACTER(1),
     HOLIDAY_NM           VARCHAR(40),
     FIN_YEAR_NO          NUMERIC(6),
     FIN_MONTH_NO         NUMERIC(6),
     FIN_DAY_OF_MONTH_NO  NUMERIC(6),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_CAL_DATE_PI (FINANCIAL_CALENDAR_RK,CALENDAR_DT)
;
CREATE TABLE FINANCIAL_COLLATERAL (
     FINANCIAL_COLLATERAL_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FIN_COLLATERAL_SUBTYPE_CD VARCHAR(3),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     FINANCIAL_COLLATERAL_ID VARCHAR(32)     NOT NULL,
     LAST_VALUATION_DT    DATE,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     ACCOUNT_RK           NUMERIC(10),
     HOLDINGS_NO          NUMERIC(18,5),
     INS_SURRENDER_VALUE_AMT NUMERIC(18,5),
     HAIRCUT_SET_ID       VARCHAR(32),
     INS_PROVIDER_EXT_ORG_RK NUMERIC(10),
     INSURED_AMT          NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_COLLATERAL_PI (FINANCIAL_COLLATERAL_RK)
;
CREATE TABLE FINANCIAL_FUND (
     FINANCIAL_FUND_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FINANCIAL_FUND_ID    VARCHAR(32),
     FINANCIAL_FUND_NM    VARCHAR(40),
     FUND_DESC            VARCHAR(100),
     RING_FENCED_FLG      CHARACTER(1),
     FINANCIAL_FUND_TYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP     NOT NULL,
     EFFECTIVE_TO_DTTM    TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_FUND_PI (FINANCIAL_FUND_RK)
;
CREATE TABLE FINANCIAL_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RATE_POLICY_RK       NUMERIC(10),
     INTEREST_PAYMENT_TYPE_CD VARCHAR(3),
     FINANCIAL_INSTRUMENT_ID VARCHAR(32),
     FINANCIAL_INSTRUMENT_NM VARCHAR(200),
     EFFECTIVE_FROM_DT    DATE,
     MATURITY_DT          DATE,
     SOURCE_SYSTEM_CD     VARCHAR(3),
     FIRST_PAYMENT_DT     DATE,
     LAST_PAYMENT_DT      DATE,
     FACE_VALUE_AMT       NUMERIC(18,5),
     PAYMENTS_PER_ANNUM_RT NUMERIC(9,4),
     FIRST_RESET_DT       DATE,
     LAST_RESET_DT        DATE,
     RESETS_PER_ANNUM_NO  NUMERIC(5),
     GRACE_PERIOD_DAYS_CNT NUMERIC(3),
     MATERIALITY_THRESHOLD_AMT NUMERIC(18,5),
     PRESENT_VALUE_AMT    NUMERIC(18,5),
     FINANCIAL_INSTRUMENT_TYPE_CD VARCHAR(3),
     FINANCIAL_CALENDAR_RK NUMERIC(10),
     HIGH_RISK_CATEGORY_FLG CHARACTER(1),
     IRRECOVERABLE_FLG    CHARACTER(1),
     MATERIALITY_THRESH_CURRENCY_CD VARCHAR(3),
     CURRENCY_CD          VARCHAR(3),
     MTM_VALUE_TO_SELL_CURRENCY_CD VARCHAR(3),
     MTM_VALUE_TO_BUY_CURRENCY_CD VARCHAR(3),
     REMARGINING_DAYS_CNT NUMERIC(6),
     ISSUER_COUNTERPARTY_RK NUMERIC(10),
     NEXT_CONTRACT_RESET_DT DATE,
     DAY_BASIS_CD         VARCHAR(10),
     COVER_SECURITIZATION_POOL_RK NUMERIC(10),
     SENIORITY_CD         VARCHAR(3),
     EFFECTIVE_MATURITY_YEAR_NO NUMERIC(7,3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     BOOK_VALUE_AMT       NUMERIC(18,5),
     CONTRACT_SETTLEMENT_DT DATE,
     PAYMENT_RESET_FREQ_MONTH_NO NUMERIC(10),
     SPREAD_RT            NUMERIC(9,4),
     DISCOUNT_SPREAD_RT   NUMERIC(9,4),
     INITIAL_CONTRACT_RT  NUMERIC(9,4),
     PRINCIPAL_PAYMENT_AMT NUMERIC(18,5),
     ANNUITY_PAYMENT_AMT  NUMERIC(18,5),
     YIELD_RT             NUMERIC(9,4),
     CARRYING_COST_RT     NUMERIC(9,4),
     COMPOUNDING_CD       VARCHAR(10),
     ACCRUED_BASE_AMT     NUMERIC(18,5),
     PRINCIPAL_PAYMENT_TYPE_CD VARCHAR(3),
     SETTLEMENT_TYPE_CD   VARCHAR(3),
     QUANTO_FEATURE_RK    NUMERIC(10),
     ANNUITY_PAYMENT_TYPE_CD VARCHAR(3),
     ARREARS_PAYMENT_CD   VARCHAR(3),
     CONVEXITY_ADJUSTMENT_FLG CHARACTER(1),
     COUPON_GRACE_DAYS_CNT NUMERIC(6),
     INTEREST_PAYMENT_TIME_FREQ_CD VARCHAR(3),
     INTERNAL_REPORTING_CATEGORY_CD VARCHAR(3),
     PAYMENT_TIME_FREQUENCY_CD VARCHAR(3),
     UP_FRONT_FEE_AMT     NUMERIC(18,5),
     UP_FRONT_FEE_DT      DATE,
     CAPITAL_CLASS_TYPE_CD VARCHAR(3),
     VALUE_SCALING_FACTOR_RT NUMERIC(9,4),
     FIRST_INTEREST_PAYMENT_DT DATE,
     HOLIDAY_DATE_ROLL_CONV_CD VARCHAR(3),
     LAST_INTEREST_PAYMENT_DT DATE,
     LIQUIDITY_HORIZON_MONTH_CNT NUMERIC(6),
     WEEKEND_DATE_ROLL_CONV_CD VARCHAR(3),
     CIC_CD               VARCHAR(4),
     UNWIND_TRIGGER_EVENT_TYPE_CD VARCHAR(3),
     UNWIND_MAX_LOSS_AMT  NUMERIC(18,5),
     PAYMENT_DAY_OF_MONTH_NO NUMERIC(3),
     INT_PAYMENT_DAY_OF_MONTH_NO NUMERIC(3),
     RESET_DAY_OF_MONTH_NO NUMERIC(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE FINANCIAL_INSTRUMENT_ASSOC (
     FINANCIAL_INSTRUMENT_ASSOC_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     FINANCIAL_INSTR_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     UNDERLYING_INSTRUMENT_UNITS_NO NUMERIC(12,2),
     UNDERLYING_WEIGHT_RT NUMERIC(9,4),
     REFERENCE_FINANCIAL_INSTR_RK NUMERIC(10),
     REFERENCE_ACCOUNT_RK NUMERIC(10),
     REFERENCE_CREDIT_FACILITY_RK NUMERIC(10),
     STATISTIC_RELATIONSHIP_TYPE_CD VARCHAR(3),
     PHYSICAL_ASSET_RK    NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTRUMENT_ASSOC_PI (FINANCIAL_INSTRUMENT_ASSOC_RK)
;
CREATE TABLE FINANCIAL_INSTRUMENT_CALC_SPEC (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     MTM_TIME_FREQUENCY_CD VARCHAR(3),
     REGULATORY_PRODUCT_CD VARCHAR(3),
     HOLDING_PERIOD_DAYS_CNT NUMERIC(6),
     HAIRCUT_SET_ID       VARCHAR(32),
     HAIRCUT_VALUE_RT     NUMERIC(9,4),
     RISK_WEIGHT_PCT      NUMERIC(9,4),
     ADD_ON_PCT           NUMERIC(9,4),
     QUALIFYING_DEBT_SECURITY_FLG CHARACTER(1),
     LIQUIDITY_HAIRCUT_SET_ID VARCHAR(32),
     DELTA_GAMMA_APPROXIMATION_FLG CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FORWARD_RATE_AGREEMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE FINANCIAL_INSTRUMENT_CHNG (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     IN_DEFAULT_FLG       CHARACTER(1),
     ACCRUED_INTEREST_AMT NUMERIC(18,5),
     ACCRUED_BASE_INTEREST_AMT NUMERIC(18,5),
     PRINCIPAL_BALANCE_AMT NUMERIC(18,5),
     MTM_VALUE_TO_SELL_AMT NUMERIC(18,5),
     MTM_VALUE_TO_BUY_AMT NUMERIC(18,5),
     EXPECTED_LOSS_PCT    NUMERIC(9,4),
     UNDERLYING_CORRELATION_RT NUMERIC(9,4),
     SWAP_INFLOW_PERIOD_TO_DATE_AMT NUMERIC(18,5),
     SWAP_OUTFLW_PERIOD_TO_DATE_AMT NUMERIC(18,5),
     PREM_PAID_PERIOD_TO_DATE_AMT NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTRUMENT_CHNG_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE FINANCIAL_INSTRUMENT_CLASS (
     FINANCIAL_INSTRUMENT_CLASS_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_CLASS_DES VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTRUMENT_CLASS_PI (FINANCIAL_INSTRUMENT_CLASS_CD)
;
CREATE TABLE FINANCIAL_INSTRUMENT_ISSUE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     ISSUE_CD             VARCHAR(15)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ISSUE_TYPE_CD        VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     MARKET_ENTRY_PLACE_NM VARCHAR(40),
     EXCHANGE_CD          VARCHAR(10),
     MARKET_INDEX_CD      VARCHAR(10),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTRUMENT_ISSUE_PI (FINANCIAL_INSTRUMENT_RK,ISSUE_CD,ISSUE_TYPE_CD)
;
CREATE TABLE FINANCIAL_INSTRUMENT_TYPE (
     FINANCIAL_INSTRUMENT_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_TYPE_DESC VARCHAR(100),
     MINIMUM_DAYS_HOLDING_PERIOD_CD VARCHAR(3),
     FINANCIAL_INSTRUMENT_CLASS_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTRUMENT_TYPE_PI (FINANCIAL_INSTRUMENT_TYPE_CD)
;
CREATE TABLE FINANCIAL_INSTRUMENT_VAR (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     CONFIDENCE_LEVEL_RT  NUMERIC(9,4)     NOT NULL,
     TIME_UOM_CD          VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     TIME_UOM_AMT         NUMERIC(18,5),
     VAR_RETURN_AMT       NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     NETTING_SET_RK       NUMERIC(10),
     VAR_RT               NUMERIC(9,4),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTRUMENT_VAR_PI (FINANCIAL_INSTRUMENT_RK,CONFIDENCE_LEVEL_RT,TIME_UOM_CD)
;
CREATE TABLE FINANCIAL_INSTR_TRANSFER_RATE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     TRANSFER_RATE_TYPE_CD VARCHAR(3)     NOT NULL,
     TRANSFER_METHOD_CD   VARCHAR(3)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP     NOT NULL,
     EFFECTIVE_TO_DTTM    TIMESTAMP     NOT NULL,
     TRANSFER_RT          NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTR_TRANSFER_RA_PI (FINANCIAL_INSTRUMENT_RK,TRANSFER_RATE_TYPE_CD,TRANSFER_METHOD_CD,EFFECTIVE_FROM_DTTM)
;
CREATE TABLE FINANCIAL_INST_CREDIT_ASSESS (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     ASSESSMENT_DT        DATE     NOT NULL,
     ASSESSMENT_MODEL_RK  NUMERIC(10)     NOT NULL,
     ASSESSMENT_RESULT_TYPE_CD VARCHAR(3)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10),
     OVERRIDE_RATING_FLG  CHARACTER(1),
     ASSESSMENT_RESULT_RT NUMERIC(9,4),
     EQUIV_INSTRUMENT_USED_FLG CHARACTER(1),
     EQUIVALENT_INSTRUMENT_TXT VARCHAR(100),
     CR_MITIGANT_ADJUSTED_FLG CHARACTER(1),
     PRINCIPAL_ONLY_FLG   CHARACTER(1),
     ASSESS_CHANGE_REASON_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATING_GRADE_PI (FINANCIAL_INSTRUMENT_RK,ASSESSMENT_DT,ASSESSMENT_MODEL_RK,ASSESSMENT_RESULT_TYPE_CD)
;
CREATE TABLE FINANCIAL_POSITION (
     FINANCIAL_POSITION_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FINANCIAL_POSITION_ID VARCHAR(32)     NOT NULL,
     TOTAL_LIMIT_AMT      NUMERIC(18,5),
     MOST_RECENT_DEAL_DTTM TIMESTAMP,
     SOURCE_SYSTEM_CD     VARCHAR(3),
     MOST_RECENT_DEAL_AMT NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     EFFECTIVE_FROM_DT    DATE,
     EXPIRATION_DT        DATE,
     FINANCIAL_POSITION_STATUS_CD VARCHAR(3),
     HOLDINGS_NO          NUMERIC(18,5),
     BUY_PRICE_AMT        NUMERIC(18,5),
     SELL_PRICE_AMT       NUMERIC(18,5),
     POSITION_PAYMENT_LEG_CD VARCHAR(3),
     PORTFOLIO_ID         VARCHAR(32),
     COUNTERPARTY_RK      NUMERIC(10),
     CUSTODIAN_COUNTERPARTY_RK NUMERIC(10),
     OWNED_BY_INTERNAL_ORG_RK NUMERIC(10),
     NETTING_SET_RK       NUMERIC(10),
     FINANCIAL_POSITION_TYPE_CD VARCHAR(5),
     EQUITY_IN_LEG_PROGRAM_FLG CHARACTER(1),
     OFF_BALANCE_SHEET_TYPE_CD VARCHAR(3),
     SECURITIZATION_POOL_RK NUMERIC(10),
     GL_ACCOUNT_RK        NUMERIC(10),
     EQUITY_POSITION_TYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     EXPOSURE_AT_DEFAULT_AMT NUMERIC(18,5),
     ADJUSTMENT_TO_EXPOSURE_AMT NUMERIC(18,5),
     SEGMENT_RK           NUMERIC(10),
     CONTRACT_DELIVERY_DT DATE,
     REPO_TRANSACTION_FLG CHARACTER(1),
     FINANCIAL_FUND_RK    NUMERIC(10),
     PHYSICAL_ASSET_RK    NUMERIC(10),
     CAPITAL_ALLOCATION_RK NUMERIC(10),
     CAPITAL_COST_RK      NUMERIC(10),
     MARGIN_AGREEMENT_RK  NUMERIC(10),
     CREDIT_FACILITY_RK   NUMERIC(10),
     EXPENSE_ALLOCATION_RK NUMERIC(10),
     FINANCIAL_POSITION_ROLE_CD VARCHAR(3),
     LIQUIDITY_CATEGORY_TYPE_CD VARCHAR(3),
     CONCENTRATION_RSK_FLG CHARACTER(1),
     LIQUIDITY_HORIZON_MONTH_CNT NUMERIC(6),
     RECEIVABLES_POOL_RK  NUMERIC(10),
     UNENCUMBERED_FLG     CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_POSITION_PI (FINANCIAL_POSITION_RK)
;
CREATE TABLE FINANCIAL_POSITION_CR_MITIGANT (
     CREDIT_RISK_MITIGANT_RK NUMERIC(10)     NOT NULL,
     FINANCIAL_POSITION_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     MATURITY_DT          DATE,
     TOTAL_VALUE_AMT      NUMERIC(18,5),
     SOURCE_DOCUMENT_TXT  VARCHAR(100),
     CR_MITIGANT_RANK_NO  NUMERIC(10),
     USED_TO_COV_RISK_TYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_POSITION_CR_MITIG_PI (CREDIT_RISK_MITIGANT_RK)
;
CREATE TABLE FINANCIAL_REPORTING_DATA (
     INTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EFFECTIVE_TO_DTTM    TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ELIGC_INSTR_NONINN_LIMIT_AMT NUMERIC(18,5),
     ELIGC_INSTR_INN_LIMIT_AMT NUMERIC(18,5),
     ELIGC_PAID_UP_CAPITAL_AMT NUMERIC(18,5),
     ELIGC_SHARE_VALUE_AMT NUMERIC(18,5),
     ELIGC_SHARE_PREMIUM_AMT NUMERIC(18,5),
     ELIGC_INSTR_OTHER_AMT NUMERIC(18,5),
     ER_RESERVES_AMT      NUMERIC(18,5),
     ER_MINORITY_INTEREST_AMT NUMERIC(18,5),
     ER_INSTR_NONINN_LIMIT_AMT NUMERIC(18,5),
     ER_INSTR_INN_LIMIT_AMT NUMERIC(18,5),
     ER_IP_CURR_YEAR_AMT  NUMERIC(18,5),
     ER_IP_CURR_YEAR_VAL_AMT NUMERIC(18,5),
     ER_ML_INCOME_CURR_YEAR_AMT NUMERIC(18,5),
     ER_ML_INCOME_CURR_YEAR_VAL_AMT NUMERIC(18,5),
     ER_ML_IP_CURR_YEAR_AMT NUMERIC(18,5),
     ER_ML_IP_CURR_YEAR_VAL_AMT NUMERIC(18,5),
     ER_ML_IP_INC_SEC_AMT NUMERIC(18,5),
     ER_VD_AFS_EQUITY_AMT NUMERIC(18,5),
     ER_VD_AFS_EQUITY_ADJ_AMT NUMERIC(18,5),
     ER_VD_AFS_RECEIVABLES_AMT NUMERIC(18,5),
     ER_VD_AFS_RECEIVABLES_ADJ_AMT NUMERIC(18,5),
     ER_VD_AFS_AMT        NUMERIC(18,5),
     ER_VD_AFS_ADJ_AMT    NUMERIC(18,5),
     ER_VD_FVO_FIN_LIAB_AMT NUMERIC(18,5),
     ER_VD_FVO_FIN_LIAB_ADJ_AMT NUMERIC(18,5),
     ER_VD_NONAFS_AMT     NUMERIC(18,5),
     ER_VD_NONAFS_ADJ_AMT NUMERIC(18,5),
     ER_VD_PROPERTY_AMT   NUMERIC(18,5),
     ER_VD_PROPERTY_ADJ_AMT NUMERIC(18,5),
     ER_VD_PPE_AMT        NUMERIC(18,5),
     ER_VD_PPE_ADJ_AMT    NUMERIC(18,5),
     ER_VD_ER_AMT         NUMERIC(18,5),
     ER_VD_OTHER_ADJ_AMT  NUMERIC(18,5),
     BR_FUND_AMT          NUMERIC(18,5),
     CSF_INSTR_NONINN_LIMIT_AMT NUMERIC(18,5),
     CSF_INSTR_INN_LIMIT_AMT NUMERIC(18,5),
     CSF_INSTR_IAS_AMT    NUMERIC(18,5),
     CSF_OTHER_AMT        NUMERIC(18,5),
     ODF_INTNGBL_ASSETS_AMT NUMERIC(18,5),
     ODF_INSTR_NONINN_LIMIT_AMT NUMERIC(18,5),
     ODF_INSTR_INN_LIMIT_AMT NUMERIC(18,5),
     ODF_CSF_IAS_OTHER_AMT NUMERIC(18,5),
     ODF_CSF_OTHER_AMT    NUMERIC(18,5),
     AOF_VD_AFS_ADJ_AMT   NUMERIC(18,5),
     AOF_VD_AFS_OTHER_ADJ_AMT NUMERIC(18,5),
     AOF_VD_INVS_ADJ_AMT  NUMERIC(18,5),
     AOF_VD_PPE_ADJ_AMT   NUMERIC(18,5),
     AOF_VD_OTHER_ADJ_AMT NUMERIC(18,5),
     AOF_REVAL_RESERVES_AMT NUMERIC(18,5),
     AOF_VCR_STD_ADJ_AMT  NUMERIC(18,5),
     AOF_OTHER_AMT        NUMERIC(18,5),
     AOF_SID_INSTR_OTHER_AMT NUMERIC(18,5),
     AOF_IRBP_EXCESS_AMT  NUMERIC(18,5),
     AOF_CSF_FUND_AMT     NUMERIC(18,5),
     AOF_COMMIT_CREDIT_INST_AMT NUMERIC(18,5),
     AOF_FIX_TERM_SHARES_AMT NUMERIC(18,5),
     AOF_LOAN_CAPITAL_AMT NUMERIC(18,5),
     AOF_SUPPL_AMT        NUMERIC(18,5),
     AOF_EXCESS_LIMIT_SUPPL_AMT NUMERIC(18,5),
     AOF_EXCESS_LIMIT_FUND_AMT NUMERIC(18,5),
     AOF_CSF_DED_OTHER_AMT NUMERIC(18,5),
     DOF_FUND_AMT         NUMERIC(18,5),
     DOF_ADDL_FUND_AMT    NUMERIC(18,5),
     DOF_HOLDINGS_10_CAPITAL_AMT NUMERIC(18,5),
     DOF_SUBORD_CLAIM_AMT NUMERIC(18,5),
     DOF_EXCESS_LIMIT_10_CAP_AMT NUMERIC(18,5),
     DOF_INSTR_AMT        NUMERIC(18,5),
     DOF_INSTR_OTHER_AMT  NUMERIC(18,5),
     DOF_CSF_ORIGINAL_AMT NUMERIC(18,5),
     DOF_SECU_EXPO_RWA_AMT NUMERIC(18,5),
     DOF_IRB_PROV_SF_AMT  NUMERIC(18,5),
     DOF_QUAL_INTEREST_NONFIN_AMT NUMERIC(18,5),
     DOF_FREE_DELIV_AMT   NUMERIC(18,5),
     DOF_CSF_OTHER_AMT    NUMERIC(18,5),
     TOF_EXCESS_LIMIT_ADDL_AMT NUMERIC(18,5),
     TOF_PROFITS_AMT      NUMERIC(18,5),
     TOF_ST_SUBORD_CAPITAL_AMT NUMERIC(18,5),
     TOF_ILLIQUID_ASSEST_AMT NUMERIC(18,5),
     TOF_EXCESS_LIMIT_SPCFC_AMT NUMERIC(18,5),
     TOF_CSF_DED_AMT      NUMERIC(18,5),
     DTF_CSF_TOTAL_AMT    NUMERIC(18,5),
     DTF_INSURANCE_AMT    NUMERIC(18,5),
     M_IRBP_AMT           NUMERIC(18,5),
     M_IRBP_GEN_COLL_IMP_AMT NUMERIC(18,5),
     M_IRBP_SPCFC_INDV_IMP_AMT NUMERIC(18,5),
     M_IRBP_REVAL_RESERVES_AMT NUMERIC(18,5),
     M_IRBP_EXPEC_LOSS_AMT NUMERIC(18,5),
     M_LOAN_CAPITAL_AMT   NUMERIC(18,5),
     M_INITIAL_CAPITAL_REQM_AMT NUMERIC(18,5),
     SETTLEMENT_RISK_AMT  NUMERIC(18,5),
     TCR_TRD_DEBT_INSTR_AMT NUMERIC(18,5),
     TCR_EQUITY_AMT       NUMERIC(18,5),
     TCR_FOREIGN_EXCHANGE_AMT NUMERIC(18,5),
     TCR_COMMODITIES_AMT  NUMERIC(18,5),
     CAPITAL_REQM_FIXED_AMT NUMERIC(18,5),
     OCR_FLOOR_AMT        NUMERIC(18,5),
     OCR_INVESTMENT_45B_AMT NUMERIC(18,5),
     OCR_CSF_OTHER_AMT    NUMERIC(18,5),
     M_SURPLUS_FUND_AMT   NUMERIC(18,5),
     M_SURPLUS_SOLV_IDX_RATIO_AMT NUMERIC(18,5),
     IA_CAPITAL_AMT       NUMERIC(18,5),
     IA_CAPITAL_NEEDS_AMT NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_REPORTING_DATA_PI (INTERNAL_ORG_RK,EFFECTIVE_FROM_DTTM)
;
CREATE TABLE FIN_ACCT_IRREG_CASHFLW_PAYMENT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     PAYMENT_DT           DATE     NOT NULL,
     PAYMENT_TYPE_CD      VARCHAR(3)     NOT NULL,
     PAYMENT_AMT          NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FIN_ACCT_IRREG_CASHFLW_PAYM_PI (ACCOUNT_RK,PAYMENT_DT,PAYMENT_TYPE_CD)
;
CREATE TABLE FLEET_DETAILS (
     FLEET_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FLEET_ID             VARCHAR(32)     NOT NULL,
     VEH_TYPE_CD          VARCHAR(3),
     NUM_VEHS             NUMERIC(6),
     NUM_VEHS_LEASED      NUMERIC(6),
     NUM_VEHS_OWNED       NUMERIC(6),
     NUM_VEHS_INTERMEDIATE_RADIUS NUMERIC(6),
     NUM_VEHS_LOCAL_RADIUS NUMERIC(6),
     NUM_VEHS_LONG_DISTANCE_RADIUS NUMERIC(6),
     NUM_VEHS_LONG_TERM_LEASED NUMERIC(6),
     NUM_VEHS_NON_OWNED   NUMERIC(6),
     NUM_VEHS_TRIP_LEASED NUMERIC(6),
     PROPERTY_HAULED_DESC VARCHAR(255),
     RADIUS_USE           NUMERIC(14,4),
     TERRITORY_CD         VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXFLEET_DETAILS (FLEET_RK)
;
CREATE TABLE FOREIGN_TRAVEL_DETAILS (
     INSURED_RK           NUMERIC(10)     NOT NULL,
     COUNTRY_CD           VARCHAR(3)     NOT NULL,
     BUSINESS_TRAVEL_IND  CHARACTER(1),
     PLEASURE_TRAVEL_IND  CHARACTER(1),
     TRAVEL_TRANSPORTATION_CD VARCHAR(3),
     TRAVEL_AVG_TIME      NUMERIC(9),
     TRAVEL_MAX_TIME      NUMERIC(9),
     LAST_TRIP_DT         DATE,
     TRAVEL_ENVIRONMENT_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FOREIGN_TRAVEL_DETAILS_PI (INSURED_RK,COUNTRY_CD)
;
CREATE TABLE FORWARD_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FORWARD_TYPE_CD      VARCHAR(3),
     CONVERSION_FACTOR_RT NUMERIC(9,4),
     VALUE_SCALING_FACTOR_RT NUMERIC(9,4),
     FORWARD_STRIKE_VALUE NUMERIC(18,5),
     FORWARD_STRIKE_VALUE_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     FORWARD_STRIKE_QUOTE_CD VARCHAR(3))
     PRIMARY INDEX FORWARD_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE FORWARD_INSTRUMENT_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FORWARD_INSTRUMENT_QUOTE_PI (QUOTE_DTTM,FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE FRA_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FIXING_DT            DATE,
     BUY_FLG              CHARACTER(1),
     CONTRACT_RT          NUMERIC(14,6),
     NOTIONAL_AMT         NUMERIC(18,5),
     NOTIONAL_CURRENCY_CD VARCHAR(3),
     FRA_INSTRUMENT_TYPE_CD VARCHAR(3),
     REFERENCE_RISK_FACTOR_ID VARCHAR(32),
     UNDERLYING_RATE_TERM_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FRA_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE FRA_INSTRUMENT_LEG (
     FRA_INSTRUMENT_LEG_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FRA_LEG_CD           VARCHAR(3),
     FRA_LEG_TYPE_CD      VARCHAR(3),
     FRA_LEG_FINANCIAL_INSTR_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FRA_INSTRUMENT_LEG_PI (FRA_INSTRUMENT_LEG_RK)
;
CREATE TABLE FRA_INSTRUMENT_QUOTE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FRA_INSTRUMENT_QUOTE_PI (FINANCIAL_INSTRUMENT_RK,QUOTE_DTTM)
;
CREATE TABLE FUND_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FUND_INSTRUMENT_NM   VARCHAR(40),
     FUND_ID              VARCHAR(32),
     FUND_FAMILY_NM       VARCHAR(40),
     MANAGER_NM           VARCHAR(40),
     UCITS_FLG            CHARACTER(1),
     MANAGEMENT_FEE_PCT   NUMERIC(9,4),
     NET_ASSET_VALUE_AMT  NUMERIC(18,5),
     FUND_INSTRUMENT_TYPE_CD VARCHAR(3),
     VALUATION_TIME_FREQ_CD VARCHAR(3),
     LEVEL_OF_LOOKTHROUGH_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FUND_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE FUND_INSTRUMENT_QUOTE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FUND_INSTRUMENT_QUOTE_PI (FINANCIAL_INSTRUMENT_RK,QUOTE_DTTM)
;
CREATE TABLE FX_FORWARD_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     SELL_CURRENCY_CD     VARCHAR(3)     NOT NULL,
     BUY_CURRENCY_CD      VARCHAR(3)     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FX_FORWARD_QUOTE_PI (QUOTE_DTTM,MARKET_CD,SELL_CURRENCY_CD,BUY_CURRENCY_CD)
;
CREATE TABLE FX_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FX_INSTRUMENT_TYPE_CD VARCHAR(3),
     BUY_CURRENCY_CD      VARCHAR(3)     NOT NULL,
     SELL_CURRENCY_CD     VARCHAR(3)     NOT NULL,
     BUY_CURR_DAY_BASIS_CD VARCHAR(10),
     SELL_CURR_DAY_BASIS_CD VARCHAR(10),
     SELL_CCY_FINANCIAL_CALENDAR_RK NUMERIC(10),
     BUY_CCY_FINANCIAL_CALENDAR_RK NUMERIC(10),
     BUY_CURR_COMPOUNDING_CD VARCHAR(10),
     SELL_CURR_COMPOUNDING_CD VARCHAR(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FX_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE FX_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     BUY_CURRENCY_CD      VARCHAR(3)     NOT NULL,
     SELL_CURRENCY_CD     VARCHAR(3)     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     BID_RT               NUMERIC(18,5),
     ASK_RT               NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FX_QUOTE_PI (QUOTE_DTTM,MARKET_CD,BUY_CURRENCY_CD,SELL_CURRENCY_CD)
;
CREATE TABLE FX_VOLATILITY_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     SELL_CURRENCY_CD     VARCHAR(3)     NOT NULL,
     BUY_CURRENCY_CD      VARCHAR(3)     NOT NULL,
     BID_VOLATILITY_RT    NUMERIC(11,6),
     ASK_VOLATILITY_RT    NUMERIC(11,6),
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FX_VOLATILITY_QUOTE_PI (QUOTE_DTTM,MARKET_CD,SELL_CURRENCY_CD,BUY_CURRENCY_CD)
;
CREATE TABLE GARAGE_TYPE_DETAILS (
     GARAGE_TYPE_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     GARAGE_TYPE_CD       VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     ATTACHED_IND         CHARACTER(1),
     BASEMENT_UNDER_GARAGE_IND CHARACTER(1),
     NUM_GARAGES          NUMERIC(6),
     NUM_VEHS             NUMERIC(6),
     SURFACE_AREA         NUMERIC(14,4),
     ESTIMATED_REPL_COST_AMT NUMERIC(18,5),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GARAGE_TYPE_DETAILS_PI (GARAGE_TYPE_RK)
;
CREATE TABLE GENERAL_HEDGING_SET (
     HEDGING_SET_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     HEDGING_SET_DESC     VARCHAR(100),
     HEDGING_SET_ID       VARCHAR(20),
     HEDGING_SET_TYPE_CD  VARCHAR(3),
     CURRENCY_CD          VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GENERAL_HEDGING_SET_PI (HEDGING_SET_RK)
;
CREATE TABLE GENERAL_INSURANCE_CLAIM (
     CLAIM_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INSURANCE_CLAIM_NO   VARCHAR(32)     NOT NULL,
     CLAIMANT_RK          NUMERIC(10)     NOT NULL,
     INTIMATION_DT        DATE,
     CLAIM_STATUS_CD      VARCHAR(3),
     CLAIM_SETTLEMENT_TYPE_CD VARCHAR(3),
     CLAIM_OPEN_DTTM      TIMESTAMP,
     CLAIM_CLOSE_DTTM     TIMESTAMP,
     BLAME_CD             VARCHAR(3),
     LOSS_REASON_CD       VARCHAR(3),
     INCIDENT_RK          NUMERIC(10)     NOT NULL,
     CATASTROPHE_RK       NUMERIC(10),
     FRAUDULENT_CLAIM_IND CHARACTER(1),
     CLAIM_STATUS_CHANGE_DTTM TIMESTAMP,
     CLAIM_STATUS_REASON_CD VARCHAR(3),
     CLAIM_TYPE_CD        VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     PRODUCER_RK          NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXINSURANCE_CLAIM (CLAIM_RK)
;
CREATE TABLE GENERAL_INSURANCE_PRODUCT (
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INSURANCE_PRODUCT_CD VARCHAR(3)     NOT NULL,
     INSURANCE_PRODUCT_NM VARCHAR(50),
     INTRODUCTION_DT      DATE,
     PRODUCT_TYPE_CD      VARCHAR(3),
     SALE_EFFECTIVE_DT    DATE,
     SALE_EXPIRATION_DT   DATE,
     PRODUCT_CATEGORY_RK  NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INSURANCE_PRODUCT (INSURANCE_PRODUCT_RK,LOB_RK)
;
CREATE TABLE GENERAL_POLICY_TRANS (
     POLICY_TRANS_ID      VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     REFERENCE_NO         VARCHAR(32),
     TRANS_TYPE_CD        VARCHAR(3),
     TOTAL_TRANS_AMT      NUMERIC(18,5),
     PAYMENT_METHOD_CD    VARCHAR(3),
     TRANS_DT             DATE,
     TRANS_CURRENCY_CD    VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GENERAL_POLICY_TRANS_PI (POLICY_TRANS_ID,SOURCE_SYSTEM_CD)
;
CREATE TABLE GENERAL_POLICY_TRANS_LINE_ITEM (
     POLICY_TRANS_LINE_ITEM_NO NUMERIC(9)     NOT NULL,
     POLICY_TRANS_ID      VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     AMT_TYPE_CD          VARCHAR(3),
     LINE_ITEM_TRANS_AMT  NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GENERAL_POLICY_TRANS_LINE_I_PI (POLICY_TRANS_LINE_ITEM_NO,POLICY_TRANS_ID,SOURCE_SYSTEM_CD,POLICY_RK)
;
CREATE TABLE GENERAL_UNIT_OF_EXPOSURE (
     UOE_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     PRODUCT_COVERAGE_RK  NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     SUBJECT_OF_INS_TYPE_CD VARCHAR(3),
     COVERAGE_CD          VARCHAR(3),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     PREMIUM_BASIS_CD     VARCHAR(3),
     REASON_CD            VARCHAR(3)     NOT NULL,
     INSURED_AMT          NUMERIC(18,5),
     BASE_PREMIUM_AMT     NUMERIC(18,5),
     PREMIUM_AMT          NUMERIC(18,5),
     NET_PREMIUM_AMT      NUMERIC(18,5),
     COMMISSION_AMT       NUMERIC(18,5),
     GEN_COVERAGE_STATUS_CD VARCHAR(3),
     SOLVENCY2_LEVEL_1_SEGMENT_CD VARCHAR(3),
     SOLVENCY2_LEVEL_2_SEGMENT_CD VARCHAR(3),
     PROBABLE_MAX_LOSS_PCT NUMERIC(9,4),
     UNDERWRITING_MODEL_TYPE_CD VARCHAR(3),
     UNDERWRITING_MODEL_AMT NUMERIC(18,5),
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXUNIT_OF_EXPOSURE (UOE_RK)
;
CREATE TABLE GLASS_SIGN_TYPE_DETAILS (
     SCHEDULE_TYPE_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SCHEDULE_TYPE_CD     VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     NUM_PLATES           NUMERIC(6),
     PLATE_SIZE_AREA      NUMERIC(14,4),
     KIND_GLASS_CLASS_CD  VARCHAR(3),
     NUM_PLATES_LARGE_LOSS_PAYMENT NUMERIC(6),
     INSIDE_OUTSIDE_SIGN_CD VARCHAR(3),
     GLASS_BLDG_INTR_IND  CHARACTER(1),
     ITEM_VALUE_AMT       NUMERIC(18,5),
     PAINTED_PLATES_CD    VARCHAR(3),
     BLDG_USE_CD          VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GLASS_SIGN_TYPE_DETAILS_PI (SCHEDULE_TYPE_RK)
;
CREATE TABLE GL_ACCOUNT (
     GL_ACCOUNT_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     GL_ACCOUNT_ID        VARCHAR(32)     NOT NULL,
     GL_ACCOUNT_TYPE_CD   VARCHAR(3),
     GL_ACCOUNT_NM        VARCHAR(50),
     GL_ACCOUNT_DESC      VARCHAR(255),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     OWN_FUND_TYPE_CD     VARCHAR(3),
     TIER_NO              NUMERIC(4),
     CTA_ACCOUNT_FLG      CHARACTER(1),
     INTERCOMPANY_ACCOUNT_FLG CHARACTER(1),
     RETAINED_EARNINGS_FLG CHARACTER(1),
     CONTROL_ACCOUNT_FLG  CHARACTER(1),
     EXCHANGE_RATE_TYPE_CD VARCHAR(3),
     NORMAL_BALANCE_CD    VARCHAR(3),
     FINANCIAL_FUND_RK    NUMERIC(10),
     INTERNAL_ORG_RK      NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GL_ACCOUNT_PI (GL_ACCOUNT_RK)
;
CREATE TABLE GL_ACCOUNT_ASSOC (
     GL_ACCOUNT_RK        NUMERIC(10)     NOT NULL,
     PARENT_GL_ACCOUNT_RK NUMERIC(10)     NOT NULL,
     GL_ACCOUNT_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GL_ACCOUNT_ASSOC_PI (GL_ACCOUNT_RK,PARENT_GL_ACCOUNT_RK,GL_ACCOUNT_ASSOC_TYPE_CD)
;
CREATE TABLE GL_ACCOUNT_BALANCE (
     GL_ACCOUNT_RK        NUMERIC(10)     NOT NULL,
     ACCOUNT_PERIOD_RK    NUMERIC(10)     NOT NULL,
     GL_BALANCE_REPT_CURRENCY_CD VARCHAR(3)     NOT NULL,
     REPORTING_METHOD_CD  VARCHAR(3)     NOT NULL,
     AS_OF_DT             DATE     NOT NULL,
     BALANCE_AMT          NUMERIC(18,5),
     GL_BALANCE_BASE_CURRENCY_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GL_ACCOUNT_BALANCE_PI (GL_ACCOUNT_RK,ACCOUNT_PERIOD_RK,GL_BALANCE_REPT_CURRENCY_CD,REPORTING_METHOD_CD)
;
CREATE TABLE GL_JRNL (
     GL_JRNL_ID           VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     GL_JRNL_DT           DATE,
     GL_JRNL_DESC         VARCHAR(255),
     REVERSED_GL_JRNL_ID  VARCHAR(32),
     REVERSAL_REASON_CD   VARCHAR(3),
     REVERSAL_DESC        VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GL_JRNL_PI (GL_JRNL_ID)
;
CREATE TABLE GL_JRNL_DETAILS (
     GL_JRNL_ID           VARCHAR(32)     NOT NULL,
     GL_JRNL_LINE_ITEM_ID VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     GL_ACCOUNT_RK        NUMERIC(10)     NOT NULL,
     TRANS_DT             DATE,
     TRANS_AMT            NUMERIC(18,5),
     ACCOUNT_PERIOD_RK    NUMERIC(10)     NOT NULL,
     COST_CENTER_RK       NUMERIC(10),
     PROFIT_CENTER_RK     NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GL_JRNL_DETAILS_PI (GL_JRNL_ID,GL_JRNL_LINE_ITEM_ID,SOURCE_SYSTEM_CD,GL_ACCOUNT_RK)
;
CREATE TABLE GL_SEGMENT_BALANCE (
     GL_ACCOUNT_RK        NUMERIC(10)     NOT NULL,
     ACCOUNT_PERIOD_RK    NUMERIC(10)     NOT NULL,
     REPORTING_METHOD_CD  VARCHAR(3)     NOT NULL,
     GL_SEGMENT_GROUP_RK  NUMERIC(10)     NOT NULL,
     GL_BALANCE_REPT_CURRENCY_CD VARCHAR(3)     NOT NULL,
     SEGMENT_BALANCE_AMT  NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GL_SEGMENT_BALANCE_PI (GL_ACCOUNT_RK,ACCOUNT_PERIOD_RK,REPORTING_METHOD_CD,GL_SEGMENT_GROUP_RK,GL_BALANCE_REPT_CURRENCY_CD)
;
CREATE TABLE GL_SEGMENT_PARAMETER (
     PARAM_VALUE_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PARAMETER_NM         VARCHAR(32),
     PARAMETER_DESC       VARCHAR(100),
     PARAMETER_VALUE      VARCHAR(100),
     PARAMETER_VALUE_TYPE_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GL_SEGMENT_PARAMETER_PI (PARAM_VALUE_RK)
;
CREATE TABLE GL_SEGMENT_PARAM_GROUP (
     GL_SEGMENT_GROUP_RK  NUMERIC(10)     NOT NULL,
     PARAM_VALUE_RK       NUMERIC(10)     NOT NULL,
     GL_SEGMENT_GROUP_ID  VARCHAR(32),
     GL_SEGMENT_GROUP_DESC VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GL_SEGMENT_PARAM_GROUP_PI (GL_SEGMENT_GROUP_RK)
;
CREATE TABLE GUARANTEE (
     GUARANTEE_RK         NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     GUARANTEE_ID         VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3),
     VALUATION_DT         DATE,
     COUNTERPARTY_RK      NUMERIC(10),
     GUARANTEE_TYPE_CD    VARCHAR(10),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX GUARANTEE_PI (GUARANTEE_RK)
;
CREATE TABLE HAIRCUT_SET (
     HAIRCUT_SET_ID       VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     HAIRCUT_SET_DESC     VARCHAR(100),
     FX_HAIRCUT_FLG       CHARACTER(1),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     LIQUIDITY_FLG        CHARACTER(1),
     ESTIMATION_MODEL_RK  NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX HAIRCUT_SET_PI (HAIRCUT_SET_ID)
;
CREATE TABLE HEALTH_AGREEMENT (
     HEALTH_AGR_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     HEALTH_AGR_ID        VARCHAR(32)     NOT NULL,
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX HEALTH_AGREEMENT_PI (HEALTH_AGR_RK)
;
CREATE TABLE HEATING_UNIT_DETAILS (
     HEATING_UNIT_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     HEATING_UNIT_ID      VARCHAR(32)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     HEATING_UNIT_CD      VARCHAR(3),
     FUEL_TYPE_CD         VARCHAR(3),
     FUEL_STORAGE_LOCATION_DESC VARCHAR(255),
     CERTIFIED_IND        CHARACTER(1),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX HEATING_UNIT_DETAILS_PI (HEATING_UNIT_RK)
;
CREATE TABLE HEDGE (
     HEDGING_FINANCIAL_POSITION_RK NUMERIC(10),
     FINANCIAL_POSITION_RK NUMERIC(10),
     ACCOUNT_RK           NUMERIC(10),
     CREDIT_FACILITY_RK   NUMERIC(10),
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX AK1_HEDGE_UX (ACCOUNT_RK,FINANCIAL_POSITION_RK,HEDGING_FINANCIAL_POSITION_RK)
;
CREATE TABLE HOUSEHOLD (
     HOUSEHOLD_RK         NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     HOUSEHOLD_ID         VARCHAR(32)     NOT NULL,
     HHOLD_TYPE_CD        VARCHAR(3),
     ADDRESS_LINE_1       VARCHAR(64),
     ADDRESS_LINE_2       VARCHAR(64),
     ADDRESS_LINE_3       VARCHAR(64),
     ADDRESS_LINE_4       VARCHAR(64),
     CITY_NM              VARCHAR(100),
     POSTAL_CD            VARCHAR(20),
     COUNTY_NM            VARCHAR(40),
     STATE_REGION_CD      VARCHAR(4),
     PRIMARY_PHONE_NO     VARCHAR(20),
     SECONDARY_PHONE_NO   VARCHAR(20),
     RESIDENCY_LENGTH     NUMERIC(10),
     HHOLD_DO_NOT_MAIL_FLG CHARACTER(1),
     HHOLD_DO_NOT_PHONE_FLG CHARACTER(1),
     HHOLD_DO_NOT_EMAIL_FLG CHARACTER(1),
     HHOLD_DO_NOT_SMS_FLG CHARACTER(1),
     HHOLD_DO_NOT_CONTACT_FLG CHARACTER(1),
     HHOLD_INCOME_AMT     NUMERIC(18,5),
     HHOLD_ANNUAL_FIXED_EXPENSE_AMT NUMERIC(18,5),
     BANK_CREDIT_CARD_FLG CHARACTER(1),
     HHOLD_DEBT_AMT       NUMERIC(18,5),
     HHOLD_FAMILY_FLG     CHARACTER(1),
     HOME_OWNERSHIP_STATUS_CD VARCHAR(3),
     HEAD_OF_HHOLD_GENDER_CD VARCHAR(3),
     INDIVIDUALS_CNT      NUMERIC(6),
     CHILDREN_CNT         NUMERIC(6),
     MIDDLE_SCHOOL_CHILDREN_CNT NUMERIC(6),
     HIGH_SCHOOL_CHILDREN_CNT NUMERIC(6),
     COLLEGE_AGED_CHILDREN_CNT NUMERIC(6),
     HIGHEST_EDUCATION_LEVEL_CD VARCHAR(3),
     RETIRED_ELDERS_CNT   NUMERIC(6),
     NONEARNING_ADULTS_CNT NUMERIC(6),
     HOUSE_SIZE           NUMERIC(14,4),
     HOUSE_BUILT_YR       NUMERIC(4),
     HHOLD_PROPERTY_TYPE_CD VARCHAR(3),
     HHOLD_PROPERTY_VALUE NUMERIC(18,5),
     HHOLD_REPLACEMENT_CONTENT_IND CHARACTER(1),
     HHOLD_STRUCTURE_TYPE_CD VARCHAR(3),
     OLDEST_DEP_ADULT_BIRTH_DT DATE,
     OLDEST_DEP_CHILD_BIRTH_DT DATE,
     YOUNGEST_DEP_ADULT_BIRTH_DT DATE,
     YOUNGEST_DEP_CHILD_BIRTH_DT DATE,
     NO_OF_LICENSED_DRIVERS NUMERIC(9),
     NUM_VEHS             NUMERIC(6),
     COUNTRY_CD           VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX HOUSEHOLD_PI (HOUSEHOLD_RK)
;
CREATE TABLE INCIDENT_DETAILS (
     INCIDENT_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOSS_DT              DATE     NOT NULL,
     LOSS_TM              DATE     NOT NULL,
     INCIDENT_TYPE_CD     VARCHAR(3)     NOT NULL,
     INCIDENT_DESC        VARCHAR(255),
     DAMAGE_DESC          VARCHAR(255),
     WHERE_OCCURRED_DESC  VARCHAR(255),
     ADDRESS_LINE_1       VARCHAR(64),
     ADDRESS_LINE_2       VARCHAR(64),
     ADDRESS_LINE_3       VARCHAR(64),
     ADDRESS_LINE_4       VARCHAR(64),
     CITY_NM              VARCHAR(100),
     POSTAL_CD            VARCHAR(20),
     COUNTY_NM            VARCHAR(40),
     STATE_REGION_CD      VARCHAR(4),
     LOCATION_CD          VARCHAR(3),
     SITE_CD              VARCHAR(3),
     ADDITIONAL_CLAIM_IND CHARACTER(1),
     COUNTRY_CD           VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXINCIDENT_DETAILS (INCIDENT_RK)
;
CREATE TABLE INCOME_OPTIONS (
     INCOME_OPTION_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INCOME_OPTION_CD     VARCHAR(3)     NOT NULL,
     INCOME_OPTION_NM     VARCHAR(40),
     INCOME_OPTION_DESC   VARCHAR(255),
     INCOME_PAYOUT_RK     NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INCOME_OPTIONS_PI (INCOME_OPTION_RK)
;
CREATE TABLE INCOME_PAYOUT_DETAILS (
     INCOME_PAYOUT_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRODUCT_CD           VARCHAR(3)     NOT NULL,
     PAYOUT_TYPE_CD       VARCHAR(3),
     LIQUIDITY_FEATURE_TYPE_CD VARCHAR(3),
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXINCOME_PAYOUT_DETAILS (INCOME_PAYOUT_RK)
;
CREATE TABLE INDEX_QUOTE (
     INDEX_CD             VARCHAR(15)     NOT NULL,
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INDEX_QUOTE_PI (INDEX_CD,QUOTE_DTTM)
;
CREATE TABLE INDEX_VOLATILITY_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     ISSUE_CD             VARCHAR(15)     NOT NULL,
     ASK_PRICE_AMT        NUMERIC(18,5),
     BID_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     ASK_VOLATILITY_RT    NUMERIC(11,6),
     BID_VOLATILITY_RT    NUMERIC(11,6),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INDEX_VOLATILITY_QUOTE_PI (QUOTE_DTTM,MARKET_CD,ISSUE_CD)
;
CREATE TABLE INDIVIDUAL (
     INDIVIDUAL_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     MASTER_INDIVIDUAL_ID VARCHAR(32)     NOT NULL,
     HEAD_OF_HOUSEHOLD_IND CHARACTER(1),
     SALUTATION_TXT       VARCHAR(10),
     TITLE_TXT            VARCHAR(10),
     FIRST_NM             VARCHAR(50),
     MIDDLE_NM            VARCHAR(50),
     LAST_NM              VARCHAR(50),
     BIRTH_DT             DATE,
     MARITAL_STATUS_CD    VARCHAR(3),
     GENDER_CD            VARCHAR(3),
     ETHNICITY_CD         VARCHAR(3),
     COUNTRY_OF_RESIDENCE_CD VARCHAR(3),
     PASSPORT_NO          VARCHAR(32),
     CENTRAL_TAX_NO       VARCHAR(32),
     TAX_BRACKET_CD       VARCHAR(3),
     SOCIAL_SECURITY_NO   VARCHAR(32),
     PRIMARY_LANGUAGE_CD  VARCHAR(3),
     DISABILITY_FLG       CHARACTER(1),
     DISABLED_DEGREE_PCT  NUMERIC(9,4),
     SPECIAL_NEED_CD      VARCHAR(3),
     GEO_DEMOGRAPHIC_CD   VARCHAR(5),
     EDUCATION_LEVEL_CD   VARCHAR(3),
     CREDIT_RATING_CD     VARCHAR(20),
     CHILDREN_CNT         NUMERIC(6),
     YOUNGEST_CHILD_BIRTH_DT DATE,
     ANNUAL_INCOME_AMT    NUMERIC(18,5),
     NUM_VEHS             NUMERIC(6),
     OWN_OR_RENT_CD       VARCHAR(3),
     NET_WORTH_AMT        NUMERIC(18,5),
     DECEASED_FLG         CHARACTER(1),
     DECEASED_DT          DATE,
     SHAREHOLDER_FLG      CHARACTER(1),
     RESIDENT_STATUS_CD   VARCHAR(3),
     STD_OCCUPATION_CD    VARCHAR(3),
     STAFF_FLG            CHARACTER(1),
     PROJECTED_RETIREMENT_AGE NUMERIC(3),
     OCCUPATION_CLASS_CD  VARCHAR(3),
     HOUSEHOLD_RK         NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INDIVIDUAL_PI (INDIVIDUAL_RK)
;
CREATE TABLE INDIVIDUAL_ADDRESS (
     INDIVIDUAL_ADDRESS_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INDIVIDUAL_RK        NUMERIC(10)     NOT NULL,
     ADDRESS_TYPE_CD      VARCHAR(3)     NOT NULL,
     ADDRESS_LINE_1       VARCHAR(64),
     ADDRESS_LINE_2       VARCHAR(64),
     ADDRESS_LINE_3       VARCHAR(64),
     ADDRESS_LINE_4       VARCHAR(64),
     CITY_NM              VARCHAR(100),
     POSTAL_CD            VARCHAR(20),
     COUNTY_NM            VARCHAR(40),
     STATE_REGION_CD      VARCHAR(4),
     OCCUPANCY_YR         NUMERIC(4),
     NON_PHYSICAL_ADDRESS_FLG CHARACTER(1),
     DELIVERY_POINT_ID    VARCHAR(32),
     ADDRESS_QUALITY_CD   VARCHAR(3),
     TELEPHONE_NO         VARCHAR(20),
     MOBILE_PHONE_NO      VARCHAR(20),
     FAX_NO               VARCHAR(20),
     EMAIL_ADDRESS        VARCHAR(100),
     PRIMARY_ADDRESS_FLG  CHARACTER(1),
     COUNTRY_CD           VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INDIVIDUAL_ADDRESS_PI (INDIVIDUAL_ADDRESS_RK)
;
CREATE TABLE INDIVIDUAL_ASSOC (
     INDIVIDUAL_RK        NUMERIC(10)     NOT NULL,
     PARENT_INDIVIDUAL_RK NUMERIC(10)     NOT NULL,
     INDIVIDUAL_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INDIVIDUAL_ASSOC_PI (INDIVIDUAL_RK,PARENT_INDIVIDUAL_RK,INDIVIDUAL_ASSOC_TYPE_CD)
;
CREATE TABLE INQUIRY (
     INQUIRY_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INQUIRY_ID           VARCHAR(32)     NOT NULL,
     INQUIRY_CAT_CD       VARCHAR(3),
     INQUIRY_SUBCAT_CD    VARCHAR(3),
     SERVICE_CHANNEL_CD   VARCHAR(3),
     INQUIRY_DTTM         TIMESTAMP,
     INQUIRY_STATUS_CD    VARCHAR(3),
     STATUS_CHANGE_DT     DATE,
     STATUS_REASON_CD     VARCHAR(3),
     INQUIRY_RESOLUTION_CD VARCHAR(3),
     AFFECTED_POLICY_CNT  NUMERIC(6),
     PRODUCT_TYPE_CD      VARCHAR(3),
     EMPLOYEE_RK          NUMERIC(10),
     INSURANCE_PRODUCT_RK NUMERIC(10),
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INQUIRY_PI (INQUIRY_RK)
;
CREATE TABLE INSURANCE_POLICY (
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     POLICY_NO            VARCHAR(32)     NOT NULL,
     CERTIFICATE_NO       VARCHAR(32),
     ISSUE_TYPE_CD        VARCHAR(3),
     ORIGINAL_POLICY_NO   VARCHAR(32),
     POLICY_VERSION       NUMERIC(4)     NOT NULL,
     ACCOUNT_NO           VARCHAR(32),
     POLICY_TYPE_CD       VARCHAR(3),
     ORIGINAL_INCEPTION_DT DATE     NOT NULL,
     POLICY_EFFECTIVE_DTTM TIMESTAMP     NOT NULL,
     POLICY_EXPIRATION_DTTM TIMESTAMP,
     POLICY_STATUS_CD     VARCHAR(3)     NOT NULL,
     STATUS_CHANGE_DT     DATE,
     STATUS_REASON_CD     VARCHAR(3),
     CONTRACT_SHARE_PCT   NUMERIC(9,4),
     ISSUE_DT             DATE,
     RENEWAL_DT           DATE,
     TERMINATION_DT       DATE,
     PREMIUM_AMT          NUMERIC(18,5),
     DAY_OF_MTH_DUE       NUMERIC(9),
     COLLECTED_BY_AGENT_AMT NUMERIC(18,5),
     POLICY_FEE_AMT       NUMERIC(18,5),
     TAX_AMT              NUMERIC(18,5),
     DISCOUNT_AMT         NUMERIC(18,5),
     CANCEL_OR_LAPSE_REASON_CD VARCHAR(3),
     GROUP_NM             VARCHAR(50),
     REINSURANCE_IND      CHARACTER(1),
     PORTABILITY_IND      CHARACTER(1),
     CONVERT_TO_PRIVATE_IND CHARACTER(1),
     PROPOSED_RETROACTIVE_DT DATE,
     ASSIGNMENT_FLG       CHARACTER(1),
     AGENCY_BINDER_NO     VARCHAR(32),
     MIN_PREMIUM_IND      CHARACTER(1),
     BINDER_PURPOSE_CD    VARCHAR(3),
     NEW_BINDER_IND       CHARACTER(1),
     PAYMENT_STATUS_CD    VARCHAR(3),
     TERM_PROCESS_DT      DATE,
     DEPOSIT_AMT          NUMERIC(18,5),
     DOWN_PAYMENT_PCT     NUMERIC(9,4),
     PAYOR_CD             VARCHAR(3),
     MAILING_RESPONSIBILTY_CD VARCHAR(3),
     UNDERWRITER_ID       VARCHAR(32),
     POLICY_VALUE         NUMERIC(9),
     DURATION             NUMERIC(9),
     REINSTATEMENT_DT     DATE,
     GRACE_PERIOD_END_DT  DATE,
     SETTLEMENT_OPTION_CD VARCHAR(3),
     FINAL_PAYMENT_DT     DATE,
     BILLED_TO_DT         DATE,
     PAID_TO_DT           DATE,
     PAYMENT_METHOD_CD    VARCHAR(3),
     MODAL_PAYMENT_AMT    NUMERIC(18,5),
     PAYMENT_MODE_CD      VARCHAR(3),
     REVERSIONARY_BONUS_AMT NUMERIC(18,5),
     STAMP_DUTY_AMT       NUMERIC(18,5),
     BENEFICIARY_IND      CHARACTER(1),
     ENDORSEMENT_IND      CHARACTER(1),
     OTHER_INSURED_IND    CHARACTER(1),
     RATED_IND            CHARACTER(1),
     PREMIUM_INDEX_RT     NUMERIC(9,4),
     SOURCE_CHANNEL_CD    VARCHAR(3),
     PREFERRED_CHANNEL_CD VARCHAR(3),
     APPLICATION_RK       NUMERIC(10)     NOT NULL,
     POLICY_NO_2          VARCHAR(32),
     POLICY_MOD_DT        DATE,
     POLICY_DUE_DT        DATE,
     DUNNING_LEVEL        NUMERIC(4),
     DUNNING_DTTM         TIMESTAMP,
     DUNNING_ACT_AMT      NUMERIC(18,5),
     LAST_PREMIUM_PAID_FLG CHARACTER(1),
     PREV_INSURANCE_COMP_NO VARCHAR(20),
     INDIV_PRODUCT_CD     VARCHAR(3),
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     BONUS_AMT            NUMERIC(18,5),
     BONUS_PAID_UP_TO_DT  DATE,
     BONUS_PCT            NUMERIC(9,4),
     BONUS_RESERVE_AMT    NUMERIC(18,5),
     DIVIDEND_PCT         NUMERIC(9,4),
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     GUAR_BONUS_ACCUMULATED_UPTO_DT DATE,
     ISSUE_BRANCH_RK      NUMERIC(10),
     MATURITY_DT          DATE,
     NEXT_RE_ENTRY_DT     DATE,
     POLICY_RESERVE_AMT   NUMERIC(18,5),
     PREMIUM_FREEZE_IND   CHARACTER(1),
     PREMIUM_TYPE_CD      VARCHAR(3),
     RE_ENTRY_RT          NUMERIC(9,4),
     UW_TYPE_CD           VARCHAR(3),
     MIN_PREMIUM_AMT      NUMERIC(18,5),
     TARGET_PREMIUM_AMT   NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     DIVIDEND_TYPE_CD     VARCHAR(3),
     DIVIDEND_ACCUM_RT    NUMERIC(9,4),
     LOB_RK               NUMERIC(10)     NOT NULL,
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     PRODUCER_RK          NUMERIC(10),
     FINANCIAL_FUND_RK    NUMERIC(10),
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXPOLICY (POLICY_RK,LOB_RK)
;
CREATE TABLE INSURANCE_POLICY_RESTRICTIONS (
     RESTRICTION_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RESTRICTION_CD       VARCHAR(3)     NOT NULL,
     START_DT             DATE,
     END_DT               DATE,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INSURANCE_POLICY_RESTRICTIO_PI (RESTRICTION_RK)
;
CREATE TABLE INSURED_PERSON_DETAILS (
     INSURED_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INSURED_ID           VARCHAR(32)     NOT NULL,
     RELATIONSHIP_TO_PRINCIPAL_CD VARCHAR(3),
     PHYSICAL_DEFECT_IND  CHARACTER(1),
     AUTO_VIOLATION_POINTS NUMERIC(9),
     AUTO_LICENSE_SUSPENSION_IND CHARACTER(1),
     AUTO_LICENSE_REINSTATE_DT DATE,
     KNOWN_FAMILY_HISTORY_IND CHARACTER(1),
     RELATIONSHIP_TO_OWNER_CD VARCHAR(3),
     EXISTING_INSURANCE_IND CHARACTER(1),
     REJECTION_IND        CHARACTER(1),
     ADJUSTED_AGE         NUMERIC(3),
     REJECTION_COMPANY_NM VARCHAR(40),
     REJECTION_REASON_CD  VARCHAR(3),
     SPECIAL_TERMS_IND    CHARACTER(1),
     SPECIAL_TERMS_REASON_CD VARCHAR(3),
     BANKRUPTCY_IND       CHARACTER(1),
     PREMATURE_BIRTH_IND  CHARACTER(1),
     BIRTH_WEIGHT         NUMERIC(9,4),
     NUM_BROTHERS_LIVING  NUMERIC(6),
     NUM_BROTHERS_DEAD    NUMERIC(6),
     NUM_SISTERS_LIVING   NUMERIC(6),
     NUM_SISTERS_DEAD     NUMERIC(6),
     DISABILITY_EFF_START_DT DATE,
     DISABILITY_EFF_STOP_DT DATE,
     ACTIVELY_AT_WORK_IND CHARACTER(1),
     RECENT_HOSPITALIZATION_IND CHARACTER(1),
     SERIOUS_ILLNESS_IND  CHARACTER(1),
     RECEIV_DISABILITY_BENEFIT_IND CHARACTER(1),
     AIDS_IND             CHARACTER(1),
     ASSISTANCE_IND       CHARACTER(1),
     CANCER_IND           CHARACTER(1),
     DEMENTIA_IND         CHARACTER(1),
     DIABETES_IND         CHARACTER(1),
     NURSING_HOME_IND     CHARACTER(1),
     PARKINSONS_IND       CHARACTER(1),
     RESPIRATORY_IND      CHARACTER(1),
     STROKE_IND           CHARACTER(1),
     TRANSPLANT_IND       CHARACTER(1),
     WHEELCHAIR_IND       CHARACTER(1),
     TOBACCO_IND          CHARACTER(1),
     TOTAL_INFORCE_AND_APP_INS_AMT NUMERIC(18,5),
     SUB_STD_MORTALITY_RT NUMERIC(9,4),
     SUB_STD_ADDL_DEATH_RT NUMERIC(9,4),
     SUB_STD_EXPIRY_DT    DATE,
     COVERED_SALARY_AMT   NUMERIC(18,5),
     PARTY_RK             NUMERIC(10)     NOT NULL,
     APPLICATION_RK       NUMERIC(10),
     AGR_RK               NUMERIC(10)     NOT NULL,
     RISK_CLASS_CD        VARCHAR(3),
     SMOKER_STATUS_CD     VARCHAR(3),
     STD_OCCUPATION_CD    VARCHAR(3),
     OCCUPATION_CLASS_CD  VARCHAR(3),
     EXP_SALARY_GROWTH_RT NUMERIC(9,4),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INSURED_PERSON_DETAILS_PI (PARTY_RK)
;
CREATE TABLE INTEREST_RATE_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     CURRENCY_CD          VARCHAR(3)     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     MARKET_DT            DATE,
     RISK_FACTOR_ID       VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INTEREST_RATE_QUOTE_PI (QUOTE_DTTM,MARKET_CD,CURRENCY_CD)
;
CREATE TABLE INTERIOR_FINISH_DETAILS (
     INTR_FINISH_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INTR_FINISH_ID       VARCHAR(32)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     INTR_COMPONENT_TYPE_CD VARCHAR(3),
     MATERIAL_PCT         NUMERIC(9,4),
     MATERIAL_TYPE_CD     VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INTERIOR_FINISH_DETAILS_PI (INTR_FINISH_RK)
;
CREATE TABLE INTERNAL_ORG (
     INTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INTERNAL_ORG_REFERENCE_NO VARCHAR(32)     NOT NULL,
     ORG_NM               VARCHAR(50),
     ORG_LEGAL_NM         VARCHAR(50),
     ORG_SHORT_NM         VARCHAR(50),
     BOOK_OF_RECORD_CURRENCY_CD VARCHAR(3),
     ORG_TYPE_CD          VARCHAR(3),
     ORG_LEGAL_TYPE_CD    VARCHAR(3),
     LINE_OF_BUSINESS_NM  VARCHAR(40),
     CENTRAL_GOVT_TAX_ID_NO VARCHAR(32),
     SIC_CD               VARCHAR(10),
     NAICS_CD             VARCHAR(10),
     ACCOUNTING_FIRM_NM   VARCHAR(50),
     ESTABLISHED_DT       DATE,
     FIRST_OPERATION_DT   DATE,
     COMPANY_REGISTRATION_NO VARCHAR(32),
     NATURE_OF_BUSINESS_CD VARCHAR(3),
     ADDRESS_LINE_1       VARCHAR(64),
     ADDRESS_LINE_2       VARCHAR(64),
     ADDRESS_LINE_3       VARCHAR(64),
     ADDRESS_LINE_4       VARCHAR(64),
     CITY_NM              VARCHAR(100),
     POSTAL_CD            VARCHAR(20),
     COUNTY_NM            VARCHAR(40),
     STATE_REGION_CD      VARCHAR(4),
     COUNTRY_CD           VARCHAR(3),
     TELEPHONE_NO         VARCHAR(20),
     FAX_NO               VARCHAR(20),
     INTERNAL_REPORTING_CATEGORY_CD VARCHAR(3),
     WEB_SITE_TXT         VARCHAR(255),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INTERNAL_ORG_PI (INTERNAL_ORG_RK)
;
CREATE TABLE INTERNAL_ORG_ASSOC (
     PARENT_INTERNAL_ORG_RK NUMERIC(10)     NOT NULL,
     INTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     INTERNAL_ORG_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     CONTROLLED_PARTICIPATION_FLG CHARACTER(1),
     GROUP_PARTICIPATION_PCT NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INTERNAL_ORG_ASSOC_PI (PARENT_INTERNAL_ORG_RK,INTERNAL_ORG_RK,INTERNAL_ORG_ASSOC_TYPE_CD)
;
CREATE TABLE INTERNAL_ORG_X_PRODUCT (
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     INTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SALE_EFFECTIVE_DT    DATE,
     SALE_EXPIRATION_DT   DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INTERNAL_ORG_X_PRODUCT_PI (INSURANCE_PRODUCT_RK,INTERNAL_ORG_RK)
;
CREATE TABLE INTERNAL_REPORTING_CATEGORY (
     INTERNAL_REPORTING_CATEGORY_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     INTERNAL_RPT_CATEGORY_DESC VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INTERNAL_REPORTING_CATEGORY_PI (INTERNAL_REPORTING_CATEGORY_CD)
;
CREATE TABLE INTERNAL_RPT_CATEGORY_ASSOC (
     INTERNAL_REPORTING_CATEGORY_CD VARCHAR(3)     NOT NULL,
     PARENT_INT_RPT_CATEGORY_CD VARCHAR(3)     NOT NULL,
     INT_RPT_CATEGORY_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INTERNAL_RPT_CATEGORY_ASSOC_PI (INTERNAL_REPORTING_CATEGORY_CD,PARENT_INT_RPT_CATEGORY_CD,INT_RPT_CATEGORY_ASSOC_TYPE_CD)
;
CREATE TABLE INT_RATE_VOLATILITY_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     CURRENCY_CD          VARCHAR(3)     NOT NULL,
     BID_VOLATILITY_RT    NUMERIC(11,6),
     ASK_VOLATILITY_RT    NUMERIC(11,6),
     RISK_FACTOR_ID       VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INT_RATE_VOLATILITY_QUOTE_PI (QUOTE_DTTM,MARKET_CD,CURRENCY_CD)
;
CREATE TABLE INVENTORY_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     INVENTORY_ACCOUNTING_METHOD_CD VARCHAR(3),
     ANNUAL_GROSS_RECEIPTS_AMT NUMERIC(18,5),
     ANNUAL_NET_RECEIPTS_AMT NUMERIC(18,5),
     RECOVERY_PERIOD      NUMERIC(9,4),
     INSURANCE_TO_VALUE_PCT NUMERIC(9,4),
     BILLABLE_LOST_PERIOD NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INVENTORY_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE INVESTMENT_DETAILS (
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ACCOUNT_NO           VARCHAR(32)     NOT NULL,
     ACCOUNT_OPEN_DT      DATE,
     LIABILITY_AMT        NUMERIC(18,5),
     REDEMPTION_METHOD_CD VARCHAR(3),
     EE_CONTRIB_PCT       NUMERIC(9,4),
     EE_CONTRIB_AMT       NUMERIC(18,5),
     ER_CONTRIB_AMT       NUMERIC(18,5),
     ACCOUNT_VALUE        NUMERIC(18,5),
     INVESTMENT_TYPE_CD   VARCHAR(3),
     POOLED_IND           CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXINVESTMENT_DETAILS (POLICY_RK)
;
CREATE TABLE INVESTMENT_FUND (
     INVESTMENT_FUND_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INVESTMENT_FUND_CD   VARCHAR(3)     NOT NULL,
     INVESTMENT_FUND_TYPE_CD VARCHAR(3),
     INVESTMENT_FUND_NM   VARCHAR(50),
     RISK_RATING_TYPE_CD  VARCHAR(3),
     OBJECTIVE_TXT        VARCHAR(100),
     CUSIP_NO             VARCHAR(32),
     CARRIER_CD           VARCHAR(3),
     ASSET_CLASS_CD       VARCHAR(3),
     RATE_TYPE_CD         VARCHAR(3),
     GUAR_LIFETIME_RT     NUMERIC(9,4),
     GUAR_INVESTMENT_RT   NUMERIC(9,4),
     GUAR_END_DT          DATE,
     FUND_CURRENCY_CD     VARCHAR(3),
     UNIT_PRICE           NUMERIC(18,5),
     UNIT_PRICE_AS_OF_DT  DATE,
     UNIT_VALUE_BUY_RT    NUMERIC(9,4),
     COMPOUND_MODE_CD     VARCHAR(3),
     SALE_EFFECTIVE_DT    DATE,
     SALE_EXPIRATION_DT   DATE,
     VERSION_DT           DATE,
     INVESTMENT_MANAGER_TYPE_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXINVESTMENT_PRODUCT (INVESTMENT_FUND_RK)
;
CREATE TABLE INVESTMENT_PRODUCT (
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     INVESTMENT_FUND_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INVESTMENT_PRODUCT_PI (INSURANCE_PRODUCT_RK,INVESTMENT_FUND_RK)
;
CREATE TABLE IRREGULAR_CASHFLOW_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CASHFLOW_INSTRUMENT_TYPE_CD VARCHAR(5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX IRREGULAR_CASHFLOW_INSTRUME_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE IRREGULAR_CASHFLOW_PAYMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     PAYMENT_DT           DATE     NOT NULL,
     PAYMENT_LEG_CD       VARCHAR(3)     NOT NULL,
     PAYMENT_TYPE_CD      VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PAYMENT_AMT          NUMERIC(18,5)     NOT NULL,
     PAYMENT_CURRENCY_CD  VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX IRREGULAR_CASHFLOW_PAYMENT_PI (FINANCIAL_INSTRUMENT_RK,PAYMENT_DT,PAYMENT_LEG_CD,PAYMENT_TYPE_CD)
;
CREATE TABLE IRREGULAR_DISCRETE_MONITORING (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     MONITORING_DT        DATE     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX IRREGULAR_DISCRETE_MONITORI_PI (FINANCIAL_INSTRUMENT_RK,MONITORING_DT)
;
CREATE TABLE IRREGULAR_RATE_RESETS (
     IRREGULAR_RATE_RESETS_RK NUMERIC(10)     NOT NULL,
     RESET_DT             DATE     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     ACCOUNT_RK           NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     CREDIT_FACILITY_RK   NUMERIC(10))
     PRIMARY INDEX IRREGULAR_RATE_RESETS_PI (IRREGULAR_RATE_RESETS_RK,RESET_DT)
;
CREATE TABLE ISSUE_CODE (
     ISSUE_CD             VARCHAR(15)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     ISSUE_TYPE_CD        VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ISSUE_DESC           VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ISSUE_CODE_PI (ISSUE_CD,ISSUE_TYPE_CD)
;
CREATE TABLE ISSUE_TYPE (
     ISSUE_TYPE_CD        VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ISSUE_TYPE_DESC      VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ISSUE_TYPE_PI (ISSUE_TYPE_CD)
;
CREATE TABLE ITEM_CATEGORY (
     ITEM_CATEGORY_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ITEM_CATEGORY_CD     VARCHAR(3)     NOT NULL,
     ITEM_CATEGORY_DESC   VARCHAR(255),
     ITEM_CATEGORY_TYPE_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ITEM_CATEGORY_PI (ITEM_CATEGORY_RK)
;
CREATE TABLE ITEM_CATEGORY_ASSOC (
     ITEM_CATEGORY_RK     NUMERIC(10)     NOT NULL,
     PARENT_ITEM_CATEGORY_RK NUMERIC(10)     NOT NULL,
     ITEM_CATEGORY_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ITEM_CATEGORY_ASSOC_PI (ITEM_CATEGORY_RK,PARENT_ITEM_CATEGORY_RK,ITEM_CATEGORY_ASSOC_TYPE_CD)
;
CREATE TABLE LEASE_ACCOUNT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     LEASE_TYPE_CD        VARCHAR(3),
     CURRENT_LIMIT_AMT    NUMERIC(18,5),
     CURRENT_LIMIT_DT     DATE,
     APPROVAL_DT          DATE,
     COMPLETE_DT          DATE,
     RESIDUAL_VALUE_AMT   NUMERIC(18,5),
     PRESENT_VALUE_AMT    NUMERIC(18,5),
     SENIORITY_CD         VARCHAR(3),
     SPECIALIZED_LENDING_CD VARCHAR(3),
     PAYMENT_AMT          NUMERIC(18,5),
     PAYMENT_TIME_FREQUENCY_CD VARCHAR(3),
     MOTOR_VEHICLE_RK     NUMERIC(10),
     PROPERTY_RK          NUMERIC(10),
     FIRST_PAYMENT_DT     DATE,
     LAST_PAYMENT_DT      DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LEASE_ACCOUNT_PI (ACCOUNT_RK)
;
CREATE TABLE LEASE_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CONTRACT_TERM        NUMERIC(9,4),
     INT_RATE_PCT         NUMERIC(9,4),
     GROSS_LEASEHOLD_INTEREST_AMT NUMERIC(18,5),
     BONUS_AMT            NUMERIC(18,5),
     IMPROVEMENTS_AMT     NUMERIC(18,5),
     PREPAID_RENT_AMT     NUMERIC(18,5),
     PAYMENT_DT           DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LEASE_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE LEGAL_PROT_AGREEMENT (
     LEGAL_PROT_AGR_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LEGAL_PROT_AGR_ID    VARCHAR(32)     NOT NULL,
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LEGAL_PROT_AGREEMENT_PI (LEGAL_PROT_AGR_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE LEGAL_PROT_INSURED_SUBJECT (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBJECT_ID           VARCHAR(32)     NOT NULL,
     SUBJECT_INSURANCE_CD VARCHAR(3),
     ITEM_DESC            VARCHAR(255),
     ITEM_VALUE_AMT       NUMERIC(18,5),
     VALUATION_CD         VARCHAR(3),
     AGREED_VALUE_IND     CHARACTER(1),
     LEGAL_PROT_AGR_RK    NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     APPLICATION_RK       NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LEGAL_PROT_INSURED_SUBJECT_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE LIABILITY_AGREEMENT (
     LIABILITY_AGR_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LIABILITY_AGR_ID     VARCHAR(32)     NOT NULL,
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LIABILITY_AGREEMENT_PI (LIABILITY_AGR_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE LIABILITY_INSURED_SUBJECT (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBJECT_ID           VARCHAR(32)     NOT NULL,
     SUBJECT_INSURANCE_CD VARCHAR(3),
     ITEM_DESC            VARCHAR(255),
     ITEM_VALUE_AMT       NUMERIC(18,5),
     VALUATION_CD         VARCHAR(3),
     AGREED_VALUE_IND     CHARACTER(1),
     LIABILITY_AGR_RK     NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     APPLICATION_RK       NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LIABILITY_INSURED_SUBJECT_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE LIFE_AGREEMENT (
     LIFE_AGR_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LIFE_AGR_ID          VARCHAR(32)     NOT NULL,
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     GROUP_POLICY_IND     CHARACTER(1),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LAST_SURRENDER_REQUEST_DT DATE,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LIFE_AGREEMENT_PI (LIFE_AGR_RK)
;
CREATE TABLE LIFE_HAZARD_EXPOSURE (
     UOE_RK               NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     DURATION_CNT         NUMERIC(6),
     AGREEMENT_TYPE_CD    VARCHAR(3),
     PREMIUM_AMT          NUMERIC(18,5),
     MAIN_BENEFIT_AMT     NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     STATUS_CD            VARCHAR(3),
     MATURITY_AGE         NUMERIC(3),
     ENTRY_AGE            NUMERIC(3),
     PAID_UP_SUM_SURVIVAL_AMT NUMERIC(18,5),
     PAID_UP_SUM_PERMANENT_AMT NUMERIC(18,5),
     INDEXED_INS_CD       VARCHAR(3),
     SURRENDER_VALUE_AMT  NUMERIC(18,5),
     SURRENDER_VALUE_DT   DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LIFE_HAZARD_EXPOSURE_PI (UOE_RK,POLICY_RK)
;
CREATE TABLE LIFE_INSURANCE_CLAIM (
     CLAIM_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIM_REFERENCE_ID   VARCHAR(32)     NOT NULL,
     LOSS_REPORT_DT       DATE,
     LOSS_DT              DATE,
     CLAIM_OPEN_DTTM      TIMESTAMP,
     CLAIM_CLOSE_DTTM     TIMESTAMP,
     CLAIM_STATUS_CD      VARCHAR(3),
     CLAIM_PAYMENT_DT     DATE,
     DEATH_CERTIFICATE_CERTIFY_DT DATE,
     LITIGATION_IND       CHARACTER(1),
     FRAUDULENT_CLAIM_IND CHARACTER(1),
     CLAIM_STATUS_REASON_CD VARCHAR(3),
     CLAIM_STATUS_CHANGE_DTTM TIMESTAMP,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXINSURANCE_CLAIM (CLAIM_RK)
;
CREATE TABLE LIFE_INSURANCE_PRODUCT (
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INSURANCE_PRODUCT_CD VARCHAR(3)     NOT NULL,
     PLAN_NM              VARCHAR(40),
     DAY_COUNT_CONVENTION_CD VARCHAR(3),
     VERSION_DT           DATE,
     PRODUCT_TYPE_CD      VARCHAR(3),
     POLICY_PRODUCT_FORM_CD VARCHAR(3),
     PARTICIPATING_IND    CHARACTER(1),
     PORTABILITY_IND      CHARACTER(1),
     CUSIP_NO             VARCHAR(32),
     DIVIDEND_ACCUM_RT    NUMERIC(9,4),
     GUAR_INT_RT          NUMERIC(9,4),
     NEW_MONEY_INT_RT     NUMERIC(9,4),
     SALE_EFFECTIVE_DT    DATE,
     SALE_EXPIRATION_DT   DATE,
     PAY_TO_AGE           NUMERIC(3),
     PAY_TO_YR_CNT        NUMERIC(6),
     MAX_NUM_INVEST_PRODUCTS NUMERIC(6),
     GUAR_LIFETIME_RT     NUMERIC(9,4),
     MIN_ISSUE_AGE        NUMERIC(3),
     MAX_ISSUE_AGE        NUMERIC(3),
     REVERSIONARY_BONUS_IND CHARACTER(1),
     BONUS_CALC_METHOD_CD VARCHAR(3),
     BONUS_COMPOUNDING_FREQ_CD VARCHAR(3),
     GUAR_RENEWAL_IND     CHARACTER(1),
     GUAR_BONUS_ACCUM_RT  NUMERIC(9,4),
     TERMINAL_BONUS_IND   CHARACTER(1),
     RESERVE_METHOD_CD    VARCHAR(3),
     GUAR_RATE_IND        CHARACTER(1),
     RE_ENTRY_IND         CHARACTER(1),
     TERMINAL_BONUS_ELIG_PERIOD NUMERIC(9,4),
     PRODUCT_CATEGORY_RK  NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXINSURANCE_PRODUCT (INSURANCE_PRODUCT_RK,LOB_RK)
;
CREATE TABLE LIFE_POLICY_DETAILS (
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     GDB_VALUE            NUMERIC(18,5),
     GDB_DT               DATE,
     VALUE_PER_UNIT       NUMERIC(18,5),
     FACE_UNITS           NUMERIC(9),
     FACE_AMT             NUMERIC(18,5),
     CURR_INT_RT          NUMERIC(9,4),
     EE_CONTRIB_AMT       NUMERIC(18,5),
     ER_CONTRIB_AMT       NUMERIC(18,5),
     CURR_LOAN_INT_RT     NUMERIC(9,4),
     LOAN_INT_TIMING_CD   VARCHAR(3),
     LOAN_INT_TYPE_CD     VARCHAR(3),
     LOAN_INT_METHOD_CD   VARCHAR(3),
     MAX_AVAILABLE_LOAN   NUMERIC(18,5),
     MAX_AVAILABLE_PREF_LOAN NUMERIC(18,5),
     LOAN_REPAYMENT_AMT   NUMERIC(18,5),
     DEATH_BENEFIT_AMT    NUMERIC(18,5),
     SURRENDER_CHARGE_AMT NUMERIC(18,5),
     NET_DEATH_BENEFIT_AMT NUMERIC(18,5),
     INDEX_COVER_IND      CHARACTER(1),
     INDEX_RT             NUMERIC(9,4),
     DIVIDEND_TYPE_CD     VARCHAR(3),
     DIVIDEND_AMT         NUMERIC(18,5),
     REQUESTED_MATURITY_AGE NUMERIC(3),
     REQUESTED_MATURITY_DT DATE,
     REQUESTED_MATURITY_DURATION NUMERIC(9),
     PREMIUM_DURATION_DT  DATE,
     TERM_BONUS_ELIG_START_AGE_CNT NUMERIC(6),
     LIFE_DEATH_BENEFIT_RATIO_CD VARCHAR(3),
     DEATH_BENEFIT_TYPE_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXLIFE (POLICY_RK)
;
CREATE TABLE LIFE_POLICY_TRANS (
     POLICY_TRANS_ID      VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     TRANS_DT             DATE,
     TRANS_TYPE_CD        VARCHAR(3),
     TRANS_SUB_TYPE_CD    VARCHAR(3),
     REVERSAL_IND         CHARACTER(1),
     TRANS_GROSS_AMT      NUMERIC(18,5),
     TRANS_NET_AMT        NUMERIC(18,5),
     TRANS_FEE            NUMERIC(18,5),
     TRANS_CURRENCY_CD    VARCHAR(3),
     REFERENCE_NO         VARCHAR(32),
     PAYMENT_METHOD_CD    VARCHAR(3),
     TOTAL_UNITS          NUMERIC(9),
     UNIT_VALUE           NUMERIC(18,5),
     FEDERAL_TAX_WITHHELD NUMERIC(18,5),
     JURISDICTION_TAX_WITHHELD NUMERIC(18,5),
     LOCAL_TAX_WITHHELD   NUMERIC(18,5),
     SERVICES_TAX_WITHHELD NUMERIC(18,5),
     ANNUITY_CONTRIBUTION_AMT NUMERIC(18,5),
     SUB_ACCOUNT_RK       NUMERIC(10),
     USER_CD              VARCHAR(3),
     PAYEE_RK             NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LIFE_POLICY_TRANS_PI (POLICY_TRANS_ID,SOURCE_SYSTEM_CD)
;
CREATE TABLE LIFE_POLICY_TRANS_LINE_ITEM (
     POLICY_TRANS_LINE_ITEM_NO NUMERIC(9)     NOT NULL,
     POLICY_TRANS_ID      VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     AMT_TYPE_CD          VARCHAR(3),
     LINE_ITEM_TRANS_AMT  NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LIFE_POLICY_TRANS_LINE_ITEM_PI (POLICY_TRANS_LINE_ITEM_NO,POLICY_TRANS_ID,SOURCE_SYSTEM_CD,POLICY_RK)
;
CREATE TABLE LIFE_PRODUCT (
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALUE_PER_UNIT       NUMERIC(18,5),
     MIN_SINGLE_LOAN      NUMERIC(18,5),
     MIN_MODAL_PAYMENT    NUMERIC(18,5),
     MIN_ANNUALIZED_PAYMENT NUMERIC(18,5),
     MIN_SINGLE_WITHDRAWAL NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXLIFE_PRODUCT (INSURANCE_PRODUCT_RK)
;
CREATE TABLE LIFE_STYLE_DETAILS (
     LIFE_STYLE_ACTIVITY_RK NUMERIC(10)     NOT NULL,
     LIFE_STYLE_ACTIVITY_TYPE_CD VARCHAR(3)     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     ACTIVITY_FREQUENCY_MODE_CD VARCHAR(3),
     ACTIVITY_FREQUENCY   NUMERIC(9),
     START_DT             DATE,
     END_DT               DATE,
     TOTAL_ACTIVITY_CNT   NUMERIC(6),
     LAST_YR_ACTIVITY_CNT NUMERIC(6),
     NEXT_YR_ACTIVITY_CNT NUMERIC(6),
     CLUB_ACTIVITY_CNT    NUMERIC(6),
     CLUB_NM              VARCHAR(40),
     LAST_ACTIVITY_DT     DATE,
     LAST_ACCIDENT_DT     DATE,
     ACCIDENT_DETAILS     VARCHAR(255),
     AT_FAULT_IND         CHARACTER(1),
     LICENSE_IND          CHARACTER(1),
     PROFESSIONAL_IND     CHARACTER(1),
     HOURS_OF_INSTRUCTION NUMERIC(4,2),
     OUTSIDE_RESIDENT_COUNTRY_IND CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LIFE_STYLE_DETAILS_PI (LIFE_STYLE_ACTIVITY_RK)
;
CREATE TABLE LIFE_UNIT_OF_EXPOSURE (
     UOE_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     COVERAGE_RIDER_RK    NUMERIC(10)     NOT NULL,
     EQUIVALENT_AGE       NUMERIC(3),
     LIFE_HAZARD_CD       VARCHAR(3),
     LIFE_COVERAGE_STATUS_CD VARCHAR(3),
     PURPOSE_CD           VARCHAR(3),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     RENEWABLE_IND        CHARACTER(1),
     GUAR_INT_RT          NUMERIC(9,4),
     PAYMENT_MODE_CD      VARCHAR(3),
     CASH_VALUE           NUMERIC(18,5),
     SURRENDER_CHARGE_AMT NUMERIC(18,5),
     CURR_AMT             NUMERIC(18,5),
     VALUE_PER_UNIT       NUMERIC(18,5),
     NO_OF_UNITS          NUMERIC(9),
     BASE_PREMIUM_AMT     NUMERIC(18,5),
     MODAL_PREMIUM_AMT    NUMERIC(18,5)     NOT NULL,
     ANNUAL_PREMIUM_AMT   NUMERIC(18,5)     NOT NULL,
     GDB_PREMIUM_AMT      NUMERIC(18,5),
     COMMISSION_AMT       NUMERIC(18,5),
     TERMINATION_DT       DATE,
     TEMP_EXTRA_PREMIUM_AMT NUMERIC(18,5),
     TEMP_EXTRA_START_DT  DATE,
     TEMP_EXTRA_END_DT    DATE,
     PERM_EXTRA_PREMIUM_AMT NUMERIC(18,5),
     PERM_EXTRA_START_DT  DATE,
     ISSUED_AS_APPLIED_IND CHARACTER(1),
     PREMIUM_PER_UNIT     NUMERIC(18,5),
     RESERVE_METHOD_CD    VARCHAR(3),
     RESERVE_AMT          NUMERIC(18,5),
     RESERVE_INTEREST_RT  NUMERIC(9,4),
     BENEFIT_PERIOD_CD    VARCHAR(3),
     BENEFIT_MODE_CD      VARCHAR(3),
     WAITING_PERIOD_CD    VARCHAR(3),
     BENEFIT_AMT_REVISION_NEXT_DT DATE,
     JOINT_BENEFIT_PAYOUT_CD VARCHAR(3),
     LAST_VALUATION_DT    DATE,
     LIVES_TYPE_CD        VARCHAR(3),
     PREMIUM_TERMINATION_DT DATE,
     BENEFIT_AMT          NUMERIC(18,5),
     BONUS_PAID_UP_TO_DT  DATE,
     BONUS_AMT            NUMERIC(18,5),
     MATURITY_BENEFIT_AMT NUMERIC(18,5),
     PREMIUM_PAID_UP_TO_DT DATE,
     RETURN_OF_PREM_BENEFIT_FLG CHARACTER(1),
     RETURN_OF_PREM_RT    NUMERIC(9,4),
     SALARY_PCT           NUMERIC(9,4),
     SOLVENCY2_LEVEL_1_SEGMENT_CD VARCHAR(3),
     SOLVENCY2_LEVEL_2_SEGMENT_CD VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     JOINT_LIFE_INSURED_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXUNIT_OF_EXPOSURE (UOE_RK)
;
CREATE TABLE "LIMIT" (
     LIMIT_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     UOE_RK               NUMERIC(10)     NOT NULL,
     LIMIT_APPLIES_TO_CD  VARCHAR(3)     NOT NULL,
     VALUATION_CD         VARCHAR(3),
     LIMIT_AMT            NUMERIC(18,5),
     LIMIT_PCT            NUMERIC(9,4),
     LIMIT_FACTOR         NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXLIMIT (LIMIT_RK)
;
CREATE TABLE LINE_OF_BUSINESS (
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOB_CD               VARCHAR(3)     NOT NULL,
     LOB_DESC             VARCHAR(255),
     LOB_NM               VARCHAR(40),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LINE_OF_BUSINESS_PI (LOB_RK)
;
CREATE TABLE LINE_OF_BUSINESS_ASSOC (
     LOB_RK               NUMERIC(10)     NOT NULL,
     PARENT_LOB_RK        NUMERIC(10)     NOT NULL,
     LOB_ASSOC_TYPE_CD    VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LINE_OF_BUSINESS_ASSOC_PI (LOB_RK,PARENT_LOB_RK,LOB_ASSOC_TYPE_CD)
;
CREATE TABLE LOAN (
     LOAN_RK              NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOAN_NO              VARCHAR(32)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOAN_TYPE_CD         VARCHAR(3),
     LOAN_START_DT        DATE,
     LOAN_END_DT          DATE,
     LOAN_STATUS_CD       VARCHAR(3),
     LOAN_REASON_CD       VARCHAR(3),
     LOAN_AMT             NUMERIC(18,5),
     LOAN_PAYMENT_AMT     NUMERIC(18,5),
     LOAN_PAYMENT_METHOD_CD VARCHAR(3),
     LOAN_PAYMENT_MODE_CD VARCHAR(3),
     LOAN_INT_RT          NUMERIC(9,4),
     LOAN_INT_TYPE_CD     VARCHAR(3),
     LOAN_INT_AS_OF_DT    DATE,
     LOAN_REPAY_NUM_YR    NUMERIC(6),
     LOAN_SUSPEND_DT      DATE,
     LOAN_INT_AMT_DUE     NUMERIC(18,5),
     LOANED_AMT_INT_RT    NUMERIC(9,4),
     LOAN_DEFAULT_DT      DATE,
     CUM_LOAN_INT_AMT     NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LOAN_PI (LOAN_RK)
;
CREATE TABLE LOAN_ACCOUNT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     LOAN_TYPE_CD         VARCHAR(3),
     LOAN_STATUS_CD       VARCHAR(3),
     LOAN_CYCLE_NO        NUMERIC(5),
     APPLIED_AMT          NUMERIC(18,5),
     ADVANCE_REQUIRED_AMT NUMERIC(18,5),
     ADVANCE_APPROVED_AMT NUMERIC(18,5),
     ACTUAL_ADVANCE_AMT   NUMERIC(18,5),
     DOWN_PAYMENT_AMT     NUMERIC(18,5),
     MATURITY_DT          DATE,
     PURPOSE_CD           VARCHAR(3),
     PAYMENT_METHOD_CD    VARCHAR(3),
     MONTHLY_PAYMENT_AMT  NUMERIC(18,5),
     AUTO_PAY_FLG         CHARACTER(1),
     INTEREST_TIER_NO     NUMERIC(5),
     APR_RT               NUMERIC(9,4),
     BASE_APR_RT          NUMERIC(9,4),
     INTEREST_PAYABLE_AMT NUMERIC(18,5),
     CHARGE_OFF_DT        DATE,
     CHARGE_OFF_AMT       NUMERIC(18,5),
     PREPAY_PENALTY_AMT   NUMERIC(18,5),
     PREPAY_PENALTY_DT    DATE,
     COLLATERAL_CD        VARCHAR(3),
     COLLATERAL_AMT       NUMERIC(18,5),
     GUARANTEE_CD         VARCHAR(3),
     GUARANTEE_AMT        NUMERIC(18,5),
     LOAN_SECURED_FLG     CHARACTER(1),
     SECURITY_CD          VARCHAR(3),
     LOAN_SECURITY_TYPE_CD VARCHAR(3),
     PROPERTY_RK          NUMERIC(10),
     DOCUMENTATION_TYPE_CD VARCHAR(3),
     OVERPAY_TO_PRINCIPAL_FLG CHARACTER(1),
     LOAN_INSURED_FLG     CHARACTER(1),
     PPI_FLG              CHARACTER(1),
     PPI_NO               VARCHAR(20),
     PPI_START_DT         DATE,
     PPI_PREMIUM_RT       NUMERIC(9,4),
     PREMIUM_FIRST_DUE_DT DATE,
     APP_LIFE_COVERAGE_FLG CHARACTER(1),
     LIEN_INDICATOR_FLG   CHARACTER(1),
     SPECIALIZED_LENDING_CD VARCHAR(3),
     LATE_PAYMENT_DAYS_LATE_NO NUMERIC(4),
     LATE_PAYMENT_STATUS_CD VARCHAR(3),
     CURRENT_LIMIT_AMT    NUMERIC(18,5),
     CURRENT_LIMIT_DT     DATE,
     BUREAU_CLASS_CD      VARCHAR(3),
     INQUIRY_BUREAU_CNT   NUMERIC(6),
     MONTHS_SINCE_AT_BUREAU_CNT NUMERIC(6),
     COLLECTIONS_STATUS_CD VARCHAR(3),
     PROT_INS_EXTERNAL_ORG_RK NUMERIC(10),
     SENIORITY_CD         VARCHAR(3),
     PAYMENT_AMT          NUMERIC(18,5),
     PAYMENT_TIME_FREQUENCY_CD VARCHAR(3),
     CASH_ADVANCE_FLG     CHARACTER(1),
     AUTO_DEBIT_ACCOUNT_NO VARCHAR(20),
     LOAN_DISBURSED_DT    DATE,
     LOAN_APPROVAL_DT     DATE,
     REFINANCE_AMT        NUMERIC(18,5),
     APR_TYPE_CD          VARCHAR(10),
     ACCOUNT_ID           VARCHAR(32),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     HONEYMOON_FLG        CHARACTER(1),
     HONEYMOON_START_DT   DATE,
     HONEYMOON_END_DT     DATE,
     OFFSET_ACCOUNT_FLG   CHARACTER(1),
     PORTABILITY_FLG      CHARACTER(1),
     PPI_STATUS_CD        VARCHAR(3),
     SPLIT_LOAN_FLG       CHARACTER(1),
     FIXED_INT_END_DT     DATE,
     CONVERTIBLE_CD       VARCHAR(3),
     REPAYMENT_HOLIDAY_FLG CHARACTER(1),
     REPAYMENT_HOLIDAY_START_DT DATE,
     REPAYMENT_HOLIDAY_END_DT DATE,
     SPECIAL_INTEREST_RT  NUMERIC(9,4),
     SPECIAL_RATE_START_DT DATE,
     SPECIAL_RATE_END_DT  DATE,
     SPECIAL_RATE_TYPE_CD VARCHAR(3),
     MATURITY_CHANGE_REASON_CD VARCHAR(3),
     DISBURSEMENT_TYPE_CD VARCHAR(3),
     APR_RT_CHANGE_REASON_CD VARCHAR(3),
     FIRST_PAYMENT_DT     DATE,
     LAST_PAYMENT_DT      DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     CURRENT_APR_SET_DT   DATE)
     PRIMARY INDEX LOAN_ACCOUNT_PI (ACCOUNT_RK)
;
CREATE TABLE LOCATION (
     LOCATION_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOCATION_ID          VARCHAR(32)     NOT NULL,
     LOCATION_TYPE_CD     VARCHAR(3),
     ADDRESS_LINE_1       VARCHAR(64),
     ADDRESS_LINE_2       VARCHAR(64),
     ADDRESS_LINE_3       VARCHAR(64),
     ADDRESS_LINE_4       VARCHAR(64),
     CITY_NM              VARCHAR(100),
     POSTAL_CD            VARCHAR(20),
     COUNTY_NM            VARCHAR(40),
     STATE_REGION_CD      VARCHAR(4),
     LATITUDE             VARCHAR(20),
     LONGITUDE            VARCHAR(20),
     RISK_LOCATION_CD     VARCHAR(3),
     EARTHQUAKE_ZONE_CD   VARCHAR(3),
     FIRE_DISTRICT        VARCHAR(64),
     FIRE_DISTRICT_CD     VARCHAR(3),
     LOCATION_NM          VARCHAR(50),
     LOCATION_DESC        VARCHAR(255),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     RISK_CAT_ZONE_RK     NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     COUNTRY_CD           VARCHAR(3))
     PRIMARY INDEX XXLOCATION (LOCATION_RK)
;
CREATE TABLE LOOKBACK_OPTION_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     LOOKBACK_OPTION_TYPE_CD VARCHAR(10),
     LOOKBACK_OPTION_SUB_TYPE_CD VARCHAR(3),
     EXTREME_SPREAD_FRST_PRD_END_DT DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX LOOKBACK_OPTION_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE MARGIN_AGREEMENT (
     MARGIN_AGREEMENT_RK  NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     MARGIN_AGREEMENT_DOC_TXT VARCHAR(100),
     MARGIN_AGREEMENT_BALANCE_AMT NUMERIC(18,5),
     MARGIN_THRESHOLD_AMT NUMERIC(18,5),
     MARGIN_PERIOD_DAYS_CNT NUMERIC(6),
     MARGIN_AGREEMENT_ID  VARCHAR(32),
     VARIATION_MARGIN_RT  NUMERIC(9,4),
     INITIAL_MARGIN_AMT   NUMERIC(18,5),
     MARGIN_INDEPENDENT_AMT NUMERIC(18,5),
     MINIMUM_MARGIN_TRANSFER_AMT NUMERIC(18,5),
     MARGIN_THRESHOLD_CURRENCY_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX MARGIN_AGREEMENT_PI (MARGIN_AGREEMENT_RK)
;
CREATE TABLE MARKET_DATA (
     RISK_FACTOR_ID       VARCHAR(32)     NOT NULL,
     DATA_DTTM            TIMESTAMP     NOT NULL,
     MARKET_VALUE         NUMERIC(18,5),
     MARKET_VALUE_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX MARKET_DATA_PI (RISK_FACTOR_ID,DATA_DTTM)
;
CREATE TABLE MEDICAL_CONDITION_DETAILS (
     CONDITION_TYPE_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CONDITION_TYPE_CD    VARCHAR(3)     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     LAST_UPDATED_DT      DATE,
     CONDITION_DESC       VARCHAR(255),
     CONDITION_ONSET_DT   DATE,
     CONDITION_STATUS_CD  VARCHAR(3),
     LAST_SEEN_DT         DATE,
     RECURRENCES_IND      CHARACTER(1),
     DISABILITY_IND       CHARACTER(1),
     TIME_OFF_WORK        NUMERIC(9),
     LAST_YR_EPISODES_CNT NUMERIC(6),
     TOTAL_EPISODES_CNT   NUMERIC(6),
     LAST_EPISODE_DT      DATE,
     RECOVERY_DT          DATE,
     EXAMINEE_DESC        VARCHAR(255),
     WEIGHT_CHANGE        NUMERIC(9,4),
     TREATMENT_START_DT   DATE,
     PHYSICIAN_RK         NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXMEDICAL_CONDITION_DETAILS (CONDITION_TYPE_RK)
;
CREATE TABLE MEDICAL_EXAM_DETAILS (
     INSURED_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EXAM_STATUS_CD       VARCHAR(3),
     EXAM_DT              DATE,
     FIRST_DIASTOLIC_BP_READING NUMERIC(9,4),
     SECOND_DIASTOLIC_BP_READING NUMERIC(9,4),
     THIRD_DIASTOLIC_BP_READING NUMERIC(9,4),
     FIRST_SYSTOLIC_BP_READING NUMERIC(9,4),
     SECOND_SYSTOLIC_BP_READING NUMERIC(9,4),
     THIRD_SYSTOLIC_BP_READING NUMERIC(9,4),
     FIRST_PULSE_READING  NUMERIC(9),
     SECOND_PULSE_READING NUMERIC(9,4),
     SIGNS_OF_ALCOHOL_ABUSE_OBS VARCHAR(100),
     SIGNS_OF_DRUG_ABUSE_OBS VARCHAR(100),
     HEIGHT_MEASURED_IND  CHARACTER(1),
     WEIGHT_MEASURED_IND  CHARACTER(1),
     PULSE_IRREGULAR_IND  CHARACTER(1),
     FIRST_PREMATURE_VC   NUMERIC(9,4),
     SECOND_PREMATURE_VC  NUMERIC(9,4),
     MENSTRUATION_IND     CHARACTER(1),
     BLOOD_GLUCOSE_LEVEL  NUMERIC(9,4),
     CHOLESTEROL_NUM      NUMERIC(6),
     HDL_CHOLESTEROL_NUM  NUMERIC(6),
     LDL_CHOLESTEROL_NUM  NUMERIC(6),
     TRIGLYCERIDES_NUM    NUMERIC(6),
     CHEST_FULL_MEASURE   NUMERIC(9,4),
     CHEST_FORCED_MEASURE NUMERIC(9,4),
     ABDOMEN_MEASURE      NUMERIC(9,4),
     PHYSICIAN_RK         NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX MEDICAL_EXAM_DETAILS_PI (INSURED_RK)
;
CREATE TABLE MEDICAL_PREVENTION_DETAILS (
     TEST_TYPE_RK         NUMERIC(10)     NOT NULL,
     TEST_TYPE_CD         VARCHAR(3)     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     PHYSICIAN_RK         NUMERIC(10)     NOT NULL,
     TEST_DT              DATE,
     POSITIVE_IND         CHARACTER(1),
     VISIT_REASON_CD      VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX MEDICAL_PREVENTION_DETAILS_PI (TEST_TYPE_RK)
;
CREATE TABLE MEDICAL_TREATMENT_DETAILS (
     TREATMENT_TYPE_RK    NUMERIC(10)     NOT NULL,
     TREATMENT_TYPE_CD    VARCHAR(3)     NOT NULL,
     CONDITION_TYPE_RK    NUMERIC(10)     NOT NULL,
     PATIENT_ID           VARCHAR(32),
     TREATMENT_START_DT   DATE,
     LAST_SEEN_DT         DATE,
     TREATMENT_COMPLETION_IND CHARACTER(1),
     MEDICATION_DESC      VARCHAR(255),
     COMPLICATIONS_IND    CHARACTER(1),
     EXAMINEE_DESC        VARCHAR(255),
     TREATMENT_DURATION   NUMERIC(9),
     PHYSICIAN_RK         NUMERIC(10)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX MEDICAL_TREATMENT_DETAILS_PI (TREATMENT_TYPE_RK)
;
CREATE TABLE MILITARY_EXP_DETAILS (
     INSURED_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     MILITARY_RANK_CD     VARCHAR(3),
     DUTIES_DESC          VARCHAR(255),
     MILITARY_STATUS_CD   VARCHAR(3),
     MILITARY_ORG_TYPE_CD VARCHAR(3),
     MILITARY_PAY_GRADE_CD VARCHAR(3),
     TIME_IN_CURR_ASSIGNMENT NUMERIC(9),
     TRANSFER_ALERT_IND   CHARACTER(1),
     TRANSFER_DETAILS     VARCHAR(100),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX MILITARY_EXP_DETAILS_PI (INSURED_RK)
;
CREATE TABLE MONEY_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     MONEY_AMT            NUMERIC(18,5),
     SECS_OTHER_THAN_PAYROLL_AMT NUMERIC(18,5),
     CHECKS_AMT           NUMERIC(18,5),
     PAYROLL_AMT          NUMERIC(18,5),
     MONEY_OVERNIGHT_AMT  NUMERIC(18,5),
     SECS_IN_BANK_AMT     NUMERIC(18,5),
     AP_CHECKS_AMT        NUMERIC(18,5),
     MAX_EXPOSURE_AMT     NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX MONEY_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE MORTGAGE_ACCOUNT (
     ACCOUNT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     BUILDING_INS_EXTERNAL_ORG_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROPERTY_RK          NUMERIC(10),
     MORTGAGE_TYPE_CD     VARCHAR(3),
     MORTGAGE_CYCLE_DAY_NO NUMERIC(3),
     ACTUAL_ADVANCE_AMT   NUMERIC(18,5),
     ADVANCE_REQ_AMT      NUMERIC(18,5),
     ADVANCE_PCT          NUMERIC(9,4),
     REVIEW_DT            DATE,
     CURRENT_LIMIT_AMT    NUMERIC(18,5),
     CURRENT_LIMIT_DT     DATE,
     INTEREST_PAYABLE_AMT NUMERIC(18,5),
     TAX_YEAR_INTEREST_AMT NUMERIC(18,5),
     SET_UP_FEES_AMT      NUMERIC(18,5),
     CHARGE_OFF_DT        DATE,
     CHARGE_OFF_AMT       NUMERIC(18,5),
     LATEST_MTH_PREM_AMT  NUMERIC(18,5),
     GUARANTEE_AMT        NUMERIC(18,5),
     CLOSING_COST_AMT     NUMERIC(18,5),
     APPROVED_ADVANCE_AMT NUMERIC(18,5),
     MAXIMUM_MONTHLY_PAYMENT_AMT NUMERIC(18,5),
     PAYMENT_ADJUSTABLE_CAP_AMT NUMERIC(18,5),
     IMPROVEMENTS_ALLOCATION_AMT NUMERIC(18,5),
     DEBT_PAYMENT_AMT     NUMERIC(18,5),
     MONTHLY_PAYMENT_AMT  NUMERIC(18,5),
     DOWN_PAYMENT_AMT     NUMERIC(18,5),
     APR_RT               NUMERIC(9,4),
     BASE_APR_RT          NUMERIC(9,4),
     VRBLE_CHNG_TIME_FREQUENCY_CD VARCHAR(3),
     FIXED_APR_RT         NUMERIC(9,4),
     FIXED_PERIOD_MONTHS  NUMERIC(6),
     FIXED_VARIABLE_DT    DATE,
     CONVERSION_TO_FIXED_END_DT DATE,
     HOME_STATUS_CD       VARCHAR(3),
     MORTGAGE_STATUS_CD   VARCHAR(3),
     EXCHANGE_DT          DATE,
     REDEEMED_DT          DATE,
     MATURITY_DT          DATE,
     PAYMENT_METHOD_CD    VARCHAR(3),
     COLLECTIONS_STATUS_CD VARCHAR(3),
     CASHBACK_AMT         NUMERIC(18,5),
     CASHBACK_PCT         NUMERIC(9,4),
     LIFE_INSURANCE_FLG   CHARACTER(1),
     INTRODUCER_CD        VARCHAR(3),
     LAST_STATEMENT_DT    DATE,
     REDEMPTION_CHARGES_CD VARCHAR(3),
     OPEN_TO_BUY_AMT      NUMERIC(18,5),
     PROTECTION_FLG       CHARACTER(1),
     PROTECTION_POLICY_NO VARCHAR(20),
     PROTECTION_START_DT  DATE,
     PROTECTION_PREM_RT   NUMERIC(9,4),
     PROTECTION_INS_EXTERNAL_ORG_RK NUMERIC(10),
     PROT_TERM_CONDITION_CD VARCHAR(3),
     PROT_PREM_START_DT   DATE,
     PPI_PREMIUM_FIRST_DUE_DT DATE,
     PREPAYMENT_PENALTY_DT DATE,
     PREPAYMENT_PENALTY_AMT NUMERIC(18,5),
     BUILDINGS_INS_FLG    CHARACTER(1),
     BLDG_INS_PROOF_FLG   CHARACTER(1),
     MONTHS_SINCE_AT_BUREAU_CNT NUMERIC(6),
     BUREAU_CLASS_CD      VARCHAR(3),
     INQUIRY_BUREAU_CNT   NUMERIC(6),
     INTEREST_RATE_CAP_RT NUMERIC(9,4),
     NEXT_PI_ADJUSTMENT_DT DATE,
     PERIOD_CAP_PERCENTAGE_RT NUMERIC(9,4),
     HOME_EQUITY_LOAN_FLG CHARACTER(1),
     DOCUMENTATION_TYPE_CD VARCHAR(3),
     FIRST_TIME_BUYER_FLG CHARACTER(1),
     PRINCIPAL_REPAYMENT_FLG CHARACTER(1),
     ANNUAL_REPAYMENT_PCT NUMERIC(9,4),
     PAYMENT_TIME_FREQUENCY_CD VARCHAR(3),
     PAYMENT_AMT          NUMERIC(18,5),
     FIRST_MORTGAGE_FLG   CHARACTER(1),
     AUTO_PAY_FLG         CHARACTER(1),
     LIEN_INDICATOR_FLG   CHARACTER(1),
     MAINTENANCE_FLG      CHARACTER(1),
     BORROWED_DOWNPAYMENT_FLG CHARACTER(1),
     BORROWED_DOWNPAYMENT_PCT NUMERIC(9,4),
     CASH_ADVANCE_FLG     CHARACTER(1),
     PURPOSE_CD           VARCHAR(3),
     SPECIALIZED_LENDING_CD VARCHAR(3),
     SENIORITY_CD         VARCHAR(3),
     INTEREST_TIER_NO     NUMERIC(5),
     PRE_CREDIT_CD        VARCHAR(3),
     PRE_CREDIT_END_DT    DATE,
     REFINANCE_AMT        NUMERIC(18,5),
     APR_TYPE_CD          VARCHAR(10),
     MINIMUM_PAYMENT_FLG  CHARACTER(1),
     REDRAW_FLG           CHARACTER(1),
     MINIMUM_REDRAW_AMT   NUMERIC(18,5),
     CONVERT_TO_SPLIT_OPTION_FLG CHARACTER(1),
     ORIGIN_CHANNEL_CD    VARCHAR(3),
     FORECLOSURE_FLG      CHARACTER(1),
     ACCOUNT_ID           VARCHAR(32),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     HONEYMOON_FLG        CHARACTER(1),
     HONEYMOON_START_DT   DATE,
     HONEYMOON_END_DT     DATE,
     OFFSET_ACCOUNT_FLG   CHARACTER(1),
     PORTABILITY_FLG      CHARACTER(1),
     PAYMENT_PROTECTION_FLG CHARACTER(1),
     PAYMENT_PROTECTION_STATUS_CD VARCHAR(3),
     PROTECTION_STATUS_CD VARCHAR(3),
     SPLIT_LOAN_FLG       CHARACTER(1),
     FIXED_INT_END_DT     DATE,
     CONVERTIBLE_CD       VARCHAR(3),
     REPAYMENT_HOLIDAY_FLG CHARACTER(1),
     REPAYMENT_HOLIDAY_START_DT DATE,
     REPAYMENT_HOLIDAY_END_DT DATE,
     SPECIAL_INTEREST_RT  NUMERIC(9,4),
     SPECIAL_RATE_START_DT DATE,
     SPECIAL_RATE_END_DT  DATE,
     DISBURSEMENT_TYPE_CD VARCHAR(3),
     SPECIAL_RATE_TYPE_CD VARCHAR(3),
     APR_RT_CHANGE_REASON_CD VARCHAR(3),
     MATURITY_CHANGE_REASON_CD VARCHAR(3),
     FIRST_PAYMENT_DT     DATE,
     LAST_PAYMENT_DT      DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     CURRENT_APR_SET_DT   DATE)
     PRIMARY INDEX MORTGAGE_ACCOUNT_PI (ACCOUNT_RK)
;
CREATE TABLE NETTING_SET (
     NETTING_SET_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     NETTING_SET_ID       VARCHAR(32)     NOT NULL,
     OFF_BALANCE_NETTING_TYPE_CD VARCHAR(3),
     INTERNAL_ORG_RK      NUMERIC(10),
     COUNTERPARTY_RK      NUMERIC(10),
     FINANCIAL_INSTRUMENT_TYPE_CD VARCHAR(3),
     MASTER_NETTING_SET_AGRMNT_FLG CHARACTER(1),
     SETTLEMENT_CURRENCY_CD VARCHAR(3),
     MATURITY_DT          DATE,
     EFFECTIVE_FROM_DT    DATE,
     NOVATION_FINANCIAL_POSITION_RK NUMERIC(10),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     MARGIN_AGREEMENT_RK  NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX NETTING_SET_PI (NETTING_SET_RK)
;
CREATE TABLE OPTION_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     OPTION_TYPE_CD       VARCHAR(3),
     STRIKE_CURRENCY_CD   VARCHAR(3),
     PUT_CALL_TYPE_CD     VARCHAR(3),
     EXERCISE_TRANSACTION_COST_PCT NUMERIC(9,4),
     OPTION_FIRST_EXERCISE_DT DATE,
     BERMUDA_FLG          CHARACTER(1),
     BERMUDA_EXERCISE_TIME_FREQ_CD VARCHAR(3),
     COMPOUND_OPTION_FLG  CHARACTER(1),
     DISCRETE_MONITORING_FLG CHARACTER(1),
     DISCRETE_MONITORING_FREQ_CD VARCHAR(3),
     DISCRETE_MONITORING_START_DT DATE,
     FORWARD_START_DT     DATE,
     FORWARD_START_FLG    CHARACTER(1),
     RESET_OPTION_TYPE_CD VARCHAR(3),
     STRIKE_VALUE         NUMERIC(18,5),
     STRIKE_VALUE_TYPE_CD VARCHAR(3),
     BASKET_UNDERLYING_INSTR_CNT NUMERIC(6),
     ASIAN_OPTION_TYPE_CD VARCHAR(3),
     WARRANTS_ISSUED_NO   NUMERIC(6),
     BARRIER_FEATURE_RK   NUMERIC(10),
     BARRIER_OPTION_TYPE_CD VARCHAR(3),
     BASKET_OPTION_TYPE_CD VARCHAR(3),
     CHOOSER_OPTION_TYPE_CD VARCHAR(10),
     COMPOUND_OPTION_TYPE_CD VARCHAR(10),
     CORRELATION_MATRIX_RK NUMERIC(10),
     DISCRETE_MONITORING_END_DT DATE,
     SECOND_STRIKE_VALUE_TYPE_CD VARCHAR(3),
     SECOND_STRIKE_VALUE  NUMERIC(18,5),
     RESET_DT             DATE,
     OPTION_STYLE_CD      VARCHAR(3),
     OPTION_STRIKE_QUOTE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX OPTION_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE OPTION_INSTRUMENT_QUOTE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX OPTION_INSTRUMENT_QUOTE_PI (FINANCIAL_INSTRUMENT_RK,QUOTE_DTTM)
;
CREATE TABLE OPTION_SCHEDULE (
     OPTION_SCHEDULE_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     OPTION_SCHEDULE_ID   VARCHAR(32),
     OPTION_SCHEDULE_TYPE_CD VARCHAR(3),
     OPTION_SCHEDULE_DT   DATE,
     STRIKE_VALUE         NUMERIC(18,5),
     STRIKE_VALUE_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     EMBEDDED_OPTION_RK   NUMERIC(10),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10))
     PRIMARY INDEX OPTION_SCHEDULE_PI (OPTION_SCHEDULE_RK)
;
CREATE TABLE ORG_CREDIT_ASSESSMENT (
     ORG_RK               NUMERIC(10)     NOT NULL,
     ASSESSMENT_MODEL_RK  NUMERIC(10)     NOT NULL,
     ASSESSMENT_DT        DATE     NOT NULL,
     ASSESSMENT_RESULT_TYPE_CD VARCHAR(3)     NOT NULL,
     CURRENCY_CD          VARCHAR(3)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10)     NOT NULL,
     OVERRIDE_RATING_FLG  CHARACTER(1),
     ASSESSMENT_RESULT_RT NUMERIC(9,4),
     ASSESS_CHANGE_REASON_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     DOMESTIC_CURR_ASSESSMENT_FLG CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX ORG_CREDIT_ASSESSMENT_PI (ORG_RK,ASSESSMENT_MODEL_RK,ASSESSMENT_DT,ASSESSMENT_RESULT_TYPE_CD,CURRENCY_CD)
;
CREATE TABLE OTHER_AGREEMENT (
     OTHER_AGR_RK         NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     OTHER_AGR_ID         VARCHAR(32)     NOT NULL,
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX OTHER_AGREEMENT_PI (OTHER_AGR_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE OTHER_INSURED_SUBJECT (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBJECT_ID           VARCHAR(32)     NOT NULL,
     SUBJECT_INSURANCE_CD VARCHAR(3),
     ITEM_DESC            VARCHAR(255),
     ITEM_VALUE_AMT       NUMERIC(18,5),
     VALUATION_CD         VARCHAR(3),
     AGREED_VALUE_IND     CHARACTER(1),
     OTHER_AGR_RK         NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     APPLICATION_RK       NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX OTHER_INSURED_SUBJECT_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE PARAMETER_LOCATOR (
     PARAMETER_NM         VARCHAR(32)     NOT NULL,
     TABLE_NM             VARCHAR(30),
     COLUMN_NM            VARCHAR(30),
     ROW_VALUE            VARCHAR(32),
     LOCATOR_TYPE_CD      VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PARAMETER_LOCATOR_PI (PARAMETER_NM)
;
CREATE TABLE PARAMETER_VALUES (
     PARAM_VALUE_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PARAMETER_NM         VARCHAR(50),
     PARAMETER_VALUE      VARCHAR(100),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PARAMETER_VALUES_PI (PARAM_VALUE_RK)
;
CREATE TABLE PARTY (
     PARTY_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PARTY_ID             VARCHAR(32)     NOT NULL,
     PARTY_TYPE_CD        VARCHAR(20),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PARTY_PI (PARTY_RK)
;
CREATE TABLE PARTY_ROLES (
     PARTY_ROLE_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PARTY_RK             NUMERIC(10)     NOT NULL,
     PARTY_ROLE_CD        VARCHAR(20),
     CLAIM_RK             NUMERIC(10)     NOT NULL,
     REFERENCE_TYPE_CD    VARCHAR(20),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PARTY_ROLES_PI (PARTY_ROLE_RK)
;
CREATE TABLE PAYEE (
     PAYEE_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PAYEE_ID             VARCHAR(32)     NOT NULL,
     PAYEE_RELATION_ROLE_CD VARCHAR(3),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PAYEE_PI (PAYEE_RK)
;
CREATE TABLE PAYOUT (
     PAYOUT_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PAYOUT_TYPE_CD       VARCHAR(3)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     INCOME_OPTION_CD     VARCHAR(3),
     NUM_MODAL_PAYOUTS    NUMERIC(6),
     PAYOUT_AMT           NUMERIC(18,5),
     PAYOUT_PCT           NUMERIC(9,4),
     PAYOUT_MODE_CD       VARCHAR(3),
     MODAL_PAYOUT_TYPE_CD VARCHAR(3),
     PAYOUT_START_DT      DATE,
     PAYOUT_END_DT        DATE,
     PAYOUT_FORM_CD       VARCHAR(3),
     PAYOUT_PERIOD_CD     VARCHAR(3),
     ANNUAL_INDEX_RT      NUMERIC(9,4),
     PAYOUT_INDEX_CD      VARCHAR(3),
     ANNUAL_FLAT_INCREASE_AMT NUMERIC(18,5),
     LEVELIZATION_OPTION_CD VARCHAR(3),
     GUAR_PAYOUT_AMT      NUMERIC(18,5),
     ANNUITIZATION_CAPITAL_AMT NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PAYOUT_PI (PAYOUT_RK)
;
CREATE TABLE PERIL (
     PERIL_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PERIL_CD             VARCHAR(3)     NOT NULL,
     PERIL_NM             VARCHAR(50),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PERIL_PI (PERIL_RK)
;
CREATE TABLE PERS_ACCIDENT_AGREEMENT (
     PERS_ACCIDENT_AGR_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PERS_ACCIDENT_AGR_ID VARCHAR(32)     NOT NULL,
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     GROUP_POLICY_IND     CHARACTER(1),
     INDEX_PCT            NUMERIC(9,4),
     INDEX_BASE_CD        VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PERS_ACCIDENT_AGREEMENT_PI (PERS_ACCIDENT_AGR_RK)
;
CREATE TABLE PERS_DRIVER_DETAILS (
     DRIVER_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     DRIVER_TRAINING_IND  CHARACTER(1),
     DRIVER_TYPE_CD       VARCHAR(3),
     GOOD_DRIVER_IND      CHARACTER(1),
     GOOD_STUDENT_DT      DATE,
     GOOD_STUDENT_EXPIRATION_DT DATE,
     GOOD_STUDENT_CD      VARCHAR(3),
     MATURE_DRIVER_DT     DATE,
     MATURE_DRIVER_EXPIRATION_DT DATE,
     MATURE_DRIVER_IND    CHARACTER(1),
     REINSTATEMENT_DT     DATE,
     RESIDENT_CUSTODY_IND CHARACTER(1),
     RESTRICTED_IND       CHARACTER(1),
     SUSPENSION_REVOCATION_DT DATE,
     SUSPENSION_REASON_CD VARCHAR(3),
     EFFECTIVE_DT         DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PERS_DRIVER_DETAILS_PI (DRIVER_RK)
;
CREATE TABLE PERS_MOTOR_AGREEMENT (
     PERS_MOTOR_AGR_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PERS_MOTOR_AGR_ID    VARCHAR(32)     NOT NULL,
     NUM_LICENSED         NUMERIC(6),
     NUM_NOT_LICENSED     NUMERIC(6),
     CONTINUOUS_INSURANCE_CD VARCHAR(3),
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PERS_MOTOR_AGREEMENT_PI (PERS_MOTOR_AGR_RK)
;
CREATE TABLE PERS_PROP_CONSTR_DETAILS (
     PERS_PROP_CONSTR_RK  NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CONSTR_CD            VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     CONSTR_DESC          VARCHAR(255),
     INSURER_CONSTR_CLASS_CD VARCHAR(3),
     CONSTR_BEGAN_DT      DATE,
     CONSTR_EST_END_DT    DATE,
     CONSTR_COST_AMT      NUMERIC(18,5),
     BUILT_YR             NUMERIC(4),
     FOUNDATION_CD        VARCHAR(3),
     BLDG_AREA            NUMERIC(14,4),
     NUM_STORIES          NUMERIC(6),
     NUM_UNITS            NUMERIC(6),
     BASEMENT_AREA        NUMERIC(14,4),
     NUM_BASEMENTS        NUMERIC(6),
     EARTHQUAKE_BLDG_GROUND_CD VARCHAR(3),
     ROOFING_MATERIAL     VARCHAR(50),
     STORM_SHUTTERS_CD    VARCHAR(3),
     HURRICANE_RESISTIVE_GLASS_IND CHARACTER(1),
     EARTHQUAKE_BLDG_CLASS_CD VARCHAR(3),
     EARTHQUAKE_RETROFIT_CD VARCHAR(3),
     ELECTRICAL_PANEL_CD  VARCHAR(3),
     INSULATION_TYPE_CD   VARCHAR(3),
     GLASS_TYPE_CD        VARCHAR(3),
     LOB_RK               NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PERS_PROP_CONSTR_DETAILS_PI (PERS_PROP_CONSTR_RK)
;
CREATE TABLE PERS_PROP_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBJECT_INSURANCE_CD VARCHAR(3),
     SERIAL_NO            VARCHAR(50)     NOT NULL,
     MANUFACTURER_NM      VARCHAR(50),
     MODEL_NM             VARCHAR(50),
     MODEL_YR             NUMERIC(4),
     PURCHASE_AMT         NUMERIC(18,5),
     VALUATION_TYPE_CD    VARCHAR(3),
     ITEM_DESC            VARCHAR(255),
     ITEM_VALUE_AMT       NUMERIC(18,5),
     VALUATION_CD         VARCHAR(3),
     AGREED_VALUE_IND     CHARACTER(1),
     PURCHASE_DT          DATE,
     PURCHASE_PRICE_AMT   NUMERIC(18,5),
     WIRING_TYPE_CD       VARCHAR(3),
     FLOOR_UNIT_LOCATED   NUMERIC(9),
     NUM_OTHER_STRUCTURES NUMERIC(6),
     OTHER_STRUCTURE_AMT  NUMERIC(18,5),
     ADDITIONAL_RESIDENCE_IND CHARACTER(1),
     THERMOSTAT_CENTRAL_HEAT_IND CHARACTER(1),
     TOTAL_INSURABLE_REPL_COST_AMT NUMERIC(18,5),
     ROOF_CONDITION_CD    VARCHAR(3),
     OCCUPANCY_YR         NUMERIC(4),
     NUM_ROOMS            NUMERIC(6),
     FIRE_PROTECTION_CLASS_CD VARCHAR(3),
     DISTANCE_TO_FIRE_STATION NUMERIC(14,4),
     RESIDENCE_TYPE_CD    VARCHAR(3),
     DISTANCE_TO_HYDRANT  NUMERIC(14,4),
     DWELL_USE_CD         VARCHAR(3),
     NUM_KITCHENS         NUMERIC(6),
     CONSTR_QUALITY_CD    VARCHAR(3),
     FIRE_EXTINGUISHER_IND CHARACTER(1),
     OCCUPANCY_TYPE_CD    VARCHAR(3),
     OCCUPANCY_TYPE_DURATION NUMERIC(9,4),
     FIRE_EC_RT           NUMERIC(9,4),
     PROTECTION_DEVICE_SMOKE_CD VARCHAR(3),
     DAYTIME_OCCUPANCY_IND CHARACTER(1),
     TERRITORY_CD         VARCHAR(3),
     NUM_FIRE_DIV         NUMERIC(6),
     DOOR_LOCK_CD         VARCHAR(3),
     SPRINKLERED_PCT      NUMERIC(9,4),
     NUM_STORIES          NUMERIC(6),
     NUM_SMOKE_ALARMS     NUMERIC(6),
     PROPERTY_AGR_RK      NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     LOCATION_RK          NUMERIC(10),
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     APPLICATION_RK       NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PERS_PROP_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE PERS_VEHICLE_DETAILS (
     VEHICLE_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VEHICLE_NO           VARCHAR(32)     NOT NULL,
     BUMPER_DISCOUNT_IND  CHARACTER(1),
     CARPOOL_IND          CHARACTER(1),
     DAMAGEABILITY_CD     VARCHAR(3),
     DAYTIME_RUNNING_LIGHT_IND CHARACTER(1),
     EXISTING_UNREPAIRED_DAMAGE_IND CHARACTER(1),
     GARAGING_CD          VARCHAR(3),
     MAX_SPEED            NUMERIC(14,4),
     DISTANCE_ONE_WAY     NUMERIC(14,4),
     MULTI_CAR_DISCOUNT_IND CHARACTER(1),
     NEW_VEH_IND          CHARACTER(1),
     NON_OWNED_VEH_IND    CHARACTER(1),
     NUM_YOUTHFUL_OPERATORS NUMERIC(6),
     ODOMETER_READING     NUMERIC(14,4),
     PRICING_CD           VARCHAR(3),
     PRINCIPAL_OPERATOR_IND CHARACTER(1),
     SEEN_CAR_IND         CHARACTER(1),
     COMMUTING_DEST_TERRITORY_CD VARCHAR(3),
     ALTERATIONS_AMT      NUMERIC(18,5),
     VEH_INSPECTION_STATUS_CD VARCHAR(3),
     VEH_PERFORMANCE_CD   VARCHAR(3),
     VEH_USE_CD           VARCHAR(3),
     ALT_DRV_STATE_REGION_CD VARCHAR(3),
     ALT_DRV_STATE_REGION_USE_PCT NUMERIC(9,4),
     NUM_PASSENGERS       NUMERIC(6),
     REASON_LIAB_REFUSED_CD VARCHAR(3),
     RESIDUAL_MKT_FACILITY_TIER_DT DATE,
     RESIDUAL_MKT_FACILITY_TIER_CD VARCHAR(3),
     INITIAL_REGISTRATION_DT DATE,
     LICENSE_PLATE_TYPE_CD VARCHAR(3),
     NUM_PREV_OWNER       NUMERIC(6),
     VEH_POWER_SIZE       NUMERIC(14,4),
     VEH_POWER_UNIT_CD    VARCHAR(3),
     PERS_MOTOR_AGR_RK    NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     APPLICATION_RK       NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXPERS_VEHICLE_DETAILS (VEHICLE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE PHYSICAL_ASSET (
     PHYSICAL_ASSET_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INS_PROVIDER_EXT_ORG_RK NUMERIC(10),
     ASSET_VALUE_AMT      NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     PHYSICAL_ASSET_TYPE_CD VARCHAR(3),
     ASSET_TYPE_CD        VARCHAR(3),
     VALUATION_DT         DATE,
     PHYSICAL_ASSET_ID    VARCHAR(32),
     ASSET_DESC           VARCHAR(100),
     ASSET_LOCATION_COUNTRY_CD VARCHAR(3),
     ASSET_LOCATION_POSTAL_CD VARCHAR(20),
     PROPERTY_RK          NUMERIC(10),
     VALUE_TO_BANK_RT     NUMERIC(9,4),
     REGULATORY_PRODUCT_CD VARCHAR(3),
     INTERNAL_REPORTING_CATEGORY_CD VARCHAR(3),
     PHYSICAL_ASSET_INS_FLG CHARACTER(1),
     INSURED_AMT          NUMERIC(18,5),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     REVALUATION_DAYS_CNT NUMERIC(6),
     CIC_CD               VARCHAR(4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PHYSICAL_ASSET_PI (PHYSICAL_ASSET_RK)
;
CREATE TABLE PHYSICAL_ASSET_CREDIT_ASSESS (
     PHYSICAL_ASSET_RK    NUMERIC(10)     NOT NULL,
     ASSESSMENT_DT        DATE     NOT NULL,
     ASSESSMENT_MODEL_RK  NUMERIC(10)     NOT NULL,
     ASSESSMENT_RESULT_TYPE_CD VARCHAR(3)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10),
     OVERRIDE_RATING_FLG  CHARACTER(1),
     ASSESSMENT_RESULT_RT NUMERIC(9,4),
     CR_MITIGANT_ADJUSTED_FLG CHARACTER(1),
     PRINCIPAL_ONLY_FLG   CHARACTER(1),
     ASSESS_CHANGE_REASON_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATING_GRADE_PI (PHYSICAL_ASSET_RK,ASSESSMENT_DT,ASSESSMENT_MODEL_RK,ASSESSMENT_RESULT_TYPE_CD)
;
CREATE TABLE PHYSICAL_ASSET_QUOTE (
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     PHYSICAL_ASSET_RK    NUMERIC(10)     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     RISK_FACTOR_ID       VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PHYSICAL_ASSET_QUOTE_PI (QUOTE_DTTM,MARKET_CD,PHYSICAL_ASSET_RK)
;
CREATE TABLE PHYSICAL_COLLATERAL (
     PHYSICAL_COLLATERAL_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PHYSICAL_COLLATERAL_ID VARCHAR(32),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     REALIZATION_CURRENCY_CD VARCHAR(3),
     PHYSICAL_COLLATERAL_SUBTYPE_CD VARCHAR(3),
     DEPRECIATION_RT      NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PHYSICAL_COLLATERAL_PI (PHYSICAL_COLLATERAL_RK)
;
CREATE TABLE PHYSICIAN (
     PHYSICIAN_RK         NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PHYSICIAN_ID         VARCHAR(32)     NOT NULL,
     PHYSICIAN_SPECIALITY_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXPHYSICIAN (PHYSICIAN_RK)
;
CREATE TABLE POLICY_MODEL_SCORE (
     POLICY_RK            NUMERIC(10)     NOT NULL,
     MODEL_RK             NUMERIC(10)     NOT NULL,
     SCORE_DT             DATE     NOT NULL,
     MODEL_SCORE_NO       NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX POLICY_MODEL_SCORE_PI (POLICY_RK,MODEL_RK,SCORE_DT)
;
CREATE TABLE POLICY_SEGMENT (
     POLICY_RK            NUMERIC(10)     NOT NULL,
     MODEL_RK             NUMERIC(10)     NOT NULL,
     SCORE_DT             DATE     NOT NULL,
     SEGMENT_CD           VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX POLICY_SEGMENT_PI (POLICY_RK,MODEL_RK,SCORE_DT)
;
CREATE TABLE PORCH_TYPE_DETAILS (
     PORCH_TYPE_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PORCH_TYPE_CD        VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     NUM_PORCHES          NUMERIC(6),
     BASEMENT_IND         CHARACTER(1),
     SURFACE_AREA         NUMERIC(14,4),
     BREEZEWAY_TYPE_CD    VARCHAR(3),
     FOUNDATION_CD        VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PORCH_TYPE_DETAILS_PI (PORCH_TYPE_RK)
;
CREATE TABLE PORTFOLIO (
     PORTFOLIO_ID         VARCHAR(32)     NOT NULL,
     PORTFOLIO_TYPE_CD    VARCHAR(3),
     PORTFOLIO_SUBTYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PORTFOLIO_PI (PORTFOLIO_ID)
;
CREATE TABLE POSTAL_CD_EXTERNAL_DATA (
     POSTAL_CD            VARCHAR(20)     NOT NULL,
     STATE_REGION_CD      VARCHAR(4)     NOT NULL,
     FROM_DT              DATE     NOT NULL,
     COUNTRY_CD           VARCHAR(3)     NOT NULL,
     TO_DT                DATE,
     POPULATION_GROWTH_RT NUMERIC(9,4),
     AVG_PERSONAL_INCOME_GROWTH_RT NUMERIC(9,4),
     HOUSE_PRICE_INDEX_RT NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX POSTAL_CD_EXTERNAL_DATA_PI (POSTAL_CD,STATE_REGION_CD,FROM_DT,COUNTRY_CD)
;
CREATE TABLE POWER_OPTION_INSTRUMENT (
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     POWER_OPTION_TYPE_CD VARCHAR(3),
     POWER_NO             NUMERIC(18,5),
     CAPPED_PAYOFF_AMT    NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX POWER_OPTION_INSTRUMENT_PI (VALID_FROM_DTTM,FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE PREMIUM_LOSS_SUMMARY (
     ACCIDENT_YR          NUMERIC(4)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     INTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     RISK_LOCATION_COUNTRY_CD VARCHAR(3)     NOT NULL,
     AMT_TYPE_CD          VARCHAR(3)     NOT NULL,
     WRITTEN_PREMIUM_AMT  NUMERIC(18,5),
     EARNED_PREMIUM_AMT   NUMERIC(18,5),
     INCURRED_LOSS_AMT    NUMERIC(18,5),
     PAID_LOSS_AMT        NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PREMIUM_LOSS_SUMMARY_PI (ACCIDENT_YR,LOB_RK,INTERNAL_ORG_RK,RISK_LOCATION_COUNTRY_CD,AMT_TYPE_CD)
;
CREATE TABLE PRESCRIPTION_DRUG_DETAILS (
     PRESCRIPTION_DRUG_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRESCRIPTION_DRUG_TYPE_CD VARCHAR(3)     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     PRESCRIPTION_CD      VARCHAR(3),
     PRESCRIPTION_LABEL   VARCHAR(100),
     PRESCRIPTION_DOSAGE_UNIT_CD VARCHAR(3),
     PRESCRIPTION_DOSAGE_STRENGTH NUMERIC(9),
     PRESCRIPTION_DOSAGE_FORM_CD VARCHAR(3),
     THERAPEUTIC_CLASS_CD VARCHAR(3),
     AVG_WHOLESALE_UNIT_COST_AMT NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRESCRIPTION_DRUG_DETAILS_PI (PRESCRIPTION_DRUG_RK)
;
CREATE TABLE PRODUCER (
     PRODUCER_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRODUCER_ID          VARCHAR(32)     NOT NULL,
     PRODUCER_TYPE_CD     VARCHAR(3),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     MANAGING_EMPLOYEE_RK NUMERIC(10),
     TRAINING_IND         CHARACTER(1),
     PRODUCER_STATUS_CD   VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRODUCER_PI (PRODUCER_RK)
;
CREATE TABLE PRODUCER_LICENSE (
     PRODUCER_RK          NUMERIC(10)     NOT NULL,
     LICENSE_NO           VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LICENSE_ISSUE_DT     DATE,
     LICENSE_STATUS_CD    VARCHAR(3),
     LICENSE_STATUS_DT    DATE,
     LICENSE_ISSUE_STATE_REGION_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRODUCER_LICENSE_PI (PRODUCER_RK,LICENSE_NO)
;
CREATE TABLE PRODUCER_TARGETS (
     TARGET_TYPE_CD       VARCHAR(3)     NOT NULL,
     TARGET_MON_YR        DATE     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRODUCER_RK          NUMERIC(10)     NOT NULL,
     TARGET_VALUE         NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRODUCER_TARGETS_PI (TARGET_TYPE_CD,TARGET_MON_YR,PRODUCER_RK)
;
CREATE TABLE PRODUCER_TRANS (
     PRODUCER_TRANS_ID    VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     PRODUCER_RK          NUMERIC(10)     NOT NULL,
     REFERENCE_NO         VARCHAR(32),
     PAYMENT_METHOD_CD    VARCHAR(3),
     TOTAL_TRANS_AMT      NUMERIC(18,5),
     TRANS_DT             DATE,
     EFFECTIVE_DT         DATE,
     AS_OF_DT             DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRODUCER_TRANS_PI (PRODUCER_TRANS_ID,SOURCE_SYSTEM_CD)
;
CREATE TABLE PRODUCER_TRANS_LINE_ITEM (
     PRODUCER_TRANS_ID    VARCHAR(32)     NOT NULL,
     PRODUCER_TRANS_LINE_ITEM_ID VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     COMMISSION_TYPE_CD   VARCHAR(3),
     TRANS_TYPE_CD        VARCHAR(3),
     PAYMENT_BASIS_AMT    NUMERIC(18,5),
     LINE_ITEM_TRANS_AMT  NUMERIC(18,5),
     POLICY_RK            NUMERIC(10),
     UOE_RK               NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRODUCER_TRANS_LINE_ITEM_PI (PRODUCER_TRANS_ID,PRODUCER_TRANS_LINE_ITEM_ID,SOURCE_SYSTEM_CD)
;
CREATE TABLE PRODUCER_X_INTERNAL_ORG (
     INTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     TARGET_TYPE_CD       VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRODUCER_RK          NUMERIC(10)     NOT NULL,
     TARGET_VALUE         NUMERIC(18,5),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRODUCER_X_INTERNAL_ORG_PI (INTERNAL_ORG_RK,TARGET_TYPE_CD,PRODUCER_RK)
;
CREATE TABLE PRODUCER_X_UOE (
     UOE_RK               NUMERIC(10)     NOT NULL,
     COMMISSION_TYPE_CD   VARCHAR(3)     NOT NULL,
     EFFECTIVE_DT         DATE     NOT NULL,
     PRODUCER_RK          NUMERIC(10)     NOT NULL,
     COMMISSION_AMT       NUMERIC(18,5),
     EXPIRATION_DT        DATE,
     SPLIT_PCT            NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRODUCER_X_UOE_PI (UOE_RK,COMMISSION_TYPE_CD,EFFECTIVE_DT,PRODUCER_RK)
;
CREATE TABLE PRODUCT_CATEGORY (
     PRODUCT_CATEGORY_RK  NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRODUCT_CATEGORY_CD  VARCHAR(3)     NOT NULL,
     PRODUCT_CATEGORY_DESC VARCHAR(255),
     PRODUCT_CATEGORY_TYPE_CD VARCHAR(3)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX INSURANCE_PRODUCT_CATEGORY (PRODUCT_CATEGORY_RK)
;
CREATE TABLE PRODUCT_COVERAGE (
     PRODUCT_COVERAGE_RK  NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRODUCT_COVERAGE_CD  VARCHAR(3)     NOT NULL,
     PRODUCT_SECTION_RK   NUMERIC(10)     NOT NULL,
     COVERAGE_RK          NUMERIC(10)     NOT NULL,
     PRODUCT_COVERAGE_DESC VARCHAR(100),
     OPTIONAL_COVERAGE_FLG CHARACTER(1),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     LOB_RK               NUMERIC(10))
     PRIMARY INDEX COVERAGE (PRODUCT_COVERAGE_RK)
;
CREATE TABLE PRODUCT_FEATURES (
     FEATURE_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FEATURE_CD           VARCHAR(3)     NOT NULL,
     FEATURE_NM           VARCHAR(40),
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     SELECTION_RULE_CD    VARCHAR(3),
     MAX_NUM_INSTANCES    NUMERIC(6),
     RIDER_TYPE_CD        VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXPRODUCT_FEATURES (FEATURE_RK)
;
CREATE TABLE PRODUCT_SECTION (
     PRODUCT_SECTION_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PRODUCT_SECTION_CD   VARCHAR(3)     NOT NULL,
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     SECTION_RK           NUMERIC(10)     NOT NULL,
     PRODUCT_SECTION_DESC VARCHAR(100),
     OPTIONAL_SECTION_FLG CHARACTER(1),
     MIN_POLICY_PERIOD_IN_MTHS NUMERIC(9),
     CANCELATION_PERIOD_IN_MTHS NUMERIC(9),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     LOB_RK               NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PRODUCT_SECTION_PI (PRODUCT_SECTION_RK)
;
CREATE TABLE PROFIT_CENTER (
     PROFIT_CENTER_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PROFIT_CENTER_ID     VARCHAR(32)     NOT NULL,
     PROFIT_CENTER_NM     VARCHAR(50),
     PROFIT_CENTER_DESC   VARCHAR(255),
     RESPONSIBLE_EMPLOYEE_RK NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PROFIT_CENTER_PI (PROFIT_CENTER_RK)
;
CREATE TABLE PROFIT_CENTER_ASSOC (
     PROFIT_CENTER_RK     NUMERIC(10)     NOT NULL,
     PARENT_PROFIT_CENTER_RK NUMERIC(10)     NOT NULL,
     PROFIT_CENTER_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PROFIT_CENTER_ASSOC_PI (PROFIT_CENTER_RK,PARENT_PROFIT_CENTER_RK,PROFIT_CENTER_ASSOC_TYPE_CD)
;
CREATE TABLE PROPERTY (
     PROPERTY_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROPERTY_ID          VARCHAR(32),
     SOURCE_SYSTEM_CD     VARCHAR(3),
     PROPERTY_TYPE_CD     VARCHAR(3),
     PROPERTY_YEAR_BUILT  NUMERIC(4),
     CENSUS_BLOCK_GROUP_CD VARCHAR(3),
     CENSUS_TRACT_CD      VARCHAR(3),
     ADDRESS_LINE_1_TXT   VARCHAR(100),
     ADDRESS_LINE_2_TXT   VARCHAR(100),
     ADDRESS_LINE_3_TXT   VARCHAR(100),
     ADDRESS_LINE_4_TXT   VARCHAR(100),
     CITY_NM              VARCHAR(100),
     POSTAL_CD            VARCHAR(20),
     COUNTY_NM            VARCHAR(40),
     STATE_REGION_CD      VARCHAR(4),
     COUNTRY_CD           VARCHAR(3),
     PARCEL_ID            VARCHAR(20),
     PROPERTY_CONSTRUCTION_TYPE_CD VARCHAR(3),
     BUILDING_STATUS_TYPE_CD VARCHAR(3),
     RIGHTS_TYPE_CD       VARCHAR(3),
     YEAR_ACQUIRED        NUMERIC(4),
     NUMBER_OF_UNITS_CNT  NUMERIC(6),
     GROSS_LIVING_AREA    VARCHAR(20),
     GROSS_LIVING_AREA_UOM_CD VARCHAR(3),
     STRUCTURE_TYPE_CD    VARCHAR(3),
     LEASEHOLD_EXPIRATION_DT DATE,
     ORIGINAL_COST_AMT    NUMERIC(18,5),
     APPRAISED_VALUE_AMT  NUMERIC(18,5),
     ESTIMATED_VALUE_AMT  NUMERIC(18,5),
     ALARMED_FLG          CHARACTER(1),
     LIEN_INDICATOR_FLG   CHARACTER(1),
     BEDROOMS_CNT         NUMERIC(6),
     BUSINESS_USE_FLG     CHARACTER(1),
     BUILD_ERA_CD         VARCHAR(3),
     GARAGES_CNT          NUMERIC(6),
     NEIGHBORHOOD_WATCH_FLG CHARACTER(1),
     APPROVED_LOCKS_FLG   CHARACTER(1),
     UNOCCUPIED_THIRTY_FLG CHARACTER(1),
     HOME_EMPTY_FLG       CHARACTER(1),
     ROOF_CONSTRUCTION_CD VARCHAR(3),
     SMOKE_ALARM_FLG      CHARACTER(1),
     BURGLAR_ALARM_FLG    CHARACTER(1),
     BURGLAR_ALARM_TYPE_CD VARCHAR(3),
     FIRE_DEPT_DISTANCE   NUMERIC(10),
     FIRE_HYDRANT_DISTANCE NUMERIC(10),
     DISTANCE_UOM_CD      VARCHAR(3),
     WIRING_LAST_UPDATE_DT DATE,
     PLUMBING_LAST_UPDATE_DT DATE,
     HEATING_LAST_UPDATE_DT DATE,
     APPRAISAL_DT         DATE,
     STATISTICAL_AREA_CD  VARCHAR(3),
     CURRENCY_CD          VARCHAR(3),
     JUDICIAL_PROCEEDINGS_REQ_FLG CHARACTER(1),
     OWNER_OCCUPANCY_FLG  CHARACTER(1),
     NET_INCOME_AMT       NUMERIC(18,5),
     LAND_AREA            NUMERIC(18,5),
     LAND_AREA_UOM_CD     VARCHAR(3),
     TOTAL_BUILDING_AREA  NUMERIC(18,5),
     TOTAL_BUILDING_AREA_UOM_CD VARCHAR(3),
     COMMERCIAL_USABLE_AREA NUMERIC(18,5),
     COMMERCIAL_USABLE_AREA_UOM_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PROPERTY_PI (PROPERTY_RK)
;
CREATE TABLE PROPERTY_AGREEMENT (
     PROPERTY_AGR_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PROPERTY_AGR_ID      VARCHAR(32)     NOT NULL,
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     LOCATION_RK          NUMERIC(10),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PROPERTY_AGREEMENT_PI (PROPERTY_AGR_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE PROP_LOSS_DETAILS (
     PROP_LOSS_RK         NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     SUBJECT_INSURANCE_CD VARCHAR(3)     NOT NULL,
     BLDG_NO              VARCHAR(32),
     REAL_ESTATE_TYPE_CD  VARCHAR(3),
     LOSS_KIND_CD         VARCHAR(3),
     OBJECT_LOSS_DESC     VARCHAR(255),
     DAMAGE_DESC          VARCHAR(255),
     WHERE_SEEN_DESC      VARCHAR(255),
     OTHER_INSURANCE_IND  CHARACTER(1),
     MORTGAGEE_IND        CHARACTER(1),
     OCCUPANCY_TYPE_CD    VARCHAR(3),
     INCENDIARY_FIRE_IND  CHARACTER(1),
     THEFT_LOCATION_CD    VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX PROP_LOSS_DETAILS_PI (PROP_LOSS_RK)
;
CREATE TABLE QUANTO_FEATURE (
     QUANTO_FEATURE_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     QUANTO_FEATURE_ID    VARCHAR(32),
     QUANTO_FLG           CHARACTER(1),
     QUANTO_EXCHANGE_RT   NUMERIC(9,4),
     QUANTO_CURRENCY_CD   VARCHAR(3),
     QUANTO_TYPE_CD       VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX QUANTO_FEATURE_PI (QUANTO_FEATURE_RK)
;
CREATE TABLE QUOTE (
     QUOTE_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     QUOTE_NO             VARCHAR(32)     NOT NULL,
     ITERATION_NO         NUMERIC(5),
     INSURED_FULL_TO_BE_PAID_AMT NUMERIC(18,5),
     QUOTE_STATUS_CD      VARCHAR(3),
     STATUS_CHANGE_DT     DATE,
     DECLINATION_REASON_CD VARCHAR(3),
     QUOTE_CONDITIONS_CD  VARCHAR(3),
     QUOTE_CONDITIONS_REASON_CD VARCHAR(3),
     INITIAL_QUOTE_REQUEST_DT DATE,
     QUOTE_PREPARED_DT    DATE,
     QUOTE_VALID_UNTIL_DT DATE,
     SALES_CHANNEL_CD     VARCHAR(3),
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     CUSTOMER_RK          NUMERIC(10),
     PRODUCER_RK          NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX QUOTE_PI (QUOTE_RK)
;
CREATE TABLE RACING_DETAILS (
     LIFE_STYLE_ACTIVITY_RK NUMERIC(10)     NOT NULL,
     LAST_RACE_LOCATION   VARCHAR(50),
     LAST_RACE_DT         DATE,
     SPEED_MAX            NUMERIC(9,4),
     SPEED_AVG            NUMERIC(9,4),
     DISTANCE_MAX         NUMERIC(9,4),
     DISTANCE_AVG         NUMERIC(9,4),
     DISTANCE_LAST_RACE   NUMERIC(9,4),
     RACE_TRACK_TYPE_CD   VARCHAR(3),
     SURFACE_TYPE_CD      VARCHAR(3),
     COMPETITION_LICENSE_IND CHARACTER(1),
     DRIVER_SCHOOL_IND    CHARACTER(1),
     STUNT_DRIVING_IND    CHARACTER(1),
     COMPETITION_LOCATION_IND CHARACTER(1),
     PROFESSIONAL_IND     CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RACING_DETAILS_PI (LIFE_STYLE_ACTIVITY_RK)
;
CREATE TABLE RAINBOW_OPTION_INSTRUMENT (
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     CASH_PAYOUT_AMT      NUMERIC(18,5),
     RAINBOW_OPTION_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RAINBOW_OPTION_INSTRUMENT_PI (VALID_FROM_DTTM,FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE RANGE_VALUES (
     RATE_POLICY_RANGE_RK NUMERIC(10)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP     NOT NULL,
     EFFECTIVE_TO_DTTM    TIMESTAMP     NOT NULL,
     RATE_POLICY_RANGE_ID VARCHAR(32),
     NUMERIC_LOWER_BOUND  NUMERIC(18,5),
     NUMERIC_UPPER_BOUND  NUMERIC(18,5),
     DATE_LOWER_BOUND_DTTM TIMESTAMP,
     DATE_UPPER_BOUND_DTTM TIMESTAMP,
     INCLUDE_LOWER_BOUND_FLG CHARACTER(1),
     INCLUDE_UPPER_BOUND_FLG CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RANGE_VALUES_PI (RATE_POLICY_RANGE_RK)
;
CREATE TABLE RATEMAKING_CLAIM_FREQ_SEVERITY (
     UOE_RK               NUMERIC(10)     NOT NULL,
     MODEL_RK             NUMERIC(10)     NOT NULL,
     SCORE_DT             DATE     NOT NULL,
     CLAIM_FREQUENCY      NUMERIC(9,4),
     CLAIM_SEVERITY       NUMERIC(9,2),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATEMAKING_CLAIM_FREQ_SEVER_PI (UOE_RK,MODEL_RK,SCORE_DT)
;
CREATE TABLE RATEMAKING_FACTOR (
     PRODUCT_COVERAGE_CD  VARCHAR(3)     NOT NULL,
     FACTOR_NM            VARCHAR(40)     NOT NULL,
     FACTOR_VALUE         VARCHAR(100)     NOT NULL,
     SCORE_DT             DATE     NOT NULL,
     RELATIVITY           NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATEMAKING_FACTOR_PI (PRODUCT_COVERAGE_CD,FACTOR_NM,FACTOR_VALUE,SCORE_DT)
;
CREATE TABLE RATE_POLICY (
     RATE_POLICY_RK       NUMERIC(10)     NOT NULL,
     RATE_POLICY_ID       VARCHAR(32),
     POLICY_NM            VARCHAR(40),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATE_POLICY_PI (RATE_POLICY_RK)
;
CREATE TABLE RATE_POLICY_PARAMETER (
     POLICY_PARAMETER_NM  VARCHAR(32)     NOT NULL,
     PARAMETER_USAGE_CD   VARCHAR(3)     NOT NULL,
     RATE_POLICY_RANGE_RK NUMERIC(10)     NOT NULL,
     RATE_POLICY_RK       NUMERIC(10)     NOT NULL,
     RATE_POLICY_RATE_RK  NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATE_POLICY_PARAMETER_PI (RATE_POLICY_RK)
;
CREATE TABLE RATE_POLICY_RATE (
     RATE_POLICY_RATE_RK  NUMERIC(10)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP     NOT NULL,
     RATE_POLICY_RATE_ID  VARCHAR(32),
     RATE_POLICY_RT       NUMERIC(9,4),
     EFFECTIVE_TO_DTTM    TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RATE_POLICY_RATE_PI (RATE_POLICY_RATE_RK)
;
CREATE TABLE RECEIVABLES (
     RECEIVABLES_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     INS_PROVIDER_EXT_ORG_RK NUMERIC(10),
     LAST_VALUATION_DT    DATE,
     SOURCE_SYSTEM_CD     VARCHAR(3),
     RECEIVABLES_ID       VARCHAR(32),
     RECEIVABLES_TYPE_CD  VARCHAR(3),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     INSURED_AMT          NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RECEIVABLES_PI (RECEIVABLES_RK)
;
CREATE TABLE RECEIVABLES_POOL (
     RECEIVABLES_POOL_RK  NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     DILUTION_EXPECTED_LOSS_PCT NUMERIC(9,4),
     RECEIVABLES_POOL_ID  VARCHAR(32),
     REGULATORY_POOL_CPTY_TYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RECEIVABLES_POOL_PI (RECEIVABLES_POOL_RK)
;
CREATE TABLE REFERENCE_DETAIL (
     TABLE_NM             VARCHAR(100)     NOT NULL,
     COLUMN_NM            VARCHAR(100)     NOT NULL,
     CODE_VALUE           VARCHAR(30)     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CODE_DESC            VARCHAR(100),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REFERENCE_DETAIL_PI (TABLE_NM,COLUMN_NM,CODE_VALUE)
;
CREATE TABLE REFERENCE_MASTER (
     TABLE_NM             VARCHAR(100)     NOT NULL,
     COLUMN_NM            VARCHAR(100)     NOT NULL,
     FORMAT_NM            VARCHAR(20),
     FORMAT_TYPE          CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REFERENCE_MASTER_PI (TABLE_NM,COLUMN_NM)
;
CREATE TABLE REINSURANCE_CARRIER (
     RI_CARRIER_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RI_NETWORK_ID        VARCHAR(32)     NOT NULL,
     PARTICIPATION_LIMIT_AMT NUMERIC(18,5),
     RI_CARRIER_TYPE_CD   VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_CARRIER_PI (RI_CARRIER_RK)
;
CREATE TABLE REINSURANCE_COLLATERAL (
     COLLATERAL_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COLLATERAL_ID        VARCHAR(32)     NOT NULL,
     COLLATERAL_TYPE_CD   VARCHAR(3),
     COLLATERAL_VALUE     NUMERIC(18,5),
     EFFECTIVE_DTTM       TIMESTAMP,
     EXPIRATION_DTTM      TIMESTAMP,
     RI_CARRIER_RK        NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_COLLATERAL_PI (COLLATERAL_RK)
;
CREATE TABLE REINSURANCE_CONTRACT (
     RI_CONTRACT_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CEDENTS_CONTRACT_ID  VARCHAR(32)     NOT NULL,
     RI_CONTRACT_TYPE_CD  VARCHAR(3),
     APPLICATION_SEQUENCE_NO NUMERIC(6),
     RI_CONTRACT_EFFECTIVE_DT DATE,
     RI_CONTRACT_EXPIRATION_DT DATE,
     TREATY_FACULTATIVE_IND CHARACTER(1),
     NON_TRAD_FIN_RI_FLG  CHARACTER(1),
     NON_PROPORTIONAL_RI_FLG CHARACTER(1),
     RI_PAY_MODE_CD       VARCHAR(3),
     RI_CONTRACT_STATUS_CD VARCHAR(3),
     RI_CONTRACT_STATUS_CHANGE_DT DATE,
     RESERVE_METHOD_CD    VARCHAR(3),
     OFF_SET_ALLOWED_IND  CHARACTER(1),
     MAX_EXP_REFUND_PREM_LIMIT_AMT NUMERIC(18,5),
     MAX_EXP_REFUND_CLAIM_LIMIT_AMT NUMERIC(18,5),
     JUMBO_LIMIT_AMT      NUMERIC(18,5),
     EXPERIENCE_REFUND_IND CHARACTER(1),
     LIFE_RI_METHOD_CD    VARCHAR(3),
     RI_PROGRAM_RK        NUMERIC(10)     NOT NULL,
     INTERNAL_ORG_RK      NUMERIC(10)     NOT NULL,
     PRIMARY_INTERMEDIARY_RK NUMERIC(10),
     RI_CONTRACT_CURRENCY_CD VARCHAR(3),
     SETTLEMENT_CURRENCY_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXREINSURANCE_DETAILS (RI_CONTRACT_RK)
;
CREATE TABLE REINSURANCE_CONTRACT_SECTION (
     RI_CONTRACT_SECTION_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RI_CONTRACT_SECTION_ID VARCHAR(32)     NOT NULL,
     RI_CONTRACT_SECTION_NM VARCHAR(40),
     RI_CONTRACT_SECTION_DESC VARCHAR(100),
     LOSS_COVERAGE_BASIS_CD VARCHAR(3),
     GROSS_RETENTION_AMT  NUMERIC(18,5),
     GROSS_RETENTION_PCT  NUMERIC(9,4),
     RETENTION_BASIS_CD   VARCHAR(3),
     STABILITY_CLAUSE_FLG CHARACTER(1),
     STABILITY_CLAUSE_TRIG_PCT NUMERIC(9,4),
     LAE_ALLOWED_IND      CHARACTER(1),
     ADJ_RECOVERY_IND     CHARACTER(1),
     MIN_PREM_AMT         NUMERIC(18,5),
     DEP_PREM_AMT         NUMERIC(18,5),
     GROSS_PREM_AMT       NUMERIC(18,5),
     LIMIT_AMT            NUMERIC(18,5),
     LIMIT_PCT            NUMERIC(9,4),
     CAT_GUARANTEE_IND    CHARACTER(1),
     BASE_INDEX_CD        VARCHAR(10),
     BASE_INDEX_RT        NUMERIC(18,5),
     EFFECTIVE_DT         DATE,
     EXPIRATION_DT        DATE,
     AGGR_DEDUCTIBLE_AMT  NUMERIC(18,5),
     AGGR_DEDUCTIBLE_PCT  NUMERIC(9,4),
     MAX_COVER_PER_RISK_EVENT NUMERIC(18,5),
     RI_CONTRACT_RK       NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_CONTRACT_SECTIO_PI (RI_CONTRACT_SECTION_RK)
;
CREATE TABLE REINSURANCE_COVERAGE (
     RI_COVERAGE_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RI_COVERAGE_ID       VARCHAR(32)     NOT NULL,
     RI_COVERAGE_DESC     VARCHAR(100),
     RI_COVERAGE_LEVEL_CD VARCHAR(3),
     RI_PREM_BASIS_CD     VARCHAR(3),
     RI_PREM_BASIS_VALUE  NUMERIC(9,4),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     RI_CONTRACT_SECTION_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_COVERAGE_PI (RI_COVERAGE_RK)
;
CREATE TABLE REINSURANCE_COVERAGE_REFERENCE (
     RI_COVERAGE_RK       NUMERIC(10)     NOT NULL,
     RI_COVERAGE_REF_CD   VARCHAR(3)     NOT NULL,
     RI_COVERAGE_REF_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_COVERAGE_REFERE_PI (RI_COVERAGE_RK,RI_COVERAGE_REF_CD,RI_COVERAGE_REF_RK)
;
CREATE TABLE REINSURANCE_EXPOSURE (
     RI_EXP_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     UOE_RK               NUMERIC(10)     NOT NULL,
     RI_CONTRACT_SECTION_RK NUMERIC(10)     NOT NULL,
     RI_EXP_STATUS_CD     VARCHAR(3),
     RI_EXP_EFFECTIVE_DT  DATE,
     RI_EXP_EXPIRATION_DT DATE,
     RI_RENEWAL_DT        DATE,
     REINSURED_AMT        NUMERIC(18,5),
     GROSS_ANNUAL_RI_PREM_AMT NUMERIC(18,5),
     RI_PREMIUM_DUE_DT    DATE,
     RI_PREMIUM_PAID_TO_DT DATE,
     RI_PREMIUM_STATUS_CD VARCHAR(3),
     MODAL_GROSS_STD_PREM_AMT NUMERIC(18,5),
     MODAL_GROSS_STD_ALLOW_AMT NUMERIC(18,5),
     MODAL_GROSS_SUBSTD_ALLOW_AMT NUMERIC(18,5),
     MODAL_GROSS_SUBSTD_PREM_AMT NUMERIC(18,5),
     MODAL_EXPENSE_ALLOWANCE_AMT NUMERIC(18,5),
     CEDING_COMMISSION_AMT NUMERIC(18,5),
     RI_PREMIUM_TAX_AMT   NUMERIC(18,5),
     RI_EXP_CHANGE_REASON_CD VARCHAR(3),
     RI_PREMIUM_RATING_AGE NUMERIC(3),
     RI_AMT_SHARE         NUMERIC(18,5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXREINSURANCE_DETAILS (RI_EXP_RK)
;
CREATE TABLE REINSURANCE_INTERMEDIARY (
     INTERMEDIARY_RK      NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     INTERMEDIARY_ID      VARCHAR(32)     NOT NULL,
     INTERMEDIARY_CD      VARCHAR(20),
     ACTIVITY_TYPE_CD     VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_INTERMEDIARY_PI (INTERMEDIARY_RK)
;
CREATE TABLE REINSURANCE_PROGRAM (
     RI_PROGRAM_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RI_PROGRAM_ID        VARCHAR(32)     NOT NULL,
     RI_PROGRAM_NM        VARCHAR(40),
     RI_PROGRAM_STATUS_CD VARCHAR(3),
     RI_PROGRAM_EFFECTIVE_DT DATE,
     RI_PROGRAM_EXPIRATION_DT DATE,
     FINAL_RETENTION_AMT  NUMERIC(18,5),
     REINSURED_RK         NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_PROGRAM_PI (RI_PROGRAM_RK)
;
CREATE TABLE REINSURANCE_RATE (
     RI_RATE_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RI_RATE_ID           VARCHAR(32)     NOT NULL,
     RI_RATE_TYPE_CD      VARCHAR(3),
     RI_RATE_VALUE_TYPE_CD VARCHAR(3),
     RI_RATE_VALUE        NUMERIC(18,5),
     XL_LAYER_RK          NUMERIC(10),
     RI_CONTRACT_SECTION_RK NUMERIC(10)     NOT NULL,
     SCHEDULE_RK          NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_RATE_PI (RI_RATE_RK)
;
CREATE TABLE REINSURANCE_REINSTATEMENT (
     RI_REINSTATEMENT_RK  NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RI_REINSTATEMENT_ID  VARCHAR(32)     NOT NULL,
     REINSTATEMENT_NO     NUMERIC(6),
     REINSTATED_PCT       NUMERIC(9,4),
     REINSTATED_AMT       NUMERIC(18,5),
     REINSTATEMENT_PREM_AMT NUMERIC(18,5),
     REINSTATEMENT_DT     DATE,
     XL_LAYER_RK          NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_REINSTATEMENT_PI (RI_REINSTATEMENT_RK)
;
CREATE TABLE REINSURANCE_TRANS (
     RI_TRANS_ID          VARCHAR(32)     NOT NULL,
     RI_CONTRACT_RK       NUMERIC(10)     NOT NULL,
     RI_CONTRACT_SECTION_RK NUMERIC(10)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     REFERENCE_NO         VARCHAR(32),
     RI_TRANS_TYPE_CD     VARCHAR(3),
     RI_TRANS_AMT         NUMERIC(18,5),
     RI_TRANS_DT          DATE,
     PAYMENT_METHOD_CD    VARCHAR(3),
     RI_TRANS_CURRENCY_CD VARCHAR(3),
     RI_REINSTATEMENT_RK  NUMERIC(10),
     XL_LAYER_RK          NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_TRANS_PI (RI_TRANS_ID,SOURCE_SYSTEM_CD,RI_CONTRACT_RK)
;
CREATE TABLE REINSURANCE_TRANS_LINE_ITEM (
     RI_TRANS_LINE_ITEM_NO NUMERIC(9)     NOT NULL,
     RI_TRANS_ID          VARCHAR(32)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     RI_CONTRACT_RK       NUMERIC(10)     NOT NULL,
     RI_CONTRACT_SECTION_RK NUMERIC(10)     NOT NULL,
     AMT_TYPE_CD          VARCHAR(3),
     LINE_ITEM_TRANS_AMT  NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REINSURANCE_TRANS_LINE_ITEM_PI (RI_TRANS_LINE_ITEM_NO,RI_TRANS_ID,SOURCE_SYSTEM_CD,RI_CONTRACT_RK,RI_CONTRACT_SECTION_RK)
;
CREATE TABLE REPO_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     REPO_INSTRUMENT_TYPE_CD VARCHAR(5),
     VALUATION_MODEL_ID   VARCHAR(32),
     ELIGIBLE_REPO_CARVE_OUT_FLG CHARACTER(1),
     REPO_PRICE_AMT       NUMERIC(18,5),
     REPO_RT              NUMERIC(9,4),
     REPO_COLLATERAL_EXCHANGE_FLG CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REPO_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE REP_GRP (
     REP_GRP_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     REP_GRP_CD           VARCHAR(3)     NOT NULL,
     SECTION_RK           NUMERIC(10)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     REP_GRP_DESC         VARCHAR(255),
     REP_GRP_TYPE_CD      VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REP_GRP_PI (REP_GRP_RK)
;
CREATE TABLE REP_GRP_ASSOC (
     REP_GRP_RK           NUMERIC(10)     NOT NULL,
     PARENT_REP_GRP_RK    NUMERIC(10)     NOT NULL,
     REP_GRP_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX REP_GRP_ASSOC_PI (REP_GRP_RK,PARENT_REP_GRP_RK,REP_GRP_ASSOC_TYPE_CD)
;
CREATE TABLE RESERVES_ESTIMATES (
     ACCIDENT_YR          NUMERIC(4)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     RESERVE_FORECAST_YR  NUMERIC(4)     NOT NULL,
     RESERVE_AMT          NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RESERVES_ESTIMATES_PI (ACCIDENT_YR,LOB_RK,RESERVE_FORECAST_YR)
;
CREATE TABLE RESPONSE (
     RESPONSE_CD          VARCHAR(30)     NOT NULL,
     COMMUNICATION_CD     VARCHAR(30)     NOT NULL,
     CAMPAIGN_RK          NUMERIC(10)     NOT NULL,
     COMMUNICATION_DTTM   TIMESTAMP     NOT NULL,
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     RESP_TYPE_CD         VARCHAR(30),
     RESP_DTTM            TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RESPONSE_PI (RESPONSE_CD,COMMUNICATION_CD,CAMPAIGN_RK,COMMUNICATION_DTTM,CUSTOMER_RK)
;
CREATE TABLE RF_CURVE_X_RF_GROUP (
     CURVE_ID             VARCHAR(32)     NOT NULL,
     GROUP_ID             VARCHAR(32)     NOT NULL,
     RLN_RISK_FACTOR_ATTRIBUTE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RF_CURVE_X_RF_GROUP_PI (CURVE_ID,GROUP_ID,RLN_RISK_FACTOR_ATTRIBUTE_CD)
;
CREATE TABLE RISK_CATASTROPHE_ZONE (
     RISK_CAT_ZONE_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RISK_CAT_ZONE_ID     VARCHAR(32)     NOT NULL,
     RISK_CAT_ZONE_CD     VARCHAR(3),
     RISK_CAT_ZONE_TYPE_CD VARCHAR(3),
     RISK_CAT_ZONE_DESC   VARCHAR(100),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_CATASTROPHE_ZONE_PI (RISK_CAT_ZONE_RK)
;
CREATE TABLE RISK_CATASTROPHE_ZONE_ASSOC (
     RISK_CAT_ZONE_RK     NUMERIC(10)     NOT NULL,
     PARENT_RISK_CAT_ZONE_RK NUMERIC(10)     NOT NULL,
     CAT_ZONE_ASSOC_TYPE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ORDER_NO             NUMERIC(5),
     LEVEL_NO             NUMERIC(5),
     LEVEL_DESC           VARCHAR(20),
     BOTTOM_LEVEL_FLG     CHARACTER(1),
     LEVELS_FROM_TOP_NO   NUMERIC(5),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_CATASTROPHE_ZONE_ASSOC_PI (RISK_CAT_ZONE_RK,PARENT_RISK_CAT_ZONE_RK,CAT_ZONE_ASSOC_TYPE_CD)
;
CREATE TABLE RISK_DRIVER (
     RISK_DRIVER_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RISK_DRIVER_ID       VARCHAR(32),
     RISK_DRIVER_CD       VARCHAR(3),
     RISK_DRIVER_DESC     VARCHAR(100),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_DRIVER_PI (RISK_DRIVER_RK)
;
CREATE TABLE RISK_DRIVER_X_EXPOSURE (
     RISK_DRIVER_X_EXPOSURE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RISK_DRIVER_RK       NUMERIC(10)     NOT NULL,
     ACCOUNT_RK           NUMERIC(10),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     PHYSICAL_ASSET_RK    NUMERIC(10),
     CREDIT_FACILITY_RK   NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_DRIVER_X_EXPOSURE_PI (RISK_DRIVER_X_EXPOSURE_RK)
;
CREATE TABLE RISK_FACTOR (
     RISK_FACTOR_ID       VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     UNDERLYING_RISK_FACTOR_ID VARCHAR(32),
     RISK_FACTOR_NM       VARCHAR(40),
     RISK_FACTOR_ROLE_CD  VARCHAR(3),
     RISK_FACTOR_CATEGORY_CD VARCHAR(3),
     MATURITY_LENGTH_OF_TIME NUMERIC(8),
     MATURITY_TIME_UOM_CD VARCHAR(3),
     RISK_FACTOR_MEASURE_TYPE_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     HEDGING_SET_RK       NUMERIC(10),
     CURRENCY_CD          VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_FACTOR_PI (RISK_FACTOR_ID)
;
CREATE TABLE RISK_FACTOR_ATTRIBUTE_VALUE (
     RISK_FACTOR_ID       VARCHAR(32)     NOT NULL,
     RISK_FACTOR_ATTRIBUTE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     RISK_FACTOR_MSRMNT_VALUE VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_FACTOR_ATTRIBUTE_VALUE_PI (RISK_FACTOR_ID,RISK_FACTOR_ATTRIBUTE_CD)
;
CREATE TABLE RISK_FACTOR_CURVE (
     CURVE_ID             VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     CURVE_NM             VARCHAR(40),
     CURVE_ROLE_CD        VARCHAR(3),
     INTERPOLATION_TECHNIQUE_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_FACTOR_CURVE_PI (CURVE_ID)
;
CREATE TABLE RISK_FACTOR_GROUP (
     GROUP_ID             VARCHAR(32)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     GROUP_NM             VARCHAR(40),
     GROUP_DESC           VARCHAR(100),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_FACTOR_GROUP_PI (GROUP_ID)
;
CREATE TABLE RISK_FACTOR_X_EXPOSURE (
     RISK_FACTOR_X_EXPOSURE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     SEGMENT_RK           NUMERIC(10),
     SWAP_INSTRUMENT_LEG_RK NUMERIC(10),
     ACCOUNT_RK           NUMERIC(10),
     EMBEDDED_OPTION_RK   NUMERIC(10),
     RISK_FACTOR_ID       VARCHAR(32),
     RISK_FACTOR_OBJECT_ROLE_CD VARCHAR(3),
     PHYSICAL_ASSET_RK    NUMERIC(10),
     CURVE_ID             VARCHAR(32),
     GROUP_ID             VARCHAR(32),
     RISK_FACTOR_OBJECT_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL,
     CREDIT_FACILITY_RK   NUMERIC(10))
     PRIMARY INDEX RISK_FACTOR_X_EXPOSURE_PI (FINANCIAL_INSTRUMENT_RK,EMBEDDED_OPTION_RK,RISK_FACTOR_ID,RISK_FACTOR_OBJECT_ROLE_CD)
;
CREATE TABLE RISK_FACTOR_X_RISK_FCTR_CURVE (
     CURVE_ID             VARCHAR(32)     NOT NULL,
     RISK_FACTOR_ID       VARCHAR(32)     NOT NULL,
     RLN_RISK_FACTOR_ATTRIBUTE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_FACTOR_X_RISK_FCTR_CUR_PI (CURVE_ID,RISK_FACTOR_ID,RLN_RISK_FACTOR_ATTRIBUTE_CD)
;
CREATE TABLE RISK_POSITION (
     RISK_POSITION_ID     VARCHAR(32)     NOT NULL,
     EVALUATION_DT        DATE     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     RISK_COMPONENT_AMT   NUMERIC(18,5),
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     HEDGING_SET_RK       NUMERIC(10),
     CURRENCY_CD          VARCHAR(3),
     RISK_POSITION_TYPE_CD VARCHAR(3),
     RISK_FACTOR_ID       VARCHAR(32)     NOT NULL,
     SECOND_RISK_FACTOR_ID VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RISK_POSITION_PI (RISK_FACTOR_ID)
;
CREATE TABLE RI_TRANS_X_CEDED_LOSS (
     RI_TRANS_ID          VARCHAR(32)     NOT NULL,
     RI_CONTRACT_RK       NUMERIC(10)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     CEDED_LOSS_RK        NUMERIC(10)     NOT NULL,
     CEDED_LOSS_TRANS_AMT NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RI_TRANS_X_CEDED_LOSS_PI (RI_TRANS_ID,RI_CONTRACT_RK,SOURCE_SYSTEM_CD,CEDED_LOSS_RK)
;
CREATE TABLE RI_TRANS_X_RI_EXPOSURE (
     RI_TRANS_ID          VARCHAR(32)     NOT NULL,
     RI_EXP_RK            NUMERIC(10)     NOT NULL,
     RI_CONTRACT_RK       NUMERIC(10)     NOT NULL,
     SOURCE_SYSTEM_CD     VARCHAR(3)     NOT NULL,
     RI_EXP_TRANS_AMT     NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RI_TRANS_X_RI_EXPOSURE_PI (RI_TRANS_ID,RI_EXP_RK,RI_CONTRACT_RK,SOURCE_SYSTEM_CD)
;
CREATE TABLE RSK_FCTR_X_ANAL_MDL_TRANS_METH (
     RISK_FACTOR_TRANS_METH_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     RISK_FACTOR_ID       VARCHAR(32)     NOT NULL,
     MODEL_TRANSFORMATION_RK NUMERIC(10),
     CURVE_ID             VARCHAR(32),
     INPUT_OUTPUT_INDICATOR_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX RSK_FCTR_X_ANAL_MDL_TRANS_M_PI (RISK_FACTOR_TRANS_METH_RK)
;
CREATE TABLE SAFE_VAULT_DETAILS (
     SAFE_RK              NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SAFE_NO              VARCHAR(32)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     SAFE_VAULT_CLASS_CD  VARCHAR(3),
     TIME_LOCK_IND        CHARACTER(1),
     RELOCKING_DEVICE_IND CHARACTER(1),
     VAULT_LENGTH         NUMERIC(14,4),
     VAULT_WIDTH          NUMERIC(14,4),
     VAULT_HEIGHT         NUMERIC(14,4),
     NUM_OPENINGS         NUMERIC(6),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SAFE_VAULT_DETAILS_PI (SAFE_RK)
;
CREATE TABLE SALVAGE_DETAILS (
     CLAIM_UNIT_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SALVAGE_DT           DATE,
     ITEM_APPRAISED_VALUE_AMT NUMERIC(18,5),
     ITEM_VALUE_PRIOR_TO_LOSS_AMT NUMERIC(18,5),
     ITEM_VALUE_RECEIVED_AMT NUMERIC(18,5),
     OWNER_RETAINING_SALVAGE_IND CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SALVAGE_DETAILS_PI (CLAIM_UNIT_RK)
;
CREATE TABLE SCHEDULE (
     SCHEDULE_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SCHEDULE_CD          VARCHAR(3),
     SCHEDULE_NM          VARCHAR(50),
     SCHEDULE_DESC        VARCHAR(100),
     SCHEDULE_TYPE_CD     VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SCHEDULE_PI (SCHEDULE_RK)
;
CREATE TABLE SCHEDULE_GROUP_RATE (
     SCHEDULE_RK          NUMERIC(10)     NOT NULL,
     GROUP_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SCHEDULE_GROUP_RT    NUMERIC(9,4),
     RATE_EFFECTIVE_FROM_DT DATE,
     RATE_EFFECTIVE_TO_DT DATE,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SCHEDULE_GROUP_RATE_PI (GROUP_RK,SCHEDULE_RK)
;
CREATE TABLE SCHEDULE_PARAM_GROUP (
     GROUP_RK             NUMERIC(10)     NOT NULL,
     PARAM_VALUE_RK       NUMERIC(10)     NOT NULL,
     GROUP_ID             VARCHAR(32)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SCHEDULE_PARAM_GROUP_PI (GROUP_RK)
;
CREATE TABLE SCHEDULE_X_INSURANCE_PRODUCT (
     INSURANCE_PRODUCT_RK NUMERIC(10)     NOT NULL,
     SCHEDULE_RK          NUMERIC(10)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SCHEDULE_X_INSURANCE_PRODUC_PI (INSURANCE_PRODUCT_RK,SCHEDULE_RK)
;
CREATE TABLE SCHEDULE_X_SEGMENT (
     SEGMENT_RK           NUMERIC(10)     NOT NULL,
     SCHEDULE_RK          NUMERIC(10)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SCHEDULE_X_SEGMENT_PI (SEGMENT_RK,SCHEDULE_RK)
;
CREATE TABLE SECTION (
     SECTION_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SECTION_CD           VARCHAR(3)     NOT NULL,
     SECTION_DESC         VARCHAR(100)     NOT NULL,
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX POLICY_SECTION_TYPE_CD (SECTION_CD)
;
CREATE TABLE SECURITIZATION_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     SECURITIZATION_POOL_RK NUMERIC(10),
     SECURITIZ_INSTRUMENT_TYPE_CD VARCHAR(3),
     TRANCHE_SECURITY_RANK_NO NUMERIC(10),
     TRANCHE_FACE_VALUE_AMT NUMERIC(18,5),
     TRANCHE_CREDIT_ENHNCE_LEVEL_RT NUMERIC(9,4),
     TRANCHE_THICKNESS_RT NUMERIC(9,4),
     TRANCHE_CURRENT_FACTOR_RT NUMERIC(9,4),
     LOSS_RANK_NO         NUMERIC(10),
     OVER_COLLAT_TEST_TRIGGER_VALUE NUMERIC(18,5),
     CAPITAL_PROTECTION_AMT NUMERIC(18,5),
     TRANCHE_ATTACH_POINT_VALUE NUMERIC(18,5),
     TRANCHE_DETACH_POINT_VALUE NUMERIC(18,5),
     TRANCHE_POINT_VALUE_TYPE_CD VARCHAR(3),
     OVER_COL_TST_TRIG_VAL_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SECURITIZATION_INSTRUMENT_PI (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE SECURITIZATION_INSTR_QUOTE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SECURITIZATION_INSTR_QUOTE_PI (FINANCIAL_INSTRUMENT_RK,QUOTE_DTTM)
;
CREATE TABLE SECURITIZATION_POOL (
     SECURITIZATION_POOL_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SECURITIZATION_POOL_ID VARCHAR(32),
     SECURITIZ_STRUC_TYPE_CD VARCHAR(3),
     SECURITIZ_STRUC_SUBTYPE_CD VARCHAR(3),
     SECURITIZ_PRIM_BANK_ROLE_CD VARCHAR(3),
     SECURITIZ_PRIM_TYPE_CD VARCHAR(3),
     CLEAN_UP_CALL_TYPE_CD VARCHAR(3),
     CLEAN_UP_CALL_HOLDER_FLG CHARACTER(1),
     CLEAN_UP_CALL_LEVEL_AMT NUMERIC(18,5),
     GAIN_ON_SALE_AMT     NUMERIC(18,5),
     EARLY_AMORTIZATION_TYPE_CD VARCHAR(3),
     LONGEST_MATURITY_DT  DATE,
     IMPLICIT_SUPPORT_FLG CHARACTER(1),
     AVG_3_MONTH_EXCESS_SPREAD_AMT NUMERIC(18,5),
     EXCESS_SPREAD_TRAP_POINT_AMT NUMERIC(18,5),
     POOL_FACE_VALUE_AMT  NUMERIC(18,5),
     EFFECTIVE_NO_OF_EXPOSURES NUMERIC(10),
     TOTAL_TRANCHE_NO     NUMERIC(10),
     UNCOMM_RETAIL_REVOLV_FACE_AMT NUMERIC(18,5),
     COMM_RETAIL_REVOLV_FACE_AMT NUMERIC(18,5),
     UNCOMM_OTHER_REVOLV_FACE_AMT NUMERIC(18,5),
     COMM_OTHER_REVOLV_FACE_AMT NUMERIC(18,5),
     WEIGHT_AVG_MATURITY_MONTHS_NO NUMERIC(9,4),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     K_IRB_RT             NUMERIC(9,4),
     WEIGHTED_AVG_LGD_PCT NUMERIC(9,4),
     WEIGHTED_AVG_COUPON_RT NUMERIC(9,4),
     MAX_RISK_WEIGHT_PCT  NUMERIC(9,4),
     MIN_RISK_WEIGHT_PCT  NUMERIC(9,4),
     AVG_RISK_WEIGHT_PCT  NUMERIC(9,4),
     CRDT_ENHNC_INT_ONLY_STRIP_AMT NUMERIC(18,5),
     INVESTORS_INTEREST_PCT NUMERIC(9,4),
     UNDERLYING_EXPOSURE_CNT NUMERIC(6),
     UNDERLYING_PRODUCT_TYPE_CD VARCHAR(3),
     RESECURITIZATION_FLG CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SECURITIZATION_POOL_PI (SECURITIZATION_POOL_RK)
;
CREATE TABLE SECURITY_DETAILS (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     BULLET_RESIST_ENCLSR_TYPE_CD VARCHAR(3),
     DT_TIME_ON_SURVEILLANCE_IND CHARACTER(1),
     LINE_SECURITY_IND    CHARACTER(1),
     MAINTENANCE_CONTRACT_IND CHARACTER(1),
     MONITORED_SURVEILLANCE_IND CHARACTER(1),
     NUM_GUARDS           NUMERIC(6),
     NUM_WATCH_PERSONS    NUMERIC(6),
     PROTECTION_CLASS_GRD_CD VARCHAR(3),
     PROTECTION_EXTENT_CD VARCHAR(3),
     RECORDED_SURVEILLANCE_IND CHARACTER(1),
     RECORDING_ARCHIVED_IND CHARACTER(1),
     REMOTE_SURVEILLANCE_IND CHARACTER(1),
     REMOTE_SURVEILLANCE_TYPE_CD VARCHAR(3),
     NUM_HOLD_UP_BUTTONS  NUMERIC(6),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SECURITY_DETAILS_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE SEGMENT (
     SEGMENT_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     PARENT_SEGMENT_RK    NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     SEGMENT_ID           VARCHAR(32),
     SEGMENT_DESC         VARCHAR(250),
     SEGMENT_TYPE_CD      VARCHAR(3),
     SEGMENT_STATUS_CD    VARCHAR(3),
     SEGMENT_CRITERIA_TXT VARCHAR(250),
     SEGMENT_CREATE_DT    DATE,
     SCHEME_ID            VARCHAR(32),
     SEGMENT_LONG_NM      VARCHAR(100),
     SEGMENT_SHORT_NM     VARCHAR(20),
     SEGMENT_SHARED_FLG   CHARACTER(1),
     SCHEME_NM            VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SEGMENT_PI (SEGMENT_RK)
;
CREATE TABLE SEGMENT_ATTRIBUTE_VALUE (
     SEGMENT_RK           NUMERIC(10)     NOT NULL,
     SEGMENT_ATTRIBUTE_NM VARCHAR(32)     NOT NULL,
     SEGMENT_ATTRIBUTE_VALUE_TXT VARCHAR(32),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SEGMENT_ATTRIBUTE_VALUE_PI (SEGMENT_RK,SEGMENT_ATTRIBUTE_NM)
;
CREATE TABLE SEGMENT_CREDIT_ASSESSMENT (
     SEGMENT_RK           NUMERIC(10)     NOT NULL,
     ASSESSMENT_DT        DATE     NOT NULL,
     ASSESSMENT_MODEL_RK  NUMERIC(10)     NOT NULL,
     ASSESSMENT_RESULT_TYPE_CD VARCHAR(3)     NOT NULL,
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10),
     ASSESSMENT_RESULT_RT NUMERIC(9,4),
     PRINCIPAL_ONLY_FLG   CHARACTER(1),
     ASSESS_CHANGE_REASON_CD VARCHAR(3),
     EFFECTIVE_FROM_DTTM  TIMESTAMP,
     EFFECTIVE_TO_DTTM    TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SEGMENT_CREDIT_ASSESSMENT_PI (ASSESSMENT_MODEL_RK)
;
CREATE TABLE SERVICED_TERMINAL_DETAILS (
     TERMINAL_RK          NUMERIC(10)     NOT NULL,
     TERMINAL_SERVICED_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     DISTANCE_FROM_GARAGE NUMERIC(9,4),
     NUM_VEHS             NUMERIC(6),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SERVICED_TERMINAL_DETAILS_PI (TERMINAL_RK,TERMINAL_SERVICED_RK)
;
CREATE TABLE SPECIALTY_ROOM_DETAILS (
     SPECIALITY_ROOM_RK   NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SPECIALTY_ROOM_CD    VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     SURFACE_AREA         NUMERIC(14,4),
     SPECIALTY_ROOM_PCT   NUMERIC(9,4),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SPECIALTY_ROOM_DETAILS_PI (SPECIALITY_ROOM_RK)
;
CREATE TABLE STATE_REGION (
     STATE_REGION_CD      VARCHAR(4)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     STATE_REGION_NM      VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX STATE_REGION_PI (STATE_REGION_CD)
;
CREATE TABLE SUBSTANCE_USAGE_DETAILS (
     SUBSTANCE_TYPE_RK    NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBSTANCE_TYPE_CD    VARCHAR(3)     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     PHYSICIAN_RK         NUMERIC(10),
     TOBACCO_TYPE_CD      VARCHAR(3),
     SUBSTANCE_DESC       VARCHAR(255),
     SUBSTANCE_START_DT   DATE,
     SUBSTANCE_END_DT     DATE,
     SUBSTANCE_MODE_CD    VARCHAR(3),
     SUBSTANCE_AMT        NUMERIC(18,5),
     TREATMENT_IND        CHARACTER(1),
     LAST_TREATMENT_DT    DATE,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SUBSTANCE_USAGE_DETAILS_PI (SUBSTANCE_TYPE_RK)
;
CREATE TABLE SUBSTRUCTURE_TYPE_DETAILS (
     SUBSTRUCTURE_TYPE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBSTRUCTURE_TYPE_CD VARCHAR(3)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     FOUNDATION_CD        VARCHAR(3),
     GROUND_FLOOR_PCT     NUMERIC(9,4),
     SURFACE_AREA         NUMERIC(14,4),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SUBSTRUCTURE_TYPE_DETAILS_PI (SUBSTRUCTURE_TYPE_RK)
;
CREATE TABLE SUB_ACCOUNT (
     SUB_ACCOUNT_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUB_ACCOUNT_ID       VARCHAR(32)     NOT NULL,
     SUB_ACCOUNT_STATUS_CD VARCHAR(3),
     ASSET_CLASS_CD       VARCHAR(3),
     USAGE_CD             VARCHAR(3),
     PORTFOLIO_CD         VARCHAR(3),
     CARRIER_CD           VARCHAR(3),
     PRODUCT_OBJECTIVE_CD VARCHAR(3),
     INVESTMENT_TYPE_CD   VARCHAR(3),
     DIVIDEND_OPTION_CD   VARCHAR(3),
     OPEN_DT              DATE,
     MATURITY_DT          DATE,
     MATURITY_VALUE       NUMERIC(18,5),
     PAYOUT_UNIT_VALUE    NUMERIC(18,5),
     ALLOC_PCT            NUMERIC(9,4),
     CURR_INT_RT          NUMERIC(9,4),
     ALLOC_AMT            NUMERIC(18,5),
     ACTUAL_END_DT        DATE,
     PAYMENT_METHOD_CD    VARCHAR(3),
     DEBT_TYPE_CD         VARCHAR(3),
     GUAR_INT_RT          NUMERIC(9,4),
     GUAR_INT_END_DT      DATE,
     MATURITY_PAYMENT_TYPE_CD VARCHAR(3),
     COMMISSION_PCT       NUMERIC(9,4),
     INT_TYPE_CD          VARCHAR(3),
     OPT_PUT_CALL_TYPE_CD VARCHAR(3),
     WITHDRAWALS_ALLOWED_IND CHARACTER(1),
     INVESTMENT_FUND_RK   NUMERIC(10),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXSUB_ACCOUNT (SUB_ACCOUNT_RK)
;
CREATE TABLE SUB_ACCOUNT_AMOUNTS (
     SUB_ACCOUNT_RK       NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     UNIT_VALUE           NUMERIC(18,5),
     UNIT_VALUE_BUY_RT    NUMERIC(9,4),
     CURR_NUM_UNITS       NUMERIC(18,5),
     CURR_RT              NUMERIC(9,4),
     PRICING_AS_OF_DT     DATE,
     TOTAL_COST           NUMERIC(18,5),
     TOTAL_VALUE          NUMERIC(18,5),
     NET_SURR_VALUE_AMT   NUMERIC(18,5),
     RISK_PREMIUM_PCT     NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SUB_ACCOUNT_AMOUNTS_PI (SUB_ACCOUNT_RK)
;
CREATE TABLE SUB_LEDGER (
     SUB_LEDGER_RK        NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUB_LEDGER_ID        VARCHAR(32)     NOT NULL,
     SUB_LEDGER_TYPE_CD   VARCHAR(3),
     GL_ACCOUNT_RK        NUMERIC(10)     NOT NULL,
     EXTERNAL_ORG_RK      NUMERIC(10),
     INDIVIDUAL_RK        NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SUB_LEDGER_PI (SUB_LEDGER_RK)
;
CREATE TABLE SUB_LEDGER_BALANCE (
     SUB_LEDGER_RK        NUMERIC(10)     NOT NULL,
     REPT_CURRENCY_CD     VARCHAR(3)     NOT NULL,
     ACCOUNT_PERIOD_RK    NUMERIC(10)     NOT NULL,
     AS_OF_DT             DATE     NOT NULL,
     CURRENT_BALANCE_AMT  NUMERIC(18,5),
     ORIGINAL_BALANCE_AMT NUMERIC(18,5),
     BASE_CURRENCY_CD     VARCHAR(3),
     BALANCE_DUE_DT       DATE,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SUB_LEDGER_BALANCE_PI (SUB_LEDGER_RK,REPT_CURRENCY_CD,ACCOUNT_PERIOD_RK,AS_OF_DT)
;
CREATE TABLE SUPER_ANNUATION_DETAILS (
     POLICY_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     EMP_STD_DISC_CONT_AMT NUMERIC(18,5),
     EMP_STD_DISC_CONT_FREQ_CD VARCHAR(3),
     EMP_STD_DISC_SAL_PCT NUMERIC(9,4),
     EMP_ADDL_DISC_CONT_AMT NUMERIC(18,5),
     EMP_ADDL_DISC_CONT_FREQ_CD VARCHAR(3),
     EMP_ADDL_DISC_SAL_PCT NUMERIC(9,4),
     GUAR_CONT_AMT        NUMERIC(18,5),
     GUAR_FREQ_CD         VARCHAR(3),
     GUAR_SAL_PCT         NUMERIC(9,4),
     MEMBER_CONT_AMT      NUMERIC(18,5),
     MEMBER_CONT_FREQ_CD  VARCHAR(3),
     MEMBER_SAL_PCT       NUMERIC(9,4),
     EARLIEST_START_DT    DATE,
     MEMBER_COVER_SALARY_AMT NUMERIC(18,5),
     CATEGORY_DESC        VARCHAR(255),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SUPER_ANNUATION_DETAILS_PI (POLICY_RK)
;
CREATE TABLE SURVEY (
     SURVEY_REFERENCE_NO  VARCHAR(32)     NOT NULL,
     SURVEY_DESC          VARCHAR(100),
     SURVEY_SOURCE_CD     VARCHAR(3),
     SURVEY_DTTM          TIMESTAMP,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SURVEY_PI (SURVEY_REFERENCE_NO)
;
CREATE TABLE SURVEY_ANSWER (
     QUESTION_NO          VARCHAR(32)     NOT NULL,
     SURVEY_REFERENCE_NO  VARCHAR(32)     NOT NULL,
     CUSTOMER_RK          NUMERIC(10)     NOT NULL,
     ANSWER_TXT           VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SURVEY_ANSWER_PI (QUESTION_NO,SURVEY_REFERENCE_NO,CUSTOMER_RK)
;
CREATE TABLE SURVEY_QUESTION (
     QUESTION_NO          VARCHAR(32)     NOT NULL,
     SURVEY_REFERENCE_NO  VARCHAR(32)     NOT NULL,
     QUESTION_TXT         VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SURVEY_QUESTION_PI (QUESTION_NO,SURVEY_REFERENCE_NO)
;
CREATE TABLE SWAP_INSTRUMENT (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     START_DT             DATE,
     SWAP_INSTRUMENT_TYPE_CD VARCHAR(5),
     PRINCIPAL_EXCHANGE_FLG CHARACTER(1),
     PRIN_EXCHANGE_PER_ANNUM_NO NUMERIC(10),
     FX_RT                NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX FINANCIAL_INSTRUMENT_RK (FINANCIAL_INSTRUMENT_RK)
;
CREATE TABLE SWAP_INSTRUMENT_LEG (
     SWAP_INSTRUMENT_LEG_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PAYMENT_LEG_CD       VARCHAR(3)     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     SWAP_LEG_FINANCIAL_INSTR_RK NUMERIC(10),
     LEG_START_DT         DATE,
     LEG_END_DT           DATE,
     FIXED_RT             NUMERIC(9,4),
     YIELD_RT             NUMERIC(9,4),
     SPREAD_RT            NUMERIC(9,4),
     FIRST_PAYMENT_DT     DATE,
     FACE_VALUE_AMT       NUMERIC(18,5),
     PAYMENTS_PER_ANNUM_RT NUMERIC(9,4),
     PRINCIPAL_PAYMENT_AMT NUMERIC(18,5),
     PRINCIPAL_PAYMENT_TYPE_CD VARCHAR(3),
     REDEMPTION_PRICE_AMT NUMERIC(18,5),
     CURRENCY_CD          VARCHAR(3),
     LEG_UNITS_NO         NUMERIC(12,2),
     DAY_BASIS_CD         VARCHAR(10),
     CARRYING_COST_RT     NUMERIC(9,4),
     COMPOUNDING_CD       VARCHAR(10),
     SWAP_INSTRUMENT_LEG_ID VARCHAR(32),
     PAYMENT_TIME_FREQUENCY_CD VARCHAR(3),
     UNDERLYING_INSTRUMENT_UNITS_NO NUMERIC(12,2),
     SWAP_LEG_TYPE_CD     VARCHAR(3),
     PAYMENT_DAY_OF_MONTH_NO NUMERIC(3),
     INT_PAYMENT_DAY_OF_MONTH_NO NUMERIC(3),
     RESET_DAY_OF_MONTH_NO NUMERIC(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SWAP_INSTRUMENT_LEG_PI (SWAP_INSTRUMENT_LEG_RK)
;
CREATE TABLE SWAP_INSTRUMENT_QUOTE (
     FINANCIAL_INSTRUMENT_RK NUMERIC(10)     NOT NULL,
     MARKET_CD            VARCHAR(5)     NOT NULL,
     QUOTE_DTTM           TIMESTAMP     NOT NULL,
     BID_PRICE_AMT        NUMERIC(18,5),
     ASK_PRICE_AMT        NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SWAP_INSTRUMENT_QUOTE_PI (FINANCIAL_INSTRUMENT_RK,MARKET_CD,QUOTE_DTTM)
;
CREATE TABLE SWIMMING_POOL_DETAILS (
     SWIMMING_POOL_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SWIMMING_POOL_NO     VARCHAR(32)     NOT NULL,
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     ABV_GROUND_IND       CHARACTER(1),
     APPROVED_FENCE_IND   CHARACTER(1),
     DIVING_BOARD_IND     CHARACTER(1),
     FENCE_CONSTR_CD      VARCHAR(3),
     FENCE_HEIGHT         NUMERIC(14,4),
     LIFE_GUARD_IND       CHARACTER(1),
     LIMITED_ACCESS_IND   CHARACTER(1),
     SLIDE_IND            CHARACTER(1),
     SWIM_INSTRUCTION_IND CHARACTER(1),
     POOL_DEPTH           NUMERIC(14,4),
     INDOOR_CD            VARCHAR(3),
     POOL_CONSTR_CD       VARCHAR(3),
     POOL_AREA            NUMERIC(14,4),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX SWIMMING_POOL_DETAILS_PI (SWIMMING_POOL_RK)
;
CREATE TABLE TARIFF_DETAILS (
     UOE_RK               NUMERIC(10)     NOT NULL,
     TARIFF_FACTOR_CD     VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     TARIFF_AMT           NUMERIC(18,5),
     TARIFF_FACTOR        NUMERIC(9,4),
     TARIFF_FACTOR_DESC   VARCHAR(255),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TARIFF_DETAILS_PI (UOE_RK,TARIFF_FACTOR_CD)
;
CREATE TABLE TECHNICAL_INSURANCE_AGREEMENT (
     TECHNICAL_AGR_RK     NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     TECHNICAL_AGR_ID     VARCHAR(32)     NOT NULL,
     STATUS_CD            VARCHAR(3),
     BEGIN_DT             DATE,
     END_DT               DATE,
     MOD_DT               DATE,
     GROSS_ANNUAL_PREMIUM_AMT NUMERIC(18,5),
     COMMISSION_INITIAL_AMT NUMERIC(18,5),
     COMMISSION_RENEWAL_AMT NUMERIC(18,5),
     PLAN_NOTATION_TXT    VARCHAR(20),
     SOLVENCY2_GROUP_CD   VARCHAR(3),
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TECHNICAL_INSURANCE_AGREEME_PI (TECHNICAL_AGR_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE TECHNICAL_INSURED_SUBJECT (
     SUBJECT_OF_INSURANCE_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     SUBJECT_ID           VARCHAR(32)     NOT NULL,
     SUBJECT_INSURANCE_CD VARCHAR(3),
     ITEM_DESC            VARCHAR(255),
     ITEM_VALUE_AMT       NUMERIC(18,5),
     VALUATION_CD         VARCHAR(3),
     AGREED_VALUE_IND     CHARACTER(1),
     TECHNICAL_AGR_RK     NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     CHANGE_EFFECTIVE_FROM_DTTM TIMESTAMP,
     CHANGE_EFFECTIVE_TO_DTTM TIMESTAMP,
     APPLICATION_RK       NUMERIC(10),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TECHNICAL_INSURED_SUBJECT_PI (SUBJECT_OF_INSURANCE_RK,POLICY_RK,LOB_RK)
;
CREATE TABLE TERM (
     TERM_CD              VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     TERM_DESC            VARCHAR(100),
     TIME_UOM_CD          VARCHAR(3),
     TERM_TIME_UOM_VALUE_NO NUMERIC(5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TERM_PI (TERM_CD)
;
CREATE TABLE TIME_FREQUENCY (
     TIME_FREQUENCY_CD    VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     TIME_UOM_NO          NUMERIC(6,2),
     TIME_UOM_CD          VARCHAR(3),
     TIME_FREQUENCY_DESC  VARCHAR(100),
     HOURS_PER_PERIOD_QTY NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TIME_FREQUENCY_PI (TIME_FREQUENCY_CD)
;
CREATE TABLE TRANSITION_MATRIX (
     TRANSITION_MATRIX_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     TRANSITION_MATRIX_ID VARCHAR(32),
     TRANSITION_MATRIX_GROUP_RK NUMERIC(10),
     TRANSITION_TIME_UOM_CD VARCHAR(3),
     TRANSITION_TIME_CNT  NUMERIC(6),
     TRANSITION_MATRIX_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TRANSITION_MATRIX_PI (TRANSITION_MATRIX_RK)
;
CREATE TABLE TRANSITION_MATRIX_ELEMENT (
     TRANSITION_MATRIX_RK NUMERIC(10)     NOT NULL,
     TRANSITION_FROM_STATE_CD VARCHAR(3)     NOT NULL,
     TRANSITION_TO_STATE_CD VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     RISK_FACTOR_ID       VARCHAR(32),
     TRANSITION_RT        NUMERIC(9,4),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TRANSITION_MATRIX_ELEMENT_PI (TRANSITION_MATRIX_RK,TRANSITION_FROM_STATE_CD,TRANSITION_TO_STATE_CD)
;
CREATE TABLE TRANSITION_MATRIX_GROUP (
     TRANSITION_MATRIX_GROUP_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     TRANSITION_MATRIX_GROUP_ID VARCHAR(32),
     TRANSITION_MATRIX_GROUP_DESC VARCHAR(100),
     TRANSITION_MATRIX_ID VARCHAR(32),
     TRANSITION_SOURCE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TRANSITION_MATRIX_GROUP_PI (TRANSITION_MATRIX_GROUP_RK)
;
CREATE TABLE TRANSITION_SOURCE (
     TRANSITION_SOURCE_CD VARCHAR(3)     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     TRANSITION_SOURCE_DESC VARCHAR(100),
     TRANSITION_SOURCE_TYPE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TRANSITION_SOURCE_PI (TRANSITION_SOURCE_CD)
;
CREATE TABLE TRANSITION_SOURCE_TYPE (
     TRANSITION_SOURCE_TYPE_CD VARCHAR(3)     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     TRANSITION_SOURCE_TYPE_DESC VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TRANSITION_SOURCE_TYPE_PI (TRANSITION_SOURCE_TYPE_CD)
;
CREATE TABLE TRANSITION_STATE (
     TRANSITION_STATE_CD  VARCHAR(3)     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     TRANSITION_STATE_DESC VARCHAR(100),
     ASSESSMENT_RATING_GRADE_RK NUMERIC(10),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TRANSITION_STATE_PI (TRANSITION_STATE_CD)
;
CREATE TABLE TRANS_MATRIX_X_ANALYTICAL_MDL (
     TRANSITION_MATRIX_RK NUMERIC(10)     NOT NULL,
     MODEL_RK             NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     ANALYTICAL_MODEL_ROLE_CD VARCHAR(3),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX TRANS_MATRIX_X_ANALYTICAL_M_PI (TRANSITION_MATRIX_RK,MODEL_RK)
;
CREATE TABLE TRUCKERS_TERMINAL (
     TERMINAL_RK          NUMERIC(10)     NOT NULL,
     COMML_MOTOR_AGR_RK   NUMERIC(10)     NOT NULL,
     POLICY_RK            NUMERIC(10)     NOT NULL,
     LOB_RK               NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     NUM_TERMINALS_SERVICED NUMERIC(6),
     DISTANCE_FARTHEST_TERMINAL NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXTRUCKERS_ZONE_DETAILS (TERMINAL_RK)
;
CREATE TABLE UNDERLYING_MONITORING (
     UNDERLYING_MONITORING_RK NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     FINANCIAL_INSTRUMENT_RK NUMERIC(10),
     PERIOD_NO            NUMERIC(6),
     UNDERLYING_PRICE_MAX_VALUE NUMERIC(18,5),
     UNDERLYING_PRICE_MIN_VALUE NUMERIC(18,5),
     EMBEDDED_OPTION_RK   NUMERIC(10),
     VALUE_TYPE_CD        VARCHAR(3),
     UNDERLYING_AVERAGE_PRICE_AMT NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX UNDERLYING_MONITORING_PI (UNDERLYING_MONITORING_RK)
;
CREATE TABLE UNDERWATER_DIVING_DETAILS (
     LIFE_STYLE_ACTIVITY_RK NUMERIC(10)     NOT NULL,
     MAX_DEPTH            NUMERIC(9,4),
     AVG_DEPTH            NUMERIC(9,4),
     MAX_MINUTE           NUMERIC(6,2),
     AVG_MINUTE           NUMERIC(6,2),
     LAST_DIVE_DT         DATE,
     DIVING_TYPE_CD       VARCHAR(3),
     CERTIFICATION_LEVEL_CD VARCHAR(3),
     CERTIFIED_ORG        VARCHAR(50),
     DIVE_ALONE_IND       CHARACTER(1),
     EXPERIMENTAL_EQUIP_IND CHARACTER(1),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX UNDERWATER_DIVING_DETAILS_PI (LIFE_STYLE_ACTIVITY_RK)
;
CREATE TABLE UNIT_OF_MEASURE (
     UOM_CD               VARCHAR(3)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     LANGUAGE_CD          VARCHAR(3)     NOT NULL,
     UOM_TYPE_DESC        VARCHAR(100),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     UOM_DESC             VARCHAR(100),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX UNIT_OF_MEASURE_PI (UOM_CD)
;
CREATE TABLE UP_SELL_TARGET_COVERAGE (
     MODEL_RK             NUMERIC(10)     NOT NULL,
     SCORE_DT             DATE     NOT NULL,
     PRODUCT_COVERAGE_RK  NUMERIC(10)     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX UP_SELL_TARGET_COVERAGE_PI (PRODUCT_COVERAGE_RK)
;
CREATE TABLE UW_CLASS_DETAILS (
     UW_CLASS_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     UW_CLASS_CD          VARCHAR(3)     NOT NULL,
     COVERAGE_RK          NUMERIC(10)     NOT NULL,
     CLASS_NM             VARCHAR(40),
     UNDERWRITING_SUB_CLASS_CD VARCHAR(3),
     SMOKER_STAT_CD       VARCHAR(3),
     TOBACCO_PREMIUM_BASIS_CD VARCHAR(3),
     ISSUE_GENDER_CD      VARCHAR(3),
     MIN_ISSUE_AGE        NUMERIC(3),
     MAX_ISSUE_AGE        NUMERIC(3),
     MIN_ISSUE_AMT        NUMERIC(18,5),
     MAX_ISSUE_AMT        NUMERIC(18,5),
     AGE_ADJUSTMENT       NUMERIC(3),
     MAX_ISSUE_UNITS      NUMERIC(9),
     MIN_ISSUE_UNITS      NUMERIC(9),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX UW_CLASS_DETAILS_PI (UW_CLASS_RK)
;
CREATE TABLE VEHICLE (
     VEHICLE_RK           NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VEH_IDENTIFICATION_NO VARCHAR(32)     NOT NULL,
     MANUFACTURER_NM      VARCHAR(50),
     MODEL_NM             VARCHAR(50),
     MODEL_YR             NUMERIC(4),
     MANUFACTURE_DT       DATE,
     VEH_BODY_TYPE_CD     VARCHAR(3),
     VEH_TYPE_CD          VARCHAR(3),
     VEH_LENGTH           NUMERIC(14,4),
     VEH_WIDTH            NUMERIC(14,4),
     COST_NEW_AMT         NUMERIC(18,5),
     PURCHASE_DT          DATE,
     PURCHASE_AMT         NUMERIC(18,5),
     NUM_DAYS_DRIVEN_PER_WEEK NUMERIC(6),
     ESTIMATED_ANNUAL_DISTANCE NUMERIC(9,4),
     FULL_TERM_AMT        NUMERIC(18,5),
     NET_CHANGE_AMT       NUMERIC(18,5),
     DISPLACEMENT         NUMERIC(14,4),
     LEASED_VEH_IND       CHARACTER(1),
     LEASED_DT            DATE,
     LICENSE_PLATE_EFFECTIVE_DT DATE,
     LICENSE_PLATE_EXPIRATION_DT DATE,
     LICENSE_PLATE_NO     VARCHAR(32),
     REGISTERED_VEH_IND   CHARACTER(1),
     REGISTRATION_STATE_REGION_CD VARCHAR(3),
     CHASSIS_SERIAL_NO    VARCHAR(50),
     ENGINE_SERIAL_NO     VARCHAR(50),
     TRANSMISSION_SERIAL_NO VARCHAR(50),
     COLOR_CD             VARCHAR(3),
     VEH_SYMBOL_CD        VARCHAR(3),
     GROSS_VEH_OR_COMBINED_WEIGHT NUMERIC(14,4),
     RATE_SUB_CLASS_CD    VARCHAR(3),
     ANTI_LOCK_BRAKE_CD   VARCHAR(3),
     ENGINE_TYPE_CD       VARCHAR(3),
     NUM_CYLINDERS        NUMERIC(6),
     PRIMARY_FUEL_TYPE_CD VARCHAR(3),
     TRANSMISSION_TYPE_CD VARCHAR(3),
     NUM_AXLES            NUMERIC(6),
     TRACTION_CONTROL_IND CHARACTER(1),
     FOUR_WHEEL_DRIVE_IND CHARACTER(1),
     NUM_DOORS            NUMERIC(6),
     SEAT_BELT_TYPE_CD    VARCHAR(3),
     AIR_BAG_TYPE_CD      VARCHAR(3),
     VEH_IMPORTED_IND     CHARACTER(1),
     NIGHT_SECURE_PARKING_IND CHARACTER(1),
     UNDER_WARRANTY_IND   CHARACTER(1),
     LOCATION_RK          NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XXVEHICLE (VEHICLE_RK)
;
CREATE TABLE VEHICLE_ACCESSORIES (
     VEHICLE_RK           NUMERIC(10)     NOT NULL,
     ITEM_NO              VARCHAR(50)     NOT NULL,
     ITEM_NM              VARCHAR(40),
     ITEM_TYPE_CD         VARCHAR(3),
     PURCHASE_AMT         NUMERIC(18,5),
     CURR_VALUE_AMT       NUMERIC(18,5),
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX VEHICLE_ACCESSORIES_PI (VEHICLE_RK,ITEM_NO)
;
CREATE TABLE VIOLATION_DETAILS (
     VIOLATION_RK         NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     VIOLATION_TYPE_CD    VARCHAR(3)     NOT NULL,
     INSURED_RK           NUMERIC(10)     NOT NULL,
     VIOLATION_DESC       VARCHAR(255),
     VIOLATION_DT         DATE,
     VIOLATION_JURISDICTION_CD VARCHAR(3),
     DRIVER_IMPROVE_SCHOOL_IND CHARACTER(1),
     VIOLATION_COUNTRY_CD VARCHAR(3),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX VIOLATION_DETAILS_PI (VIOLATION_RK)
;
CREATE TABLE XL_LAYER (
     XL_LAYER_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     XL_LAYER_ID          VARCHAR(32)     NOT NULL,
     CAP_RANGE_1_AMT_TYPE_CD VARCHAR(3),
     CAP_RANGE_2_AMT_TYPE_CD VARCHAR(3),
     DEDUCTIBLE_1_AMT     NUMERIC(18,5),
     DEDUCTIBLE_2_AMT     NUMERIC(18,5),
     DEDUCTIBLE_AMT_RULE_CD VARCHAR(3),
     LIMIT_1_AMT          NUMERIC(18,5),
     LIMIT_2_AMT          NUMERIC(18,5),
     LIMIT_AMT_RULE_CD    VARCHAR(3),
     XL_LAYER_MIN_PREM_AMT NUMERIC(18,5),
     XL_LAYER_DEP_PREM_AMT NUMERIC(18,5),
     ALLOWED_REINSTATEMENTS_NO NUMERIC(6),
     REINSTATEMENT_LIMIT  NUMERIC(18,5),
     XL_LAYER_AGGR_LIMIT_AMT NUMERIC(18,5),
     RI_CONTRACT_SECTION_RK NUMERIC(10)     NOT NULL,
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XL_LAYER_PI (XL_LAYER_RK)
;
CREATE TABLE XL_LAYER_X_RI_CARRIER (
     RI_CARRIER_RK        NUMERIC(10)     NOT NULL,
     XL_LAYER_RK          NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     COMMUTATION_DT       DATE,
     SHARE_PCT            NUMERIC(9,4),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX XL_LAYER_X_RI_CARRIER_PI (RI_CARRIER_RK,XL_LAYER_RK)
;
CREATE TABLE YOUNG_DRIVER_DETAILS (
     DRIVER_RK            NUMERIC(10)     NOT NULL,
     VALID_FROM_DTTM      TIMESTAMP     NOT NULL,
     ALLOW_OTHERS_IND     CHARACTER(1),
     ARRESTED_OR_DETAINED_IND CHARACTER(1),
     ATTEND_SCHOOL_IND    CHARACTER(1),
     AVG_COLLEGE_GRADE    VARCHAR(4),
     SIGNED_DT            DATE,
     DAYS_PER_WEEK_DRIVEN_TO_SCHOOL NUMERIC(9),
     DAYS_PER_WEEK_DRIVEN_TO_WORK NUMERIC(9),
     COVERAGE_REFUSED_IND CHARACTER(1),
     EXPELLED_ETC_IND     CHARACTER(1),
     HIGHEST_GRADE_COMPLETED VARCHAR(4),
     IN_ACCIDENT_IND      CHARACTER(1),
     LICENSE_SUSPENDED_REVOKED_IND CHARACTER(1),
     AVG_HIGH_SCHOOL_GRADE VARCHAR(4),
     DISTANCE_ONE_WAY_TO_SCHOOL NUMERIC(14,4),
     DISTANCE_ONE_WAY_TO_WORK NUMERIC(14,4),
     LENGTH_TIME_DRIVING  NUMERIC(9,4),
     RESIDE_WITH_PARENTS_IND CHARACTER(1),
     TICKET_RECEIVED_IND  CHARACTER(1),
     VALID_TO_DTTM        TIMESTAMP     NOT NULL,
     PROCESSED_DTTM       TIMESTAMP     NOT NULL)
     PRIMARY INDEX YOUNG_DRIVER_DETAILS_PI (DRIVER_RK)
;
